@@ -566,16 +566,16 @@ void InstallACL(char *alias,char *classes)
 #include <windows.h>
 
 
-DWORD getNTModeMask ARGLIST((char *new_mode, DWORD old_mode));
-DWORD getNTACEs_Size ARGLIST((struct CFACE *));
-SECURITY_DESCRIPTOR* getNTACLInformation ARGLIST((char *filename, PACL *old_pacl, BOOL *haveACL, ACL_SIZE_INFORMATION *oldACLSize));
-void attachToNTACEs ARGLIST((struct CFACE *new_aces, char *user, char *mode, char *access, char *classes, DWORD NTMask));
-void appendNTACEs ARGLIST((struct CFACE *aces, struct CFACE *new_aces, ACL_SIZE_INFORMATION oldACLSize, PACL old_pacl));
-void AddNTACEs ARGLIST((char *accessType, struct CFACE *new_aces, PACL *new_pacl));
-void createNTACL ARGLIST((struct CFACE *aces, char method, char *filename, enum fileactions action));
+DWORD getNTModeMask (char *new_mode, DWORD old_mode);
+DWORD getNTACEs_Size (struct CFACE *);
+SECURITY_DESCRIPTOR* getNTACLInformation (char *filename, PACL *old_pacl, BOOL *haveACL, ACL_SIZE_INFORMATION *oldACLSize);
+void attachToNTACEs (struct CFACE *new_aces, char *user, char *mode, char *access, char *classes, DWORD NTMask);
+void appendNTACEs (struct CFACE *aces, struct CFACE *new_aces, ACL_SIZE_INFORMATION oldACLSize, PACL old_pacl);
+void AddNTACEs (char *accessType, struct CFACE *new_aces, PACL *new_pacl);
+void createNTACL (struct CFACE *aces, char method, char *filename, enum fileactions action);
 #endif
 
-int CheckNTACE ARGLIST((struct CFACE *aces, char method, char *filename, enum fileactions action));
+int CheckNTACE (struct CFACE *aces, char method, char *filename, enum fileactions action);
 
 #ifdef NT
 
@@ -1692,11 +1692,11 @@ enum fileactions action;/* The action to be performed */
 
 /*****************************************************************************/
 
-int CheckNTACE(aces,method,filename,action)
-struct CFACE *aces;     /* List built up during parsing of config file */
-char method;   /* ACL operation method (o/a) */
-char *filename;   /* The filename */
-enum fileactions action;/* The action to be performed */
+int CheckNTACE(
+       struct CFACE *aces,     /* List built up during parsing of config file */
+       char method,   /* ACL operation method (o/a) */
+       char *filename,   /* The filename */
+       enum fileactions action)/* The action to be performed */
 {
 #ifdef NT
  struct CFACE *ep;
@@ -1718,11 +1718,7 @@ enum fileactions action;/* The action to be performed */
 
 /*************************** END NT Addition *******************************/
 
-int CheckPosixACE(aces,method,filename,action)
-struct CFACE *aces;
-char method;
-char *filename;
-enum fileactions action;
+int CheckPosixACE(struct CFACE *aces,char method,char *filename,enum fileactions action)
 {
 #if defined(HAVE_SYS_ACL_H) && defined(SOLARIS)
  struct CFACE *ep;
