@@ -275,12 +275,13 @@ extern int errno;
 #define true  1
 #define false 0
 #define CF_BUFSIZE 4096
-#define CF_EXPANDSIZE 2*CF_BUFSIZE
-#define CF_ALLCLASSSIZE 4*CF_BUFSIZE
+#define CF_EXPANDSIZE (2*CF_BUFSIZE)
+#define CF_ALLCLASSSIZE (4*CF_BUFSIZE)
 #define CF_BUFFERMARGIN 32
 #define CF_BLOWFISHSIZE 16
+#define CF_SMALLBUF 128
 #define CF_MAXVARSIZE 1024
-#define CF_NONCELEN CF_BUFSIZE/16
+#define CF_NONCELEN (CF_BUFSIZE/16)
 #define CF_MAXLINKSIZE 256
 #define CF_MAXLINKLEVEL 4
 #define CF_MAXARGS 31
@@ -291,19 +292,22 @@ extern int errno;
 #define CF_MACROALPHABET 61    /* a-z, A-Z plus a bit */
 #define CF_MAXSHELLARGS 30
 #define CF_SAMEMODE 0
-#define CF_SAME_OWNER (uid_t)-1
-#define CF_UNKNOWN_OWNER (uid_t)-2
-#define CF_SAME_GROUP (gid_t)-1
-#define CF_UNKNOWN_GROUP (gid_t)-2
+#define CF_SAME_OWNER ((uid_t)-1)
+#define CF_UNKNOWN_OWNER ((uid_t)-2)
+#define CF_SAME_GROUP ((gid_t)-1)
+#define CF_UNKNOWN_GROUP ((gid_t)-2)
 #define CF_NOSIZE    -1
 #define CF_EXTRASPC 8      /* pads items during AppendItem for eol handling in editfiles */
-#define CF_INFINITY (int)999999999
+#define CF_INFINITY ((int)999999999)
 #define CF_TICKS_PER_DAY 86400 /* 60 * 60 *24 */
 #define CF_NOT_CONNECTED -1
 #define CF_RECURSION_LIMIT 100
 #define CF_MONDAY_MORNING 342000
 #define CF_NOVAL -0.7259285297502359
 
+#define CF_IFREQ 8192
+#define CF_ADDRSIZE 128
+
 #define CF_METHODEXEC 0
 #define CF_METHODREPLY  1
 #define CF_EXEC_IFELAPSED 5
@@ -473,6 +477,7 @@ struct LockData
    (including indirect blocks). */
 
 
+#define SMALL_BLOCK_BUF_SIZE 512
 
 #ifndef HAVE_ST_BLOCKS
 # define ST_BLKSIZE(statbuf) DEV_BSIZE
@@ -624,6 +629,7 @@ enum builtin
    fn_islink,
    fn_isplain,
    fn_execresult,
+   fn_execshellresult,
    fn_returnszero,
    fn_iprange,
    fn_hostrange,
@@ -648,6 +654,7 @@ enum builtin
    fn_selectpna,
    fn_greaterthan,
    fn_lessthan,
+   fn_readtcp
    };
 
 /*******************************************************************/
@@ -920,6 +927,7 @@ enum vnames
    cfdefcopy,
    cfredef,
    cfdefpkgmgr,
+   cfabortclasses,
    nonexistentvar
    };
 
@@ -1025,6 +1033,7 @@ enum editnames
    AppendIfNoSuchLinesFromFile,
    IncrementPointer,
    ReplaceLineWith,
+   ExpandVariables,
    DeleteToLineMatching,
    HashCommentToLineMatching,
    PercentCommentToLineMatching,
@@ -1039,8 +1048,10 @@ enum editnames
    GotoLastLine,
    BreakIfLineMatches,
    BeginGroupIfNoMatch,
+   BeginGroupIfMatch,
    BeginGroupIfNoLineMatching,
    BeginGroupIfNoSuchLine,
+   BeginGroupIfLineMatching,
    EndGroup,
    Append,
    Prepend,
@@ -1066,6 +1077,7 @@ enum editnames
    BeginGroupIfFileIsNewer,
    BeginGroupIfFileExists,
    BeginGroupIfNoLineContaining,
+   BeginGroupIfLineContaining,
    BeginGroupIfDefined,
    BeginGroupIfNotDefined,
    AutoCreate,
@@ -1125,7 +1137,7 @@ enum SignalNames
    cfsys,
    cfpipe,
    cfalrm,
-   cfterm,
+   cfterm
    };
 
 #define highest_signal 64
@@ -1139,7 +1151,8 @@ enum cfoutputlevel
    cfverbose,
    cfeditverbose,
    cferror,
-   cflogonly
+   cflogonly,
+   cfloginform
    };
 
 /*******************************************************************/
@@ -1167,7 +1180,8 @@ enum cmpsense   /* For package version comparison */
    cmpsense_lt,
    cmpsense_ge,
    cmpsense_le,
-   cmpsense_ne
+   cmpsense_ne,
+   cmpsense_none
    };
 
 /*******************************************************************/
@@ -1558,7 +1572,7 @@ struct Image
    mode_t minus;
    struct UidList *uid;
    struct GidList *gid;
-   char   *action;                                   /* fix / warn */
+   char   *action;                           /* fix / warn /silent */
    char   *classes;
    char   *defines;
    char   *elsedef;
