@@ -29,21 +29,25 @@
 /*******************************************************************/
 
 
+#include "../pub/getopt.h"
+
 #if defined HAVE_PTHREAD_H && (defined HAVE_LIBPTHREAD || defined BUILDTIN_GCC_THREAD)
 extern pthread_mutex_t MUTEX_SYSCALL;
 extern pthread_mutex_t MUTEX_LOCK;
 #endif
 
+extern short ALL_SINGLECOPY;
 extern int PASS;
 extern RSA *PRIVKEY, *PUBKEY;
 extern char BINDINTERFACE[CF_BUFSIZE];
 extern char *ECGSOCKS[ATTR][2];
 extern char *TCPNAMES[CF_NETATTR];
 extern char **METHODARGV;
-
+extern int GOTMETHODARGS;
 extern struct Item *QUERYVARS;
-extern struct Item *METHODRETURNVARS;;
+extern struct Item *METHODRETURNVARS;
 extern struct Item *METHODRETURNCLASSES;
+
 extern char METHODFILENAME[CF_BUFSIZE];
 extern char *VMETHODPROTO[];
 extern int METHODARGC;
@@ -58,6 +62,7 @@ extern struct cfagent_connection *CONN;
 extern int AUTHENTICATED;
 extern struct Item *IPADDRESSES;
 
+extern char PIDFILE[CF_BUFSIZE];
 extern char  STR_CFENGINEPORT[16];
 extern unsigned short SHORT_CFENGINEPORT;
 
@@ -180,7 +185,7 @@ extern char *GROUPBUFF;
 extern char *ACTIONBUFF;
 extern char *CLASSBUFF;
 extern char ALLCLASSBUFFER[4*CF_BUFSIZE];
-extern char CHROOT[CF_ALLCLASSSIZE];
+extern char CHROOT[CF_BUFSIZE];
 extern char ELSECLASSBUFFER[CF_BUFSIZE];
 extern char FAILOVERBUFFER[CF_BUFSIZE];
 extern char *LINKFROM;
@@ -233,7 +238,7 @@ extern char VFQNAME[];
 extern char VUQNAME[];
 extern char LOGFILE[];
 
-extern short NOABSPATH;
+extern char NOABSPATH;
 
 extern struct Item *VEXCLUDECACHE;
 extern struct Item *VSINGLECOPY;
@@ -250,9 +255,11 @@ extern struct Item *VACLBUILD;
 extern struct Item *VFILTERBUILD;
 extern struct Item *VSTRATEGYBUILD;
 
+
 extern struct Item *VMOUNTLIST;
 extern struct Item *VHEAP;      /* Points to the base of the attribute heap */
 extern struct Item *VNEGHEAP;
+extern struct Item *ABORTHEAP;
 
 /* For packages: */
 extern struct Package *VPKG;
@@ -269,7 +276,7 @@ extern struct cfObject *VOBJ;
 extern char *PARSEMETHODRETURNCLASSES;
 
 extern struct Item *METHODARGS;
-extern flag  MOUNT_RO;                  /* mount directory readonly */
+extern flag  CF_MOUNT_RO;                  /* mount directory readonly */
 
 extern struct Item *VALERTS;
 extern struct Item *VMOUNTED;
@@ -456,6 +463,9 @@ extern char *VHOSTEQUIV[];
 extern char *VFSTAB[];
 extern char *VMAILDIR[];
 extern char *VNETSTAT[];
+extern char *VROUTE[];
+extern char *VROUTEADDFMT[];
+extern char *VROUTEDELFMT[];
 extern char *VFILECOMM[];
 extern char *ACTIONSEQTEXT[];
 extern char *VEDITNAMES[];
