@@ -39,28 +39,25 @@
 /* Functions internal to cfengine.c                                */
 /*******************************************************************/
 
-int main ARGLIST((int argc,char *argv[]));
-void Initialize ARGLIST((int argc, char **argv));
-void PreNetConfig ARGLIST((void));
-void ReadRCFile ARGLIST((void));
-void EchoValues ARGLIST((void));
-void CheckSystemVariables ARGLIST((void));
-void SetReferenceTime ARGLIST((int setclasses));
-void SetStartTime ARGLIST((int setclasses));
-void DoTree ARGLIST((int passes, char *info));
-enum aseq EvaluateAction ARGLIST((char *action, struct Item **classlist, int pass));
-void CheckOpts ARGLIST((int argc, char **argv));
-int GetResource ARGLIST((char *var));
-void BuildClassEnvironment ARGLIST((void));
-void Syntax ARGLIST((void));
-void EmptyActionSequence ARGLIST((void));
-void GetEnvironment ARGLIST((void));
-int NothingLeftToDo ARGLIST((void));
-void SummarizeObjects ARGLIST((void));
-void SetContext ARGLIST((char *id));
-void DeleteCaches ARGLIST((void));
-void CheckForMethod ARGLIST((void));
-void CheckMethodReply ARGLIST((void));
+int main (int argc,char *argv[]);
+void Initialize (int argc, char **argv);
+void PreNetConfig (void);
+void ReadRCFile (void);
+void EchoValues (void);
+void CheckSystemVariables (void);
+void SetReferenceTime (int setclasses);
+void SetStartTime (int setclasses);
+void DoTree (int passes, char *info);
+enum aseq EvaluateAction (char *action, struct Item **classlist, int pass);
+void CheckOpts (int argc, char **argv);
+int GetResource (char *var);
+void Syntax (void);
+void EmptyActionSequence (void);
+void GetEnvironment (void);
+int NothingLeftToDo (void);
+void SummarizeObjects (void);
+void SetContext (char *id);
+void DeleteCaches (void);
 void QueryCheck(void);
 
 /*******************************************************************/
@@ -70,7 +67,7 @@ void QueryCheck(void);
 int main(int argc,char *argv[])
 
 { struct Item *ip;
- 
+    
 SetContext("global");
 SetSignals(); 
  
@@ -107,7 +104,7 @@ ReadRCFile(); /* Should come before parsing so that it can be overridden */
 
        if (!PARSEONLY && (QUERYVARS == NULL))
           {
-          DoTree(1,"Update");
+          DoTree(2,"Update");
           DoAlerts();
           EmptyActionSequence();
           DeleteClassesFromContext("update");
@@ -143,7 +140,8 @@ ReadRCFile(); /* Should come before parsing so that it can be overridden */
  ParseInputFile(VINPUTFILE);
  CheckFilters();
  EchoValues();
- CheckForMethod();
+ 
+/* CheckForMethod(); Move to InitializeAction */
  
  if (PRSYSADM)                                           /* -a option */
     {
@@ -174,12 +172,12 @@ ReadRCFile(); /* Should come before parsing so that it can be overridden */
  
  CfOpenLog();
  CheckSystemVariables();
- 
+
  SetReferenceTime(false); /* Reset */
 
  QueryCheck();
-     
- DoTree(2,"Main Tree"); 
+
+ DoTree(3,"Main Tree"); 
  DoAlerts();
  
  CheckMethodReply();
@@ -603,9 +601,6 @@ void EchoValues()
 { struct Item *ip,*p2;
   char ebuff[CF_EXPANDSIZE];
 
-ebuff[0] = '\0';
-  
-Verbose("Accepted domain name: %s\n\n",VDOMAIN); 
 
 if (GetMacroValue(CONTEXTID,"OutputPrefix"))
    {
@@ -768,9 +763,31 @@ if (VACTIONSEQ == NULL)
 
 sprintf(id,"%d",geteuid());   /* get effective user id */
 
+ebuff[0] = '\0';
+
+if (!StrStr(VSYSNAME.nodename,VDOMAIN))
+   {
+   snprintf(VFQNAME,CF_BUFSIZE,"%s.%s",VSYSNAME.nodename,ToLowerStr(VDOMAIN));
+   strcpy(VUQNAME,VSYSNAME.nodename);
+   }
+else
+   {
+   int n = 0;
+   strcpy(VFQNAME,VSYSNAME.nodename);
+   
+   while(VSYSNAME.nodename[n++] != '.')
+      {
+      }
+   
+   strncpy(VUQNAME,VSYSNAME.nodename,n-1);        
+   }
+  
+Verbose("Accepted domain name: %s\n\n",VDOMAIN); 
+
+
 if (VACCESSLIST != NULL && !IsItemIn(VACCESSLIST,id))
    {
-   FatalError("Access denied");
+   FatalError("Access denied - user not listed in access list");
    }
 
 Debug2("cfagent -d : Debugging output enabled.\n");
@@ -1049,13 +1066,30 @@ if (GetMacroValue(CONTEXTID,"TimeOut"))
       }
    }
 
+/* Make sure we have a healthy binserver list so binserver expansion works, even if binserver not defined */
+
+if (VBINSERVERS == NULL)
+   {
+   PrependItem(&VBINSERVERS,VUQNAME,NULL);
+   }
+
+if (VBINSERVERS->name != NULL)
+   {
+   VDEFAULTBINSERVER = *VBINSERVERS;
+   Verbose("Default binary server seems to be %s\n",VDEFAULTBINSERVER.name);
+   }
+
+AppendItem(&VBINSERVERS,VUQNAME,NULL);
+
+/* Done binserver massage */
+
 if (NOSPLAY)
    {
    return;
    }
 
 time = 0;
-snprintf(ebuff,CF_BUFSIZE,"%s+%s",VFQNAME,VIPADDRESS);
+snprintf(ebuff,CF_BUFSIZE,"%s+%s+%d",VFQNAME,VIPADDRESS,getuid());
 hash = Hash(ebuff);
 
 if (!NOSPLAY)
@@ -1092,30 +1126,6 @@ if (!NOSPLAY)
     } 
 }
 
-/*******************************************************************/
-
-void SetReferenceTime(int setclasses)
-
-{ time_t tloc;
- char vbuff[CF_BUFSIZE];
- 
-if ((tloc = time((time_t *)NULL)) == -1)
-   {
-   CfLog(cferror,"Couldn't read system clock\n","");
-   }
-
-CFSTARTTIME = tloc;
-
-snprintf(vbuff,CF_BUFSIZE,"%s",ctime(&tloc));
-
-Verbose("Reference time set to %s\n",ctime(&tloc));
-
-if (setclasses)
-   {
-   AddTimeClass(vbuff);
-   }
-}
-
 
 /*******************************************************************/
 
@@ -1144,6 +1154,8 @@ exit(0);
 void DoTree(int passes,char *info)
 
 { struct Item *action;
+
+Debug("DoTree(%d,%s)\n",passes,info);
  
 for (PASS = 1; PASS <= passes; PASS++)
    {
@@ -1168,14 +1180,14 @@ for (PASS = 1; PASS <= passes; PASS++)
       
       if ((PASS > 1) && NothingLeftToDo())
          {
-         continue;
+         break;
          }
       
       Verbose("\n*********************************************************************\n");
       Verbose(" %s Sched: %s pass %d @ %s",info,action->name,PASS,ctime(&CFINITSTARTTIME));
       Verbose("*********************************************************************\n\n");
       
-      switch(ACTION = EvaluateAction(action->name,&VADDCLASSES,PASS))
+      switch (EvaluateAction(action->name,&VADDCLASSES,PASS))
          {
          case mountinfo:
              if (PASS == 1)
@@ -1358,96 +1370,187 @@ int NothingLeftToDo()
   struct Process *vproclist;
   struct Tidy *vtidy;
   struct Package *vpkg;
+  struct Image *vcopy;
 
-for (vproclist = VPROCLIST; vproclist != NULL; vproclist=vproclist->next)
+if (IsWildItemIn(VACTIONSEQ,"process*"))
    {
-   if (vproclist->done == 'n' && IsDefinedClass(vproclist->classes))
+   for (vproclist = VPROCLIST; vproclist != NULL; vproclist=vproclist->next)
       {
-      return false;
-      }
-   }
- 
- for (vscript = VSCRIPT; vscript != NULL; vscript=vscript->next)
-    {
-    if (vscript->done == 'n'  && IsDefinedClass(vscript->classes))
-       {
-       return false;
-       }
-    }
- 
-for (vfile = VFILE; vfile != NULL; vfile=vfile->next)
-   {
-   if (vfile->done == 'n' && IsDefinedClass(vfile->classes))
-      {
-      return false;
+      if ((vproclist->done == 'n') && IsDefinedClass(vproclist->classes))
+         {
+         Verbose("Checking for potential rule:: Proc <%s> / %s\n",vproclist->expr,vproclist->classes);
+         return false;
+         }
       }
    }
 
-for (vtidy = VTIDY; vtidy != NULL; vtidy=vtidy->next)
+if (IsWildItemIn(VACTIONSEQ,"shellcomman*"))
    {
-   if (vtidy->done == 'n')
+   for (vscript = VSCRIPT; vscript != NULL; vscript=vscript->next)
       {
-      return false;
-      }
-   }
- 
-for (veditlist = VEDITLIST; veditlist != NULL; veditlist=veditlist->next)
-   {
-   if (veditlist->done == 'n')
-      {
-      return false;
+      if ((vscript->done == 'n')  && IsDefinedClass(vscript->classes))
+         {
+         Verbose("Checking for potential rule:: Shell <%s> / %s\n",vscript->name,vscript->classes);
+         return false;
+         }
       }
    }
 
-for (vdisablelist = VDISABLELIST; vdisablelist != NULL; vdisablelist=vdisablelist->next)
+if (IsWildItemIn(VACTIONSEQ,"cop*"))
    {
-   if (vdisablelist->done == 'n' && IsDefinedClass(vdisablelist->classes))
+   for (vcopy = VIMAGE; vcopy != NULL; vcopy=vcopy->next)
       {
-      return false;
-      }
-   }
-
-for (vmakepath = VMAKEPATH; vmakepath != NULL; vmakepath=vmakepath->next)
-   {
-   if (vmakepath->done == 'n' && IsDefinedClass(vmakepath->classes))
-      {
-      return false;
-      }
-   }
-
-for (vlink = VLINK; vlink != NULL; vlink=vlink->next)
-   {
-   if (vlink->done == 'n' && IsDefinedClass(vlink->classes))
-      {
-      return false;
-      }
-   }
-
-for (vchlink = VCHLINK; vchlink != NULL; vchlink=vchlink->next)
-   {
-   if (vchlink->done == 'n' && IsDefinedClass(vchlink->classes))
-      {
-      return false;
+      if ((vcopy->done == 'n')  && IsDefinedClass(vcopy->classes))
+         {
+         Verbose("Checking for potential rule:: Copy <%s> / %s\n",vcopy->path,vcopy->classes);
+         return false;
+         }
       }
    }
 
 
-for (vunmount = VUNMOUNT; vunmount != NULL; vunmount=vunmount->next)
+if (IsWildItemIn(VACTIONSEQ,"file*"))
    {
-   if (vunmount->done == 'n' && IsDefinedClass(vunmount->classes))
+   for (vfile = VFILE; vfile != NULL; vfile=vfile->next)
       {
-      return false;
+      if ((vfile->done == 'n') && IsDefinedClass(vfile->classes))
+         {
+         Verbose("Checking for potential rule:: File <%s>/ %s\n",vfile->path,vfile->classes);
+         return false;
+         }
       }
    }
 
-for (vpkg = VPKG; vpkg != NULL; vpkg=vpkg->next)
+if (IsWildItemIn(VACTIONSEQ,"tid*"))
    {
-   if (vpkg->done == 'n' && IsDefinedClass(vpkg->classes))
+   for (vtidy = VTIDY; vtidy != NULL; vtidy=vtidy->next)
       {
-      return false;
+      if (vtidy->done == 'n')
+         {
+         struct TidyPattern *tp;
+         int active = 0;
+         
+         for (tp = vtidy->tidylist; tp != NULL; tp=tp->next)
+            {
+            if (IsDefinedClass(tp->classes))
+               {
+               active=1;
+               break;
+               }
+            }
+
+         if (active)
+            {
+            Verbose("Checking for potential rule:: Tidy <%s>\n",vtidy->path);
+            return false;
+            }
+         }
       }
    }
 
+if (IsWildItemIn(VACTIONSEQ,"editfile*"))
+   {
+   for (veditlist = VEDITLIST; veditlist != NULL; veditlist=veditlist->next) 
+      { 
+      struct Edlist *ep;
+      int something_to_do = false;
+      
+      for (ep = veditlist->actions; ep != NULL; ep=ep->next)
+         {
+         if (IsDefinedClass(ep->classes))
+            {
+            something_to_do = true;
+            if (ep->data)
+               {
+               Verbose("Defined Edit %s / %s\n",ep->data,ep->classes);
+               }
+            else
+               {
+               Verbose("Defined Edit nodata / %s\n",ep->classes);
+               }
+            break;
+            }
+         }
+   
+      if (veditlist->done == 'n' && something_to_do)
+         {
+         Verbose("Checking for potential rule:: Edit <%s>\n",veditlist->fname);
+         return false;
+         }
+      }
+   }
+
+if (IsWildItemIn(VACTIONSEQ,"process*"))
+   {
+   for (vdisablelist = VDISABLELIST; vdisablelist != NULL; vdisablelist=vdisablelist->next)
+      {
+      if (vdisablelist->done == 'n' && IsDefinedClass(vdisablelist->classes))
+         {
+         Verbose("Checking for potential rule:: Disable <%s> / %s\n",vdisablelist->name,vdisablelist->classes);
+         return false;
+         }
+      }
+   }
+
+if (IsWildItemIn(VACTIONSEQ,"director*"))
+   {
+   for (vmakepath = VMAKEPATH; vmakepath != NULL; vmakepath=vmakepath->next)
+      {
+      if (vmakepath->done == 'n' && IsDefinedClass(vmakepath->classes))
+         {
+         Verbose("Checking for potential rule:: makePath <%s>\n",vmakepath->path);
+         return false;
+         }
+      }
+   }
+
+if (IsWildItemIn(VACTIONSEQ,"link*"))
+   {
+   for (vlink = VLINK; vlink != NULL; vlink=vlink->next)
+      {
+      if (vlink->done == 'n' && IsDefinedClass(vlink->classes))
+         {
+         Verbose("Checking for potential rule:: Link <%s>\n",vlink->from);
+         return false;
+         }
+      }
+   
+   for (vchlink = VCHLINK; vchlink != NULL; vchlink=vchlink->next)
+      {
+      if (vchlink->done == 'n' && IsDefinedClass(vchlink->classes))
+         {
+         Verbose("Checking for potential rule:: CLink <%s>\n",vchlink->from);
+         return false;
+         }
+      }
+   }
+
+
+if (IsWildItemIn(VACTIONSEQ,"unmoun*"))
+   {
+   for (vunmount = VUNMOUNT; vunmount != NULL; vunmount=vunmount->next)
+      {
+      if (vunmount->done == 'n' && IsDefinedClass(vunmount->classes))
+         {
+         Verbose("Checking for potential rule:: Umount <%s>\n",vunmount->name);
+         return false;
+         }
+      }
+   }
+
+if (IsWildItemIn(VACTIONSEQ,"packag*"))
+   {
+   for (vpkg = VPKG; vpkg != NULL; vpkg=vpkg->next)
+      {
+      if (vpkg->done == 'n' && IsDefinedClass(vpkg->classes))
+         {
+         Verbose("Checking for potential rule:: Packages <%s>\n",vpkg->name);
+         return false;
+         }
+      }
+   }
+
+
 return true; 
 }
 
@@ -1764,84 +1867,6 @@ while ((c=getopt_long(argc,argv,"WbBzMgAbKqkhYHd:vlniIf:pPmcCtsSaeEVD:N:LwxXuUj:
   }
 }
 
-/*******************************************************************/
-
-void CheckForMethod()
-
-{ struct Item *ip;
-  int i = 0;
-
-if (strcmp(METHODNAME,"cf-nomethod") == 0)
-   {
-   return;
-   }
-
-if (! MINUSF)
-   {
-   FatalError("Input files claim to be a module but this is a parent process\n");
-   }
-
-Verbose("\n++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++\n+\n");
-Verbose("+ This is a private method: %s\n",METHODNAME);
-
-if (METHODARGS == NULL)
-   {
-   FatalError("This module was declared a method but no MethodParameters declaration was given");
-   }
-else
-   {
-   Verbose("+\n+ Method argument prototype = (");
-
-   i = 1;
-   
-   for (ip = METHODARGS; ip != NULL; ip=ip->next)
-      {
-      i++;
-      }
-
-   METHODARGV = (char **) malloc(sizeof(char *) * i); 
-   
-   i = 0;
-
-   for (ip = METHODARGS; ip != NULL; ip=ip->next)
-      {
-      /* Fill this temporarily with the formal parameters */
-      METHODARGV[i++] = ip->name; 
-      }
-
-   METHODARGC = i;
-   
-   Verbose(" )\n+\n");
-   }
- 
-Verbose("++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++\n\n");
-
-Verbose("Looking for a data package for this method (%s)\n",METHODMD5);
-
-if (!ChildLoadMethodPackage(METHODNAME,METHODMD5))
-   {
-   snprintf(OUTPUT,CF_BUFSIZE,"No valid incoming request to execute method (%s)\n",METHODNAME);
-   CfLog(cfinform,OUTPUT,"");
-   exit(0);
-   }
-
-Debug("Method package looks ok -- proceeding\n"); 
-}
-
-/*******************************************************************/
-
-void CheckMethodReply()
-
-{
-if (ScopeIsMethod())
-   {
-   if (strlen(METHODREPLYTO) > 0)
-      {
-      Banner("Method reply message");
-      DispatchMethodReply();
-      }
-   }
-}
 
 /*******************************************************************/
 
@@ -1862,110 +1887,6 @@ FatalError(OUTPUT);
 return 0;
 }
 
-/*******************************************************************/
-
-void SetStartTime(int setclasses)
-
-{ time_t tloc;
- 
-if ((tloc = time((time_t *)NULL)) == -1)
-   {
-   CfLog(cferror,"Couldn't read system clock\n","");
-   }
-
-CFINITSTARTTIME = tloc;
-
-Debug("Job start time set to %s\n",ctime(&tloc));
-}
-
-/*******************************************************************/
-
-void BuildClassEnvironment()
-
-{ struct Item *ip;
- int size = 0;
- char file[CF_BUFSIZE], *sp;
- FILE *fp;
- 
-Debug("(BuildClassEnvironment)\n");
-
-snprintf(ALLCLASSBUFFER,CF_BUFSIZE,"%s=",CF_ALLCLASSESVAR);
-
-if (!IsPrivileged())
-   {
-   Verbose("\n(Non privileged user...)\n\n");
-   
-   if ((sp = getenv("HOME")) == NULL)
-      {
-      FatalError("You do not have a HOME variable pointing to your home directory");
-      }  
-
-   snprintf(file,CF_BUFSIZE,"%s/.cfagent/allclasses",sp);
-   }
-else
-   {
-   snprintf(file,CF_BUFSIZE,"%s/state/allclasses",WORKDIR);
-   }
-
-
-if ((fp = fopen(file,"w")) == NULL)
-   {
-   CfLog(cfinform,"Could not open allclasses cache file","");
-   return;
-   }
-
-for (ip = VHEAP; ip != NULL; ip=ip->next)
-   {
-   if (IsDefinedClass(ip->name))
-      {
-      if ((size += strlen(ip->name)) > CF_ALLCLASSSIZE - CF_BUFFERMARGIN)
-         {
-         Verbose("Class buffer overflowed, dumping class environment for modules\n");
-         Verbose("This would probably crash the exec interface on most machines\n");
-         }
-      else
-         {
-         size++; /* Allow for : separator */
-         strcat(ALLCLASSBUFFER,ip->name);
-         strcat(ALLCLASSBUFFER,":");
-         }
-
-      fprintf(fp,"%s\n",ip->name);
-      }
-   }
- 
- for (ip = VALLADDCLASSES; ip != NULL; ip=ip->next)
-    {
-    if (IsDefinedClass(ip->name))
-      {
-      if ((size += strlen(ip->name)) > 4*CF_BUFSIZE - CF_BUFFERMARGIN)
-         {
-         Verbose("Class buffer overflowed, dumping class environment for modules\n");
-         Verbose("This would probably crash the exec interface on most machines\n");
-         }
-      else
-         {
-         size++; /* Allow for : separator */
-         strcat(ALLCLASSBUFFER,ip->name);
-         strcat(ALLCLASSBUFFER,":");         
-         }
-      
-      fprintf(fp,"%s\n",ip->name);
-      }
-    }
- 
- Debug2("---\nENVIRONMENT: %s\n---\n",ALLCLASSBUFFER);
- 
- if (USEENVIRON)
-    {
-    if (putenv(ALLCLASSBUFFER) == -1)
-       {
-       perror("putenv");
-       }
-    }
-
- fclose(fp);
-}
 
 /*******************************************************************/
 
@@ -1986,6 +1907,6 @@ printf("\nDebug levels: 1=parsing, 2=running, 3=summary, 4=expression eval\n");
 
 printf("\nBug reports to bug-cfengine@gnu.org (News: gnu.cfengine.bug)\n");
 printf("General help to help-cfengine@gnu.org (News: gnu.cfengine.help)\n");
-printf("Info & fixes at http://www.iu.hio.no/cfengine\n");
+printf("Info & fixes at http://www.cfengine.org\n");
 }
 /* EOF */
