@@ -125,41 +125,41 @@ char *PH_BINARIES[PH_LIMIT] =   /* Miss leading slash */
 /* Prototypes                                                      */
 /*******************************************************************/
 
-void CheckOptsAndInit ARGLIST((int argc,char **argv));
-void Syntax ARGLIST((void));
-void StartServer ARGLIST((int argc, char **argv));
-void *ExitCleanly ARGLIST((void));
-void yyerror ARGLIST((char *s));
-void FatalError ARGLIST((char *s));
-void RotateFiles ARGLIST((char *s, int n));
+void CheckOptsAndInit (int argc,char **argv);
+void Syntax (void);
+void StartServer (int argc, char **argv);
+void *ExitCleanly (void);
+void yyerror (char *s);
+void FatalError (char *s);
+void RotateFiles (char *s, int n);
 
-void GetDatabaseAge ARGLIST((void));
-void LoadHistogram  ARGLIST((void));
-void GetQ ARGLIST((void));
-char *GetTimeKey ARGLIST((void));
-struct Averages EvalAvQ ARGLIST((char *timekey));
-void ArmClasses ARGLIST((struct Averages newvals,char *timekey));
+void GetDatabaseAge (void);
+void LoadHistogram  (void);
+void GetQ (void);
+char *GetTimeKey (void);
+struct Averages EvalAvQ (char *timekey);
+void ArmClasses (struct Averages newvals,char *timekey);
 
-void GatherProcessData ARGLIST((void));
-void GatherDiskData ARGLIST((void));
-void GatherLoadData ARGLIST((void));
-void GatherSocketData ARGLIST((void));
-void GatherPhData ARGLIST((void));
-struct Averages *GetCurrentAverages ARGLIST((char *timekey));
-void UpdateAverages ARGLIST((char *timekey, struct Averages newvals));
-void UpdateDistributions ARGLIST((char *timekey, struct Averages *av));
-double WAverage ARGLIST((double newvals,double oldvals, double age));
-double SetClasses ARGLIST((char *name,double variable,double av_expect,double av_var,double localav_expect,double localav_var,struct Item **classlist,char *timekey));
-void SetVariable ARGLIST((char *name,double now, double average, double stddev, struct Item **list));
-void RecordChangeOfState  ARGLIST((struct Item *list,char *timekey));
-double RejectAnomaly ARGLIST((double new,double av,double var,double av2,double var2));
-int HashPhKey ARGLIST((char *s));
-void SetEntropyClasses ARGLIST((char *service,struct Item *list,char *inout));
-void AnalyzeArrival ARGLIST((char *tcpbuffer));
-void ZeroArrivals ARGLIST((void));
-void TimeOut ARGLIST((void));
-void IncrementCounter ARGLIST((struct Item **list,char *name));
-void SaveTCPEntropyData ARGLIST((struct Item *list,int i, char *inout));
+void GatherProcessData (void);
+void GatherDiskData (void);
+void GatherLoadData (void);
+void GatherSocketData (void);
+void GatherPhData (void);
+struct Averages *GetCurrentAverages (char *timekey);
+void UpdateAverages (char *timekey, struct Averages newvals);
+void UpdateDistributions (char *timekey, struct Averages *av);
+double WAverage (double newvals,double oldvals, double age);
+double SetClasses (char *name,double variable,double av_expect,double av_var,double localav_expect,double localav_var,struct Item **classlist,char *timekey);
+void SetVariable (char *name,double now, double average, double stddev, struct Item **list);
+void RecordChangeOfState  (struct Item *list,char *timekey);
+double RejectAnomaly (double new,double av,double var,double av2,double var2);
+int HashPhKey (char *s);
+void SetEntropyClasses (char *service,struct Item *list,char *inout);
+void AnalyzeArrival (char *tcpbuffer);
+void ZeroArrivals (void);
+void TimeOut (void);
+void IncrementCounter (struct Item **list,char *name);
+void SaveTCPEntropyData (struct Item *list,int i, char *inout);
 
 /*******************************************************************/
 /* Level 0 : Main                                                  */
@@ -241,6 +241,10 @@ while ((c=getopt_long(argc,argv,"d:vhHFVT",CFDENVOPTIONS,&optindex)) != EOF)
 
 LOGGING = true;                    /* Do output to syslog */
 
+SetReferenceTime(false);
+SetStartTime(false);
+SetSignals();
+
 /* XXX Initialize workdir for non privileged users */
 
 strcpy(CFWORKDIR,WORKDIR);
@@ -368,11 +372,11 @@ printf("Info & fixes at http://www.iu.hio.no/cfengine\n");
 
 void GetDatabaseAge()
 
-{ int errno;
+{ int err_no;
   DBT key,value;
   DB *dbp;
 
-if ((errno = db_create(&dbp,NULL,0)) != 0)
+if ((err_no = db_create(&dbp,NULL,0)) != 0)
    {
    snprintf(OUTPUT,CF_BUFSIZE,"Couldn't open average database %s\n",AVDB);
    CfLog(cferror,OUTPUT,"db_open");
@@ -380,9 +384,9 @@ if ((errno = db_create(&dbp,NULL,0)) != 0)
    }
 
 #ifdef CF_OLD_DB
-if ((errno = dbp->open(dbp,AVDB,NULL,DB_BTREE,DB_CREATE,0644)) != 0)
+if ((err_no = dbp->open(dbp,AVDB,NULL,DB_BTREE,DB_CREATE,0644)) != 0)
 #else
-if ((errno = dbp->open(dbp,NULL,AVDB,NULL,DB_BTREE,DB_CREATE,0644)) != 0)    
+if ((err_no = dbp->open(dbp,NULL,AVDB,NULL,DB_BTREE,DB_CREATE,0644)) != 0)    
 #endif
    {
    AGE = WAGE = 0;
@@ -399,18 +403,16 @@ memset(&value,0,sizeof(value));
 key.data = "DATABASE_AGE";
 key.size = strlen("DATABASE_AGE")+1;
 
-if ((errno = dbp->get(dbp,NULL,&key,&value,0)) != 0)
+if ((err_no = dbp->get(dbp,NULL,&key,&value,0)) != 0)
    {
-   if (errno != DB_NOTFOUND)
+   if (err_no != DB_NOTFOUND)
       {
-      dbp->err(dbp,errno,NULL);
+      dbp->err(dbp,err_no,NULL);
       dbp->close(dbp,0);
       return;
       }
    }
  
-dbp->close(dbp,0);
-
 if (value.data != NULL)
    {
    AGE = *(double *)(value.data);
@@ -422,6 +424,8 @@ else
    Debug("No previous AGE\n");
    AGE = 0.0;
    }
+
+dbp->close(dbp,0);
 }
 
 /*********************************************************************/
@@ -482,6 +486,7 @@ if (!NO_FORK)
    ActAsDaemon(0);
    }
 
+WritePID("cfenvd.pid");
 signal (SIGTERM,HandleSignal);                   /* Signal Handler */
 signal (SIGHUP,HandleSignal);
 signal (SIGINT,HandleSignal);
@@ -639,7 +644,7 @@ GatherPhData();
 char *GetTimeKey()
 
 { time_t now;
-  char str[64];
+  char str[CF_SMALLBUF];
   
 if ((now = time((time_t *)NULL)) == -1)
    {
@@ -811,7 +816,7 @@ SetVariable("loadavg",LOADAVG,av.expect_loadavg,sig,&classlist);
  
 for (i = 0; i < ATTR; i++)
    {
-   char name[256];
+   char name[CF_MAXLINKSIZE];
    strcpy(name,ECGSOCKS[i][1]);
    strcat(name,"_in");
    
@@ -838,7 +843,7 @@ for (i = 0; i < PH_LIMIT; i++)
 
 for (i = 0; i < CF_NETATTR; i++)
    {
-   char name[256];
+   char name[CF_MAXLINKSIZE];
    strcpy(name,TCPNAMES[i]);
    strcat(name,"_in");
    sig = SetClasses(name,NETIN[i],av.expect_netin[i],av.var_netin[i],LOCALAV.expect_netin[i],LOCALAV.var_netin[i],&classlist,timekey);
@@ -907,7 +912,7 @@ if (strstr(arrival,"tcp") || strstr(arrival,"ack"))
     
     switch (flag)
        {
-       case 'S': Debug("%1.1f: TCP new connection from %s to %d - i am %s\n",ITER,src,dest,VIPADDRESS);
+       case 'S': Debug("%1.1f: TCP new connection from %s to %s - i am %s\n",ITER,src,dest,VIPADDRESS);
     if (IsInterfaceAddress(dest))
        {
        NETIN[tcpsyn]++;
@@ -1213,7 +1218,7 @@ while (!feof(pp))
       PrependItem(&ALL_INCOMING,sp,NULL);
       }
    
-   for (sp = remote+strlen(remote); !isdigit((int)*sp); sp--)
+   for (sp = remote+strlen(remote); (sp >= remote) && !isdigit((int)*sp); sp--)
       {
       }
 
@@ -1240,7 +1245,7 @@ while (!feof(pp))
          AppendItem(&in[i],VBUFF,"");
          }
       
-      for (spend = remote+strlen(remote)-1; isdigit((int)*spend); spend--)
+      for (spend = remote+strlen(remote)-1; (sp >= remote) && isdigit((int)*spend); spend--)
          {
          }
       
@@ -1366,8 +1371,8 @@ void GatherPhData()
 { DIR *dirh;
   struct dirent *dirp;
   struct stat statbuf;
-  char file[64];
-  char key[256];
+  char file[CF_SMALLBUF];
+  char key[CF_MAXLINKSIZE];
   FILE *fp;
   int i,h,pid,value,profile;
   
@@ -1405,7 +1410,7 @@ for (dirp = readdir(dirh); dirp != NULL; dirp = readdir(dirh))
       continue;
       }
 
-   snprintf(file,63,"/proc/%s/pH",dirp->d_name);
+   snprintf(file,CF_SMALLBUF-1,"/proc/%s/pH",dirp->d_name);
    
    if ((fp = fopen(file,"r")) == NULL)
       {
@@ -1420,7 +1425,7 @@ for (dirp = readdir(dirh); dirp != NULL; dirp = readdir(dirh))
    
    while (!feof(fp))
       {
-      fgets(VBUFF,64,fp);
+      fgets(VBUFF,CF_SMALLBUF,fp);
       
       if (strncmp(VBUFF,"No profile",strlen("No profile")) == 0)
          {
@@ -1484,12 +1489,12 @@ for (dirp = readdir(dirh); dirp != NULL; dirp = readdir(dirh))
 
 struct Averages *GetCurrentAverages(char *timekey)
 
-{ int errno;
+{ int err_no;
   DBT key,value;
   DB *dbp;
   static struct Averages entry;
  
-if ((errno = db_create(&dbp,NULL,0)) != 0)
+if ((err_no = db_create(&dbp,NULL,0)) != 0)
    {
    sprintf(OUTPUT,"Couldn't open average database %s\n",AVDB);
    CfLog(cferror,OUTPUT,"db_open");
@@ -1497,9 +1502,9 @@ if ((errno = db_create(&dbp,NULL,0)) != 0)
    }
 
 #ifdef CF_OLD_DB 
-if ((errno = dbp->open(dbp,AVDB,NULL,DB_BTREE,DB_CREATE,0644)) != 0)
+if ((err_no = dbp->open(dbp,AVDB,NULL,DB_BTREE,DB_CREATE,0644)) != 0)
 #else
-if ((errno = dbp->open(dbp,NULL,AVDB,NULL,DB_BTREE,DB_CREATE,0644)) != 0)    
+if ((err_no = dbp->open(dbp,NULL,AVDB,NULL,DB_BTREE,DB_CREATE,0644)) != 0)    
 #endif
    {
    sprintf(OUTPUT,"Couldn't open average database %s\n",AVDB);
@@ -1514,11 +1519,11 @@ memset(&entry,0,sizeof(entry));
 key.data = timekey;
 key.size = strlen(timekey)+1;
 
-if ((errno = dbp->get(dbp,NULL,&key,&value,0)) != 0)
+if ((err_no = dbp->get(dbp,NULL,&key,&value,0)) != 0)
    {
-   if (errno != DB_NOTFOUND)
+   if (err_no != DB_NOTFOUND)
       {
-      dbp->err(dbp,errno,NULL);
+      dbp->err(dbp,err_no,NULL);
       dbp->close(dbp,0);
       return NULL;
       }
@@ -1546,11 +1551,11 @@ else
 
 void UpdateAverages(char *timekey,struct Averages newvals)
 
-{ int errno;
+{ int err_no;
   DBT key,value;
   DB *dbp;
  
-if ((errno = db_create(&dbp,NULL,0)) != 0)
+if ((err_no = db_create(&dbp,NULL,0)) != 0)
    {
    sprintf(OUTPUT,"Couldn't open average database %s\n",AVDB);
    CfLog(cferror,OUTPUT,"db_open");
@@ -1558,9 +1563,9 @@ if ((errno = db_create(&dbp,NULL,0)) != 0)
    }
 
 #ifdef CF_OLD_DB 
-if ((errno = dbp->open(dbp,AVDB,NULL,DB_BTREE,DB_CREATE,0644)) != 0)
+if ((err_no = dbp->open(dbp,AVDB,NULL,DB_BTREE,DB_CREATE,0644)) != 0)
 #else
-if ((errno = dbp->open(dbp,NULL,AVDB,NULL,DB_BTREE,DB_CREATE,0644)) != 0)    
+if ((err_no = dbp->open(dbp,NULL,AVDB,NULL,DB_BTREE,DB_CREATE,0644)) != 0)    
 #endif
    {
    sprintf(OUTPUT,"Couldn't open average database %s\n",AVDB);
@@ -1577,9 +1582,9 @@ key.size = strlen(timekey)+1;
 value.data = &newvals;
 value.size = sizeof(newvals);
  
-if ((errno = dbp->put(dbp,NULL,&key,&value,0)) != 0)
+if ((err_no = dbp->put(dbp,NULL,&key,&value,0)) != 0)
    {
-   dbp->err(dbp,errno,NULL);
+   dbp->err(dbp,err_no,NULL);
    dbp->close(dbp,0);
    return;
    } 
@@ -1592,9 +1597,9 @@ value.size = sizeof(double);
 key.data = "DATABASE_AGE";
 key.size = strlen("DATABASE_AGE")+1;
 
-if ((errno = dbp->put(dbp,NULL,&key,&value,0)) != 0)
+if ((err_no = dbp->put(dbp,NULL,&key,&value,0)) != 0)
    {
-   dbp->err(dbp,errno,NULL);
+   dbp->err(dbp,err_no,NULL);
    dbp->close(dbp,0);
    return;
    }
@@ -1691,7 +1696,7 @@ if (HISTO)
       position = CF_GRAINS/2 + (int)(0.5+(PH_DELTA[i] - av->expect_pH[i])*CF_GRAINS/(4*sqrt((av->var_pH[i]))));
       if (0 <= position && position < CF_GRAINS)
          {
-         HISTOGRAM[5+2*CF_NETATTR+2*2*ATTR+i][day][position]++;
+         HISTOGRAM[5+2*CF_NETATTR+2*ATTR+i][day][position]++;
          }
       }
    
