@@ -42,21 +42,21 @@
 /* Prototypes                                                                */
 /*****************************************************************************/
 
-int main ARGLIST((int argc, char **argv));
-void CheckOpts ARGLIST((int argc, char **argv));
-void Syntax ARGLIST((void));
-void ReadAverages ARGLIST((void));
-void SummarizeAverages ARGLIST((void));
-void WriteGraphFiles ARGLIST((void));
-void WriteHistograms ARGLIST((void));
-void FindHurstExponents ARGLIST((void));
-void DiskArrivals ARGLIST((void));
-void GetFQHN ARGLIST((void));
-struct Averages FindHurstFunction ARGLIST((int sameples_per_grain, int grains));
+int main (int argc, char **argv);
+void CheckOpts (int argc, char **argv);
+void Syntax (void);
+void ReadAverages (void);
+void SummarizeAverages (void);
+void WriteGraphFiles (void);
+void WriteHistograms (void);
+void FindHurstExponents (void);
+void DiskArrivals (void);
+void GetFQHN (void);
+struct Averages FindHurstFunction (int sameples_per_grain, int grains);
 
 /*****************************************************************************/
 
-/* char *COPYRIGHT = "Free Software Foundation 2001-\nDonated by Mark Burgess, Faculty of Engineering,\nOslo University College, 0254 Oslo, Norway";
+/* char *COPYRIGHT = "Free Software Foundation 2001-\nDonated by Mark Burgess, Faculty of Engineering,\nOslo University College, Norway";
  */
 
 struct option GRAPHOPTIONS[] =
@@ -81,7 +81,7 @@ int NOSCALING = true;
 char FILENAME[CF_BUFSIZE];
 unsigned int HISTOGRAM[ATTR*2+CF_NETATTR*2+5+PH_LIMIT][7][CF_GRAINS];
 int SMOOTHHISTOGRAM[ATTR*2+CF_NETATTR*2+5+PH_LIMIT][7][CF_GRAINS];
-char VFQNAME[CF_BUFSIZE];
+char VFQNAME[CF_MAXVARSIZE];
 
 /*****************************************************************************/
 /*
@@ -125,7 +125,7 @@ time_t NOW;
 DBT key,value;
 DB *DBP;
 static struct Averages ENTRY,MAX,MIN,DET;
-char TIMEKEY[64],FLNAME[CF_BUFSIZE],*sp;
+char TIMEKEY[CF_SMALLBUF],FLNAME[CF_BUFSIZE],*sp;
 double AGE;
 FILE *FPAV=NULL,*FPVAR=NULL,*FPROOT=NULL,*FPUSER=NULL,*FPOTHER=NULL;
 FILE *FPDISK=NULL,*FPLOAD=NULL,*FPIN[ATTR],*FPOUT[ATTR],*FPPH[PH_LIMIT],*fp;
