@@ -90,25 +90,25 @@ const int INF_LINES = -2;
 /* Functions internal to cfservd.c                                 */
 /*******************************************************************/
 
-void CheckOptsAndInit ARGLIST((int argc,char **argv));
-void StartServer ARGLIST((int argc, char **argv));
-void Syntax ARGLIST((void));
-void *ExitCleanly ARGLIST((void));
-void *LocalExec ARGLIST((void *dummy));
-void MailResult ARGLIST((char *filename, char *to));
-int ScheduleRun ARGLIST((void));
-void AddClassToHeap ARGLIST((char *class));
-void DeleteClassFromHeap ARGLIST((char *class));
-int Dialogue  ARGLIST((int sd,char *class));
+void CheckOptsAndInit (int argc,char **argv);
+void StartServer (int argc, char **argv);
+void Syntax (void);
+void *ExitCleanly (void);
+void *LocalExec (void *scheduled_run);
+void MailResult (char *filename, char *to);
+int ScheduleRun (void);
+void AddClassToHeap (char *class);
+void DeleteClassFromHeap (char *class);
+int Dialogue  (int sd,char *class);
 int OpeningCeremony(int sd);
-void GetCfStuff ARGLIST((void));
-void Banner ARGLIST((char * s));
+void GetCfStuff (void);
+void Banner (char * s);
 
 /* 
  * HvB: Bas van der Vlies
 */
-int CompareResult ARGLIST((char *filename, char *prev_file));
-int FileChecksum ARGLIST((char *filename, unsigned char *digest, char type));
+int CompareResult (char *filename, char *prev_file);
+int FileChecksum (char *filename, unsigned char *digest, char type);
 
 /*******************************************************************/
 /* Level 0 : Main                                                  */
@@ -244,9 +244,8 @@ strncpy(VLOCKDIR,CFWORKDIR,CF_BUFSIZE-1);
 strncpy(VLOGDIR,CFWORKDIR,CF_BUFSIZE-1);
 
 VCANONICALFILE = strdup(CanonifyName(VINPUTFILE));
-GetNameInfo();
 
-strcpy(VUQNAME,VSYSNAME.nodename);
+GetCfStuff();
 
 MAILTO[0] = '\0';
 MAILFROM[0] = '\0';
@@ -287,6 +286,7 @@ if (!NO_FORK)
   ActAsDaemon(0);
   }
 
+WritePID("cfexecd.pid");
 signal(SIGINT,(void *)ExitCleanly);
 signal(SIGTERM,(void *)ExitCleanly);
 signal(SIGHUP,SIG_IGN);
@@ -299,7 +299,7 @@ umask(077);
 if (ONCE)
    {
    GetCfStuff();
-   LocalExec(NULL);
+   LocalExec((void *)0);
    }
 else
    { char **nargv;
@@ -345,7 +345,9 @@ else
           */
          
          Debug("Spawning %s\n", nargv[0]);
+
          pid = spawnvp((int)_P_NOWAIT, nargv[0], nargv);
+
          if (pid < 1)
             {
             CfLog(cfinform,"Can't spawn run","spawnvp");
@@ -361,15 +363,15 @@ else
          pthread_attr_setstacksize(&PTHREADDEFAULTS,(size_t)2048*1024);
 #endif
          
-         if (pthread_create(&tid,&PTHREADDEFAULTS,LocalExec,NULL) != 0)
+         if (pthread_create(&tid,&PTHREADDEFAULTS,LocalExec,(void *)1) != 0)
             {
             CfLog(cfinform,"Can't create thread!","pthread_create");
-            LocalExec(NULL);
+            LocalExec((void *)1);
             }
          
          pthread_attr_destroy(&PTHREADDEFAULTS);
 #else
-         LocalExec(NULL);  
+         LocalExec((void *)1);  
 #endif
 #endif
          
@@ -411,7 +413,7 @@ void GetCfStuff()
 
 /* Do not init variables here, in case we can use previous values. */
   
-snprintf(cfcom,CF_BUFSIZE-1,"%s/bin/cfagent -Q smtpserver,sysadm,fqhost,ipaddress,EmailMaxLines,EmailFrom,EmailTo -D from_cfexecd",CFWORKDIR);
+snprintf(cfcom,CF_BUFSIZE-1,"%s/bin/cfagent -Q smtpserver,sysadm,fqhost,host,domain,ipaddress,EmailMaxLines,EmailFrom,EmailTo -D from_cfexecd",CFWORKDIR);
 
 if ((pp=cfpopen(cfcom,"r")) ==  NULL)
    {
@@ -449,18 +451,41 @@ while (!feof(pp))
       continue;
       }
 
+   if (strcmp(name,"host") == 0)
+      {
+      Debug("%s/%s\n",name,content);
+      strncpy(VUQNAME,content,CF_MAXVARSIZE-1);
+      continue;
+      }
+
+   if (strcmp(name,"domain") == 0)
+      {
+      Debug("%s/%s\n",name,content);
+      strncpy(VDOMAIN,content,CF_MAXVARSIZE-1);
+      continue;
+      }
+
    if (strcmp(name,"ipaddress") == 0)
       {
       Debug("%s/%s\n",name,content);
-      strncpy(VIPADDRESS,content,CF_MAXVARSIZE-1);
+      strncpy(VIPADDRESS,content,17);
       continue;
       }
 
    if (strcmp(name,"EmailMaxLines") == 0)
       {
       Debug("%s/%s\n",name,content);
-      MAXLINES = 20;
-      sscanf(content,"%d",&MAXLINES);
+
+      MAXLINES = 100;
+      if (strcmp(content,"inf") == 0)
+         {
+         MAXLINES = -2;
+         Debug("EmailMaxLines set to infinity\n");
+         }
+      else 
+         {
+         sscanf(content,"%d",&MAXLINES);
+         }
       continue;
       }
 
@@ -487,7 +512,7 @@ while (!feof(pp))
 
 cfpclose(pp);
 
-Debug("Got(to:%s,serv:%s,host:%s,ip:%s,max:%d,from:%s)\n",MAILTO,VMAILSERVER,VFQNAME,VIPADDRESS,MAXLINES,MAILFROM); 
+Debug("Got(to:%s,serv:%s,fqhost:%s,host:%s,domain:%s,ip:%s,max:%d,from:%s)\n",MAILTO,VMAILSERVER,VFQNAME,VUQNAME,VDOMAIN,VIPADDRESS,MAXLINES,MAILFROM); 
  
 /* Now get schedule */
   
@@ -554,14 +579,12 @@ for (ip = SCHEDULE; ip != NULL; ip = ip->next)
       Verbose("Waking up the agent at %s ~ %s \n",timekey,ip->name);
       DeleteItemList(VHEAP);
       VHEAP = NULL;
-      GetNameInfo();
       return true;
       }
    }
 
 DeleteItemList(VHEAP);
 VHEAP = NULL; 
-GetNameInfo();
 return false;
 }
 
@@ -574,7 +597,7 @@ void *ExitCleanly()
 {
 ReleaseCurrentLock();
 closelog();
- 
+unlink(PIDFILE);
 exit(0);
 }
 
@@ -597,7 +620,7 @@ static char *timestamp(time_t stamp, char *buf, size_t len)
 
 /**************************************************************/
 
-void *LocalExec(void *dummy)
+void *LocalExec(void *scheduled_run)
 
 { FILE *pp; 
   char line[CF_BUFSIZE],filename[CF_BUFSIZE],*sp;
@@ -614,19 +637,15 @@ pthread_sigmask(SIG_BLOCK,&sigmask,NULL);
 
  
 Verbose("------------------------------------------------------------------\n\n");
-Verbose("  LocalExec at %s\n",ctime(&starttime));
+Verbose("  LocalExec(%sscheduled) at %s\n", scheduled_run ? "" : "not ", ctime(&starttime));
 Verbose("------------------------------------------------------------------\n"); 
 
 /* Need to make sure we have LD_LIBRARY_PATH here or children will die  */
 
-if (NOSPLAY)
-   {
-   snprintf(cmd,CF_BUFSIZE-1,"%s/bin/cfagent -q -Dfrom_cfexecd",CFWORKDIR);
-   }
-else
-   {
-   snprintf(cmd,CF_BUFSIZE-1,"%s/bin/cfagent -Dfrom_cfexecd",CFWORKDIR);
-   }
+snprintf(cmd,CF_BUFSIZE-1,"%s/bin/cfagent%s -Dfrom_cfexecd%s",
+		 CFWORKDIR,
+		 NOSPLAY ? " -q" : "",
+		 scheduled_run ? ":scheduled_run" : "");
  
 timestamp(starttime, line, CF_BUFSIZE);
 
@@ -977,27 +996,16 @@ if (!Dialogue(sd,VBUFF))
    goto mail_err;
    }
 
-if (strlen(MAILFROM) > 0)
-   {
-   sprintf(VBUFF,"MAIL FROM: <%s>\r\n",MAILFROM);
-   Debug("%s",VBUFF);   
-   }
-else
-   {
-   domain[0] = '\0';
-   sscanf(to,"%*[^@]@%.64s",domain);
-   
-   if (strlen(domain) > 0)
-      {
-      sprintf(VBUFF,"MAIL FROM: <cfengine@%s>\r\n",domain);
-      Debug("%s",VBUFF);
-      }
-   else
-      {
-      sprintf(VBUFF,"MAIL FROM: <%s>\r\n",to);
-      Debug("%s",VBUFF);   
-      }
-   }
+ if (strlen(MAILFROM) == 0)
+    {
+    sprintf(VBUFF,"MAIL FROM: <cfengine@%s>\r\n",VFQNAME);
+    Debug("%s",VBUFF);
+    }
+ else
+    {
+    sprintf(VBUFF,"MAIL FROM: <%s>\r\n",MAILFROM);
+    Debug("%s",VBUFF);    
+    }
 
 if (!Dialogue(sd,VBUFF))
    {
@@ -1045,7 +1053,7 @@ sent=send(sd,VBUFF,strlen(VBUFF),0);
     }
  else
     {
-    sprintf(VBUFF,"From: cfengine@%s\r\n",VFQNAME);
+    sprintf(VBUFF,"From: %s\r\n",MAILFROM);
     Debug("%s",VBUFF);    
     }
  
