@@ -52,6 +52,7 @@ int  FileFlag = 0;
 int  TRUSTALL = false;
 enum fileoutputlevels  OUTPUTLEVEL = fopl_normal;
 char OUTPUTDIR[CF_BUFSIZE];
+char INCLUDEFILE[CF_BUFSIZE];
 
 struct Item *VCFRUNCLASSES = NULL;
 struct Item *VCFRUNOPTIONHOSTS = NULL;
@@ -65,14 +66,14 @@ char CFLOCK[CF_BUFSIZE] = "dummy";
 /* Functions internal to cfrun.c                                   */
 /*******************************************************************/
 
-void CheckOptsAndInit  ARGLIST((int argc,char **argv));
-int PollServer ARGLIST((char *host, char *options, int storeinfile));
-void SendClassData ARGLIST((int sd, char *sendbuffer));
-void CheckAccess ARGLIST((char *users));
-void cfrunSyntax ARGLIST((void));
-void ReadCfrunConf ARGLIST((void));
-int ParseHostname ARGLIST((char *hostname, char *new_hostname));
-void FileOutput ARGLIST((FILE *fp, enum fileoutputlevels level, char *message));
+void CheckOptsAndInit  (int argc,char **argv);
+int PollServer (char *host, char *options, int storeinfile);
+void SendClassData (int sd, char *sendbuffer);
+void CheckAccess (char *users);
+void cfrunSyntax (void);
+void ReadCfrunConf (char* cfg_fic);
+int ParseHostname (char *hostname, char *new_hostname);
+void FileOutput (FILE *fp, enum fileoutputlevels level, char *message);
 
 /*******************************************************************/
 /* Level 0 : Main                                                  */
@@ -245,7 +246,7 @@ for (i = 1; i < argc; i++)
        }
     }
 
- ReadCfrunConf(); 
+ ReadCfrunConf(VCFRUNHOSTS); 
  
  GetNameInfo();
 
@@ -424,7 +425,7 @@ if (!gotkey)
       }
    }
  
-if (!RemoteConnect(parsed_host,forceipv4))
+if (!RemoteConnect(parsed_host,forceipv4,SHORT_CFENGINEPORT,STR_CFENGINEPORT))
    {
    CfLog(cferror,"Couldn't open a socket","socket");
    FileOutput(fp, fopl_error, "Couldn't open a socket\n");
@@ -488,7 +489,7 @@ while (true)
 
       close(CONN->sd);
       free(addresses.server);
-      return true;;
+      return true;
       }
 
    if ((sp = strstr(recvbuffer,CFD_TERMINATOR)) != NULL)
@@ -553,8 +554,7 @@ return true;
 /* Level 2                                                          */
 /********************************************************************/
 
-void ReadCfrunConf()
-
+void ReadCfrunConf(char* cfg_fic)
 { char filename[CF_BUFSIZE], *sp;
   char buffer[CF_MAXVARSIZE], options[CF_BUFSIZE], line[CF_BUFSIZE];
   FILE *fp;
@@ -578,7 +578,7 @@ if (!strchr(VCFRUNHOSTS, '/'))
       }
    }
  
-strcat(filename,VCFRUNHOSTS);
+strcat(filename,cfg_fic);
 
 if ((fp = fopen(filename,"r")) == NULL)      /* Open root file */
    {
@@ -603,9 +603,9 @@ while (!feof(fp))
 
    if (strncmp(line,"hostnamekeys",6) == 0)
       {
-      char buf[16];
+      char buf[256];
       buf[0] = '\0';
-      sscanf(line,"hostnamekeys = %295[^# \n]",buf);
+      sscanf(line,"hostnamekeys = %255[^# \n]",buf);
       Verbose("Hostname keys\n");
 
       if (strcmp(buf,"yes") == 0||strcmp(buf,"true") == 0)
@@ -669,6 +669,14 @@ while (!feof(fp))
       continue;
       }
    
+   if (strncmp(line,"include", strlen("include")) == 0)
+      {
+      sscanf(line,"include = %295[^# \n]", INCLUDEFILE);
+      Verbose("cfrun: include = %s\n", INCLUDEFILE);
+      ReadCfrunConf(INCLUDEFILE);
+      continue;
+      }
+   
    if (strncmp(line,"access",6) == 0)
       {
       for (sp = line; (*sp != '=') && (*sp != '\0'); sp++)
@@ -695,6 +703,7 @@ while (!feof(fp))
       {
       continue;
       }
+   
 
 
    if (VCFRUNOPTIONHOSTS != NULL && !IsItemIn(VCFRUNOPTIONHOSTS,buffer))
@@ -888,6 +897,7 @@ void cfrunSyntax()
  printf("      cfrun -v -- -k -- solaris  Local verbose, all solaris, but no copy\n\n");
  printf("cfrun.hosts file syntax:\n");
  printf("# starts a comment\n");
+ printf("include = [file]\t# External cfrun.hosts file to include.\n");
  printf("domain = [domain]\t# Domain to use for connection(s).\n");
  printf("maxchild = [num]\t# Maximum number of children to spawn during run.\n");
  printf("outputdir = [dir]\t# Directory where to put host output files.\n");
@@ -898,37 +908,6 @@ void cfrunSyntax()
  exit(0);
 }
 
-/*********************************************************************/
-
-struct cfagent_connection *NewAgentConn()
-
-{ struct cfagent_connection *ap = (struct cfagent_connection *)malloc(sizeof(struct cfagent_connection));
-
-ap->sd = CF_NOT_CONNECTED;
-ap->family = AF_INET; 
-ap->trust = false;
-ap->localip[0] = '\0';
-ap->remoteip[0] = '\0';
-ap->session_key = NULL;
-return ap;
-};
-
-/*********************************************************************/
-
-void DeleteAgentConn(ap)
-
-struct cfagent_connection *ap;
-
-{
-if (ap->session_key != NULL)
-   {
-   free(ap->session_key);
-   }
-
-free(ap);
-ap = NULL; 
-}
-
 /***************************************************************/
 /* Linking simplification                                      */
 /***************************************************************/
