@@ -33,6 +33,7 @@
 #include "cf.extern.h"
 #include "cfservd.h"
 #include <db.h>
+#include <sys/time.h>
 
 /*******************************************************************/
 /* Pthreads                                                        */
@@ -66,6 +67,7 @@ int MULTIPLECONNS = false;
 int TRIES = 0;
 int MAXTRIES = 5;
 int LOGCONNS = false;
+int LOGENCRYPT = false;
 
 struct option CFDOPTIONS[] =
    {
@@ -75,7 +77,6 @@ struct option CFDOPTIONS[] =
    { "file",required_argument,0,'f' },
    { "no-fork",no_argument,0,'F' },
    { "parse-only",no_argument,0,'p'},
-   { "multithread",no_argument,0,'m'},
    { "ld-library-path",required_argument,0,'L'},
    { NULL,0,0,0 }
    };
@@ -88,50 +89,50 @@ struct Item *CONNECTIONLIST = NULL;
 /* Functions internal to cfservd.c                                 */
 /*******************************************************************/
 
-void CheckOptsAndInit ARGLIST((int argc,char **argv));
-void CheckVariables ARGLIST((void));
-void SummarizeParsing ARGLIST((void));
-void StartServer ARGLIST((int argc, char **argv));
-int OpenReceiverChannel ARGLIST((void));
-void Syntax ARGLIST((void));
-void PurgeOldConnections ARGLIST((struct Item **list,time_t now));
-void SpawnConnection ARGLIST((int sd_reply, char *ipaddr));
-void CheckFileChanges ARGLIST((int argc, char **argv, int sd));
-void *HandleConnection ARGLIST((struct cfd_connection *conn));
-int BusyWithConnection ARGLIST((struct cfd_connection *conn));
-void *ExitCleanly ARGLIST((int signum));
-int MatchClasses ARGLIST((struct cfd_connection *conn));
-void DoExec ARGLIST((struct cfd_connection *conn, char *sendbuffer, char *args));
-int GetCommand ARGLIST((char *str));
-int VerifyConnection ARGLIST((struct cfd_connection *conn, char *buf));
-void RefuseAccess ARGLIST((struct cfd_connection *conn, char *sendbuffer, int size, char *errormsg));
-int AccessControl ARGLIST((char *filename, struct cfd_connection *conn, int encrypt));
-int CheckStoreKey  ARGLIST((struct cfd_connection *conn, RSA *key));
-int StatFile ARGLIST((struct cfd_connection *conn, char *sendbuffer, char *filename));
-void CfGetFile ARGLIST((struct cfd_get_arg *args));
-void CompareLocalChecksum ARGLIST((struct cfd_connection *conn, char *sendbuffer, char *recvbuffer));
-int CfOpenDirectory ARGLIST((struct cfd_connection *conn, char *sendbuffer, char *dirname));
-void Terminate ARGLIST((int sd));
-void DeleteAuthList ARGLIST((struct Auth *ap));
-int AllowedUser ARGLIST((char *user));
-void ReplyNothing ARGLIST((struct cfd_connection *conn));
-struct cfd_connection *NewConn ARGLIST((int sd));
-void DeleteConn ARGLIST((struct cfd_connection *conn));
-time_t SecondsTillAuto ARGLIST((void));
-void SetAuto ARGLIST((int seconds));
-int cfscanf ARGLIST((char *in, int len1, int len2, char *out1, char *out2, char *out3));
-int AuthenticationDialogue ARGLIST((struct cfd_connection *conn,char *buffer, int buffersize));
-char *MapAddress ARGLIST((char *addr));
-int IsWildKnownHost ARGLIST((RSA *oldkey,RSA *newkey,char *addr,char *user));
-void AddToKeyDB ARGLIST((RSA *key,char *addr));
-int SafeOpen ARGLIST((char *filename));
-void SafeClose ARGLIST((int fd));
+void CheckOptsAndInit (int argc,char **argv);
+void CheckVariables (void);
+void SummarizeParsing (void);
+void StartServer (int argc, char **argv);
+int OpenReceiverChannel (void);
+void Syntax (void);
+void PurgeOldConnections (struct Item **list,time_t now);
+void SpawnConnection (int sd_reply, char *ipaddr);
+void CheckFileChanges (int argc, char **argv, int sd);
+void *HandleConnection (struct cfd_connection *conn);
+int BusyWithConnection (struct cfd_connection *conn);
+void *ExitCleanly (int signum);
+int MatchClasses (struct cfd_connection *conn);
+void DoExec (struct cfd_connection *conn, char *sendbuffer, char *args);
+int GetCommand (char *str);
+int VerifyConnection (struct cfd_connection *conn, char *buf);
+void RefuseAccess (struct cfd_connection *conn, char *sendbuffer, int size, char *errormsg);
+int AccessControl (char *filename, struct cfd_connection *conn, int encrypt);
+int CheckStoreKey  (struct cfd_connection *conn, RSA *key);
+int StatFile (struct cfd_connection *conn, char *sendbuffer, char *filename);
+void CfGetFile (struct cfd_get_arg *args);
+void CompareLocalChecksum (struct cfd_connection *conn, char *sendbuffer, char *recvbuffer);
+int CfOpenDirectory (struct cfd_connection *conn, char *sendbuffer, char *dirname);
+void Terminate (int sd);
+void DeleteAuthList (struct Auth *ap);
+int AllowedUser (char *user);
+void ReplyNothing (struct cfd_connection *conn);
+struct cfd_connection *NewConn (int sd);
+void DeleteConn (struct cfd_connection *conn);
+time_t SecondsTillAuto (void);
+void SetAuto (int seconds);
+int cfscanf (char *in, int len1, int len2, char *out1, char *out2, char *out3);
+int AuthenticationDialogue (struct cfd_connection *conn,char *buffer, int buffersize);
+char *MapAddress (char *addr);
+int IsWildKnownHost (RSA *oldkey,RSA *newkey,char *addr,char *user);
+void AddToKeyDB (RSA *key,char *addr);
+int SafeOpen (char *filename);
+void SafeClose (int fd);
 
 /*
  * HvB
 */
 
-unsigned find_inet_addr ARGLIST((char *host));
+unsigned find_inet_addr (char *host);
 
 /*******************************************************************/
 /* Level 0 : Main                                                  */
@@ -142,9 +143,12 @@ int main (int argc,char **argv)
 {
 CheckOptsAndInit(argc,argv);
 ParseInputFile(VINPUTFILE);
+
 /* We call CfOpenLog again so, if we configure SyslogFacility, 
    we open syslog again */
+closelog();
 CfOpenLog();
+
 CheckVariables();
 SummarizeParsing();
 
@@ -237,10 +241,10 @@ while ((c=getopt_long(argc,argv,"L:d:f:vmhpFV",CFDOPTIONS,&optindex)) != EOF)
          break;
 
       case 'L': Verbose("Setting LD_LIBRARY_PATH=%s\n",optarg);
-         snprintf(ld_library_path,CF_BUFSIZE-1,"LD_LIBRARY_PATH=%s",optarg);
-             putenv(ld_library_path);
-  break;
-   
+          snprintf(ld_library_path,CF_BUFSIZE-1,"LD_LIBRARY_PATH=%s",optarg);
+          putenv(ld_library_path);
+          break;
+          
       case 'm': /* No longer needed */
          break;
 
@@ -348,6 +352,11 @@ if (OptionIs(CONTEXTID,"LogAllConnections", true))
    LOGCONNS = true;
    }
 
+if (OptionIs(CONTEXTID,"LogEncryptedTransfers", true)) 
+   {
+   LOGENCRYPT = true;
+   }
+
 if (GetMacroValue(CONTEXTID,"ChecksumDatabase"))
    {
    ExpandVarstring("$(ChecksumDatabase)",ebuff,NULL);
@@ -389,7 +398,7 @@ if (GetMacroValue(CONTEXTID,"MaxConnections"))
    
    MAXTRIES = CFD_MAXPROCESSES / 3;  /* How many attempted connections over max
             before we commit suicide? */
-   if ((CFD_MAXPROCESSES < 1) || (CFD_MAXPROCESSES > 1000))
+   if ((CFD_MAXPROCESSES < 1) || (CFD_MAXPROCESSES > 10000))
       {
       FatalError("cfservd MaxConnections with silly value");
       }
@@ -413,7 +422,9 @@ if (OptionIs(CONTEXTID,"ChecksumUpdates", false))
  
 i = 0;
 
-if (StrStr(VSYSNAME.nodename,ToLowerStr(VDOMAIN)))
+strncpy(ebuff,ToLowerStr(VDOMAIN),127);
+
+if (StrStr(VSYSNAME.nodename,ebuff))
    {
    strncpy(VFQNAME,VSYSNAME.nodename,CF_MAXVARSIZE-1);
    
@@ -462,42 +473,42 @@ if (DEBUG || D2 || D3)
       printf("Path: %s (encrypt=%d)\n",ptr->path,ptr->encrypt);
 
       for (ip = ptr->accesslist; ip != NULL; ip=ip->next)
-  {
-  printf("   Admit: %s root=",ip->name);
-  for (ipr = ptr->maproot; ipr !=NULL; ipr=ipr->next)
-     {
-     printf("%s,",ipr->name);
-     }
-  printf("\n");
-  }
+         {
+         printf("   Admit: %s root=",ip->name);
+         for (ipr = ptr->maproot; ipr !=NULL; ipr=ipr->next)
+            {
+            printf("%s,",ipr->name);
+            }
+         printf("\n");
+         }
       }
-
+   
    printf("ACCESS DENIAL ------------------------ :\n\n");
-
+   
    for (ptr = VDENY; ptr != NULL; ptr=ptr->next)
       {
       printf("Path: %s\n",ptr->path);
-
+      
       for (ip = ptr->accesslist; ip != NULL; ip=ip->next)
-  {
-  printf("   Deny: %s\n",ip->name);
-  }      
+         {
+         printf("   Deny: %s\n",ip->name);
+         }      
       }
    
    printf("Host IPs allowed connection access :\n\n");
-
+   
    for (ip = NONATTACKERLIST; ip != NULL; ip=ip->next)
       {
       printf("IP: %s\n",ip->name);
       }
-
+   
    printf("Host IPs denied connection access :\n\n");
-
+   
    for (ip = ATTACKERLIST; ip != NULL; ip=ip->next)
       {
       printf("IP: %s\n",ip->name);
       }
-
+   
    printf("Host IPs allowed multiple connection access :\n\n");
 
    for (ip = MULTICONNLIST; ip != NULL; ip=ip->next)
@@ -544,6 +555,8 @@ void StartServer(int argc,char **argv)
   int sd,sd_reply,ageing;
   fd_set rset;
   time_t now;
+  struct timeval timeout;
+  int ret_val;
 
 #if defined(HAVE_GETADDRINFO) && !defined(DARWIN)
   int addrlen=sizeof(struct sockaddr_in6);
@@ -579,6 +592,7 @@ if ((!NO_FORK) && (fork() != 0))
    {
    snprintf(OUTPUT,CF_BUFSIZE*2,"cfservd starting %.24s\n",ctime(&CFDSTARTTIME));
    CfLog(cfinform,OUTPUT,"");
+   closelog();
    exit(0);
    }
 
@@ -586,7 +600,8 @@ if (!NO_FORK)
    {
    ActAsDaemon(sd);
    }
- 
+
+WritePID("cfservd.pid");
 ageing = 0;
 
 /* Andrew Stribblehill <ads@debian.org> -- close sd on exec */ 
@@ -601,8 +616,13 @@ while (true)
    
    FD_ZERO(&rset);
    FD_SET(sd,&rset);
+   
+   timeout.tv_sec = 10;  /* Set a 10 second timeout for select */
+   timeout.tv_usec = 0;
+   
+   ret_val = select((sd+1),&rset,NULL,NULL,&timeout);
 
-   if (select((sd+1),&rset,NULL,NULL,NULL) == -1)
+   if (ret_val == -1)   /* Error received from call to select */
       {
       if (errno == EINTR)
          {
@@ -614,6 +634,10 @@ while (true)
          exit(1);
          }
       }
+   else if (!ret_val)   /* No data waiting, we must have timed out! */
+      {
+      continue;
+      }
    
    if ((sd_reply = accept(sd,(struct sockaddr *)&cin,&addrlen)) != -1)
       {
@@ -687,7 +711,6 @@ while (true)
       return;
       }
 #endif
-
       
       SpawnConnection(sd_reply,ipaddr);
       }
@@ -1032,7 +1055,7 @@ if (stat(filename,&newstat) == -1)
    return;
    }
 
-Debug("Checking file updates on %s (%x/%x)\n",filename, newstat.st_ctime, CFDSTARTTIME);
+Debug("Checking file updates on %s (%x/%x)\n",filename, newstat.st_mtime, CFDSTARTTIME);
 
 if (CFDSTARTTIME < newstat.st_mtime)
    {
@@ -1044,14 +1067,29 @@ if (CFDSTARTTIME < newstat.st_mtime)
    DeleteItemList(VHEAP);
    DeleteItemList(VNEGHEAP);
    DeleteItemList(TRUSTKEYLIST);
+   DeleteItemList(VIMPORT);
+   DeleteItemList(SKIPVERIFY);
+   DeleteItemList(DHCPLIST);
+   DeleteItemList(ATTACKERLIST);
+   DeleteItemList(NONATTACKERLIST);
+   DeleteItemList(MULTICONNLIST);
    DeleteAuthList(VADMIT);
    DeleteAuthList(VDENY);
+
    strcpy(VDOMAIN,"undefined.domain");
 
    VADMIT = VADMITTOP = NULL;
    VDENY  = VDENYTOP  = NULL;
    VHEAP  = VNEGHEAP  = NULL;
+   VIMPORT = NULL;
    TRUSTKEYLIST = NULL;
+   SKIPVERIFY = NULL;
+   DHCPLIST = NULL;
+   ATTACKERLIST = NULL;
+   NONATTACKERLIST = NULL;
+   MULTICONNLIST = NULL;
+
+   BlankHashTable("server");
 
    AddClassToHeap("any");
    GetNameInfo();
@@ -1169,13 +1207,13 @@ int BusyWithConnection(struct cfd_connection *conn)
   /* and extract the information from the message */
 
 { time_t tloc, trem = 0;
-  char recvbuffer[CF_BUFSIZE+128], sendbuffer[CF_BUFSIZE],check[CF_BUFSIZE];  
+  char recvbuffer[CF_BUFSIZE+CF_BUFEXT], sendbuffer[CF_BUFSIZE],check[CF_BUFSIZE];  
   char filename[CF_BUFSIZE],buffer[CF_BUFSIZE],args[CF_BUFSIZE],out[CF_BUFSIZE];
   long time_no_see = 0;
   int len=0, drift, plainlen, received;
   struct cfd_get_arg get_args;
 
-memset(recvbuffer,0,CF_BUFSIZE+128);
+memset(recvbuffer,0,CF_BUFSIZE+CF_BUFEXT);
 memset(&get_args,0,sizeof(get_args));
 
 if ((received = ReceiveTransaction(conn->sd_reply,recvbuffer,NULL)) == -1)
@@ -1512,6 +1550,7 @@ for (i = 0; i < MAXTHREAD ; i++)
 #endif 
  
 HandleSignal(signum);
+unlink(PIDFILE);
 return NULL;
 }
 
@@ -1585,7 +1624,7 @@ while (true && (count < 10))  /* arbitrary check to avoid infinite loop, DoS att
 void DoExec(struct cfd_connection *conn,char *sendbuffer,char *args)
 
 { char ebuff[CF_EXPANDSIZE], line[CF_BUFSIZE], *sp;
-  int print = false,i;
+  int print = false,i, opt=false;
   FILE *pp;
 
 if ((CFSTARTTIME = time((time_t *)NULL)) == -1)
@@ -1623,6 +1662,36 @@ for (sp = args; *sp != '\0'; sp++) /* Blank out -K -f */
          }
       }
    }
+
+for (sp = args; *sp != '\0'; sp++) /* Blank out -f */
+   { 
+
+   if (strncmp(sp,"-D",2) == 0)
+      {
+      opt = false;
+      sp+=2;
+      }
+
+   if (strncmp(sp,"--define",8) == 0)
+      {
+      opt = false;
+      sp+=8;
+      }
+
+   switch (*sp)
+      {
+      case '-': opt = true;
+          break;
+      case ' ': opt = false;
+          break;
+      case 'f': if (opt)
+                   {
+                   *sp = 'q'; /* Replace with non-empty char which is defined anyway */
+                   }
+          break;
+      }
+   
+   }
     
 ExpandVarstring("$(cfrunCommand) --no-splay --inform",ebuff,"");
  
@@ -1794,6 +1863,13 @@ if (strlen(dns_assert) == 0)
    return false;
    }
 
+if (strcmp(dns_assert,"skipident") == 0)
+   {
+   Verbose("DNS asserted name was withheld before key exchange - untrustworthy connection\n");
+   return false;   
+   }
+
+
 Verbose("Socket caller address appears honest (%s matches %s)\n",ip_assert,MapAddress(conn->ipaddr));
  
 snprintf(conn->output,CF_BUFSIZE,"Socket originates from %s=%s\n",ip_assert,dns_assert);
@@ -1978,40 +2054,46 @@ int AccessControl(char *filename,struct cfd_connection *conn,int encrypt)
 
 { struct Auth *ap;
   int access = false;
-  char realname[CF_BUFSIZE];
+  char realname[CF_BUFSIZE],path[CF_BUFSIZE],lastnode[CF_BUFSIZE];
   struct stat statbuf;
 
 Debug("AccessControl(%s)\n",filename);
 memset(realname,0,CF_BUFSIZE);
 
-if (lstat(filename,&statbuf) == -1)
+/* Separate path first, else this breaks for lastnode = symlink */
+
+strncpy(path,filename,CF_BUFSIZE-1);
+strncpy(lastnode,ReadLastNode(filename),CF_BUFSIZE-1);
+ChopLastNode(path);
+
+/* Eliminate links from path */
+
+#ifdef HAVE_REALPATH
+if (realpath(path,realname) == NULL)
    {
-   snprintf(conn->output,CF_BUFSIZE*2,"Couldn't stat filename %s from host %s\n",filename,conn->hostname);
+   snprintf(conn->output,CF_BUFSIZE*2,"Couldn't resolve filename %s from host %s\n",filename,conn->hostname);
+   CfLog(cfverbose,conn->output,"lstat");
+   CfLog(cflogonly,conn->output,"lstat");   
+   return false;
+   }
+#else
+CompressPath(realname,path); /* in links.c */
+#endif
+
+/* Rejoin the last node and stat the real thing */
+
+AddSlash(realname);
+strcat(realname,lastnode);
+
+if (lstat(realname,&statbuf) == -1)
+   {
+   snprintf(conn->output,CF_BUFSIZE*2,"Couldn't stat filename %s (i.e. %s) from host %s\n",filename,realname,conn->hostname);
    CfLog(cfverbose,conn->output,"lstat");
    CfLog(cflogonly,conn->output,"lstat");   
    return false;
    }
 
-if (S_ISLNK(statbuf.st_mode)) 
-   {
-   strncpy(realname,filename,CF_BUFSIZE);
-   }
- else
-    {
-#ifdef HAVE_REALPATH
-    if (realpath(filename,realname) == NULL)
-       {
-       snprintf(conn->output,CF_BUFSIZE*2,"Couldn't resolve filename %s from host %s\n",filename,conn->hostname);
-       CfLog(cfverbose,conn->output,"lstat");
-       CfLog(cflogonly,conn->output,"lstat");   
-       return false;
-       }
-#else
-    CompressPath(realname,filename); /* in links.c */
-#endif
-    }
- 
-Debug("AccessControl(%s,%s) encrypt request=%d\n",realname,conn->hostname,encrypt);
+Debug("AccessControl, match(%s,%s) encrypt request=%d\n",realname,conn->hostname,encrypt);
  
 if (VADMIT == NULL)
    {
@@ -2038,7 +2120,7 @@ for (ap = VADMIT; ap != NULL; ap=ap->next)
    
    if (res)
       {
-      Debug("Found a matching rule in access list (%s,%s)\n",realname,ap->path);
+      Debug("Found a matching rule in access list (%s in %s)\n",realname,ap->path);
       if (stat(ap->path,&statbuf) == -1)
          {
          snprintf(OUTPUT,CF_BUFSIZE,"Warning cannot stat file object %s in admit/grant, or access list refers to dangling link\n",ap->path);
@@ -2100,15 +2182,20 @@ for (ap = VADMIT; ap != NULL; ap=ap->next)
     {
     snprintf(conn->output,CF_BUFSIZE*2,"Host %s granted access to %s\n",conn->hostname,realname);
     CfLog(cfverbose,conn->output,"");
+    
+    if (encrypt && LOGENCRYPT)
+       {
+       /* Log files that were marked as requiring encryption */
+       CfLog(cfloginform,conn->output,"");
+       }
     }
  else
     {
     snprintf(conn->output,CF_BUFSIZE*2,"Host %s denied access to %s\n",conn->hostname,realname);
     CfLog(cfverbose,conn->output,"");
-    CfLog(cflogonly,conn->output,"");
+    CfLog(cfloginform,conn->output,"");
     }
  
- 
  if (!conn->rsa_auth)
     {
     CfLog(cfverbose,"Cannot map root access without RSA authentication","");
@@ -2126,8 +2213,9 @@ int AuthenticationDialogue(struct cfd_connection *conn,char *recvbuffer, int rec
 { char in[CF_BUFSIZE],*out, *decrypted_nonce;
   BIGNUM *counter_challenge = NULL;
   unsigned char digest[EVP_MAX_MD_SIZE+1];
-  unsigned int crypt_len, nonce_len = 0,len = 0, encrypted_len = 0, keylen;
+  unsigned int crypt_len, nonce_len = 0,encrypted_len = 0;
   char sauth[10], iscrypt ='n';
+  int len = 0,keylen;
   unsigned long err;
   RSA *newkey;
 
@@ -2392,6 +2480,9 @@ memset(in,0,CF_BUFSIZE);
 
 if (ReceiveTransaction(conn->sd_reply,in,NULL) == -1)
    {
+   BN_free(counter_challenge);
+   free(out);
+   RSA_free(newkey);   
    return false;
    }
  
@@ -2425,11 +2516,17 @@ memset(in,0,CF_BUFSIZE);
 
 if ((keylen = ReceiveTransaction(conn->sd_reply,in,NULL)) == -1)
    {
+   BN_free(counter_challenge);
+   free(out);
+   RSA_free(newkey); 
    return false;
    }
 
 if (keylen > CF_BUFSIZE/2)
    {
+   BN_free(counter_challenge);
+   free(out);
+   RSA_free(newkey); 
    snprintf(conn->output,CF_BUFSIZE,"Session key length received from %s is too long",conn->ipaddr);
    CfLog(cfinform,conn->output,"");
    return false;
@@ -2451,10 +2548,12 @@ conn->session_key = malloc(CF_BLOWFISHSIZE);
 
 if (conn->session_key == NULL)
    {
+   BN_free(counter_challenge);
+   free(out);
+   RSA_free(newkey); 
    return false;
    }
 
-
 if (keylen == CF_BLOWFISHSIZE) /* Old, non-encrypted */
    {
    memcpy(conn->session_key,in,CF_BLOWFISHSIZE);
@@ -2474,8 +2573,6 @@ else /* New encrypted */
       
       snprintf(conn->output,CF_BUFSIZE,"Private decrypt failed = %s\n",ERR_reason_error_string(err));
       CfLog(cferror,conn->output,"");
-      free(conn->session_key);
-      conn->session_key = NULL;
       return false;
       }
    
@@ -2512,6 +2609,7 @@ int StatFile(struct cfd_connection *conn,char *sendbuffer,char *filename)
 { struct cfstat cfst;
   struct stat statbuf;
   char linkbuf[CF_BUFSIZE];
+  int islink = false;
 
   Debug("StatFile(%s)\n",filename);
 
@@ -2541,6 +2639,7 @@ memset(linkbuf,0,CF_BUFSIZE);
 
 if (S_ISLNK(statbuf.st_mode))
    {
+   islink = true;
    cfst.cf_type = cf_link;                   /* pointless - overwritten */
    cfst.cf_lmode = statbuf.st_mode & 07777;
    cfst.cf_nlink = statbuf.st_nlink;
@@ -2558,7 +2657,7 @@ if (S_ISLNK(statbuf.st_mode))
    cfst.cf_readlink = linkbuf;
    }
 
-if (stat(filename,&statbuf) == -1)
+if (!islink && (stat(filename,&statbuf) == -1))
    {
    snprintf(sendbuffer,CF_BUFSIZE,"BAD: unable to stat file %s\n",filename);
    CfLog(cfverbose,conn->output,"stat");
@@ -2646,7 +2745,7 @@ snprintf(sendbuffer,CF_BUFSIZE,"OK: %d %d %d %d %d %ld %d %d %d %d %d %d %d",
 
 SendTransaction(conn->sd_reply,sendbuffer,0,CF_DONE);
 
- memset(sendbuffer,0,CF_BUFSIZE);
+memset(sendbuffer,0,CF_BUFSIZE);
 
 if (cfst.cf_readlink != NULL)
    {
@@ -2705,7 +2804,7 @@ if (uid != 0 && !args->connect->maproot) /* should remote root be local root */
       }
    }
  
- if (args->buf_size < 512)
+ if (args->buf_size < SMALL_BLOCK_BUF_SIZE)
     {
     snprintf(args->connect->output,CF_BUFSIZE,"blocksize for %s was only %d\n",filename,args->buf_size);
     CfLog(cferror,args->connect->output,"");
@@ -2990,7 +3089,7 @@ else
    }
  
 snprintf(sendbuffer,CF_BUFSIZE,"%s",CF_FAILEDSTR);
-CfLog(cfinform,"Host authorization/authentication failed or access denied\n","");
+CfLog(cfinform,"Unspecified refusal by server\n","");
 SendTransaction(conn->sd_reply,sendbuffer,size,CF_DONE);
 snprintf(sendbuffer,CF_BUFSIZE,"From (host=%s,user=%s,ip=%s)",hostname,username,ipaddr);
 CfLog(cfinform,sendbuffer,"");
@@ -2998,7 +3097,7 @@ CfLog(cfinform,sendbuffer,"");
 if (strlen(errmesg) > 0)
    {
    snprintf(OUTPUT,CF_BUFSIZE,"ID from connecting host: (%s)",errmesg);
-   CfLog(cflogonly,OUTPUT,"");
+   CfLog(cfloginform,OUTPUT,"");
    }
 }
 
@@ -3189,6 +3288,8 @@ if ((errno = dbp->get(dbp,NULL,&key,&value,0)) != 0)
          {
          dbp->err(dbp,errno,NULL);
          }
+
+      DeletePublicKey(keyname);
       }
    else
       {
@@ -3319,6 +3420,11 @@ void DeleteConn(struct cfd_connection *conn) /* destruct */
 Debug("***Closing socket %d from %s\n",conn->sd_reply,conn->ipaddr);
 
 close(conn->sd_reply);
+
+if (conn->session_key != NULL)
+   {
+   free(conn->session_key);
+   }
  
 if (conn->ipaddr != NULL)
    {
@@ -3450,6 +3556,10 @@ struct Method *IsDefinedMethod(char *name,char *s)
 {
 return NULL; 
 }
+
+void CheckForMethod()
+{
+}
 /* EOF */
 
 
