@@ -54,7 +54,7 @@ if (CONN->sd == CF_NOT_CONNECTED)
    {   
    Debug("Opening server connnection to %s\n",server);
 
-   if (!RemoteConnect(server,ip->forceipv4))
+   if (!RemoteConnect(server,ip->forceipv4,SHORT_CFENGINEPORT,STR_CFENGINEPORT))
       {
       CfLog(cfinform,"Couldn't open a socket","socket");
       if (CONN->sd != CF_NOT_CONNECTED)
@@ -137,7 +137,7 @@ int cf_rstat(char *file,struct stat *buf,struct Image *ip,char *stattype)
   int ret,tosend,cipherlen;
   time_t tloc;
 
-Debug("cf_rstat(%s)\n",file);
+  Debug("cf_rstat(%s,%s)\n",file,stattype);
 memset(recvbuffer,0,CF_BUFSIZE); 
 
 if (strlen(file) > CF_BUFSIZE-30)
@@ -353,6 +353,7 @@ snprintf(sendbuffer,CF_BUFSIZE,"OPENDIR %s",dirname);
 
 if (SendTransaction(CONN->sd,sendbuffer,0,CF_DONE) == -1)
    {
+   free((char *)cfdirh);
    return NULL;
    }
 
@@ -364,7 +365,9 @@ while (!done)
          {
          continue;
          }
-      return false;
+
+      free((char *)cfdirh);
+      return NULL;
       }
 
    if (n == 0)
@@ -376,19 +379,23 @@ while (!done)
       {
       snprintf(OUTPUT,CF_BUFSIZE*2,"Network access to %s:%s denied\n",ip->server,dirname);
       CfLog(cfinform,OUTPUT,"");
-      return false;      
+
+      free((char *)cfdirh);
+      return NULL;      
       }
 
    if (BadProtoReply(recvbuffer))
       {
       snprintf(OUTPUT,CF_BUFSIZE*2,"%s\n",recvbuffer+4);
       CfLog(cfinform,OUTPUT,"");
-      return false;      
+
+      free((char *)cfdirh);
+      return NULL;      
       }
 
    for (sp = recvbuffer; *sp != '\0'; sp++)
       {
-      if (strncmp(sp,CFD_TERMINATOR,strlen(CFD_TERMINATOR)) == 0)        /* End transmission */
+      if (strncmp(sp,CFD_TERMINATOR,strlen(CFD_TERMINATOR)) == 0)    /* End transmission */
          {
          cfdirh->cf_listpos = cfdirh->cf_list;
          return cfdirh;
@@ -844,41 +851,5 @@ for (i = 0; i < toget; i++)
    }
 }
 
-/*********************************************************************/
-
-struct cfagent_connection *NewAgentConn()
-
-{ struct cfagent_connection *ap;
-
-if ((ap = (struct cfagent_connection *)malloc(sizeof(struct cfagent_connection))) == NULL)
-   {
-   return NULL;
-   }
-
-Debug("New server connection...\n");
-ap->sd = CF_NOT_CONNECTED;
-ap->family = AF_INET; 
-ap->trust = false;
-ap->localip[0] = '\0';
-ap->remoteip[0] = '\0';
-ap->session_key = NULL;
-ap->error = false; 
-return ap;
-};
-
-/*********************************************************************/
-
-void DeleteAgentConn(struct cfagent_connection *ap)
-
-{
-if (ap->session_key != NULL)
-   {
-   free(ap->session_key);
-   }
-
-free(ap);
-ap = NULL; 
-}
-
 
 
