@@ -75,20 +75,20 @@ for (ip = VMOUNTLIST; ip != NULL; ip=ip->next)
          {
          continue;
          }
-
+      
       strcpy(VBUFF,ip->name);
       AddSlash(VBUFF);
       strcat(VBUFF,dirp->d_name);
-
+      
       if (IsHomeDir(VBUFF))
          {
          snprintf(OUTPUT,CF_BUFSIZE*2,"Host defines a home directory %s\n",VBUFF);
-  CfLog(cfverbose,OUTPUT,"");
+         CfLog(cfverbose,OUTPUT,"");
          }
       else
          {
          snprintf(OUTPUT,CF_BUFSIZE*2,"Host defines a potential mount point %s\n",VBUFF);
-  CfLog(cfverbose,OUTPUT,"");
+         CfLog(cfverbose,OUTPUT,"");
          }
 
       snprintf(path,CF_BUFSIZE,"%s%s",ip->name,dirp->d_name);
@@ -99,7 +99,7 @@ for (ip = VMOUNTLIST; ip != NULL; ip=ip->next)
          if ( MOUNTCHECK && ! RequiredFileSystemOkay(path) && VERBOSE)
             {
             snprintf(OUTPUT,CF_BUFSIZE*2,"Found a mountpoint %s but there was\n",path);
-     CfLog(cfinform,OUTPUT,"");
+            CfLog(cfinform,OUTPUT,"");
             CfLog(cfinform,"nothing mounted on it.\n\n","");
             }
          }
@@ -283,8 +283,8 @@ do
       case cfsco: CfLog(cferror,"Don't understand SCO mount format, no data","");
 
       default:
-                    printf("cfengine software error: case %d = %s\n",VSYSTEMHARDCLASS,CLASSTEXT[VSYSTEMHARDCLASS]);
-                    FatalError("System error in GetMountInfo - no such class!");
+          printf("cfengine software error: case %d = %s\n",VSYSTEMHARDCLASS,CLASSTEXT[VSYSTEMHARDCLASS]);
+          FatalError("System error in GetMountInfo - no such class!");
       }
 
    InstallMountedItem(host,mounton);
@@ -407,6 +407,7 @@ for (lp = VCHLINK; lp != NULL; lp = lp->next)
 
    if (!GetLock(ASUniqueName("link"),CanonifyName(VBUFF),lp->ifelapsed,lp->expireafter,VUQNAME,CFSTARTTIME))
       {
+      lp->done = 'y';
       continue;
       }
 
@@ -432,8 +433,8 @@ for (lp = VCHLINK; lp != NULL; lp = lp->next)
          if (stat(from,&statbuf) == -1)
             {
             snprintf(OUTPUT,CF_BUFSIZE*2,"Makechildlinks() can't stat %s\n",from);
-     CfLog(cferror,OUTPUT,"stat");
-     ResetOutputRoute('d','d');
+            CfLog(cferror,OUTPUT,"stat");
+            ResetOutputRoute('d','d');
             continue;
             }
          LinkChildren(from,lp->type,&statbuf,0,0,lp->inclusions,lp->exclusions,lp->copy,lp->nofile,lp);
@@ -489,7 +490,7 @@ void MakeLinks()     /* <binserver> should expand to a best fit filesys */
   int matched,varstring;
   short saveenforce;
   short savesilent;
-  int (*linkfiles) ARGLIST((char *from, char *to, struct Item *inclusions, struct Item *exclusions, struct Item *copy, short int nofile, struct Link *ptr));
+  int (*linkfiles)(char *from, char *to, struct Item *inclusions, struct Item *exclusions, struct Item *copy, short int nofile, struct Link *ptr);
 
 if (NOLINKS)
    {
@@ -518,6 +519,7 @@ for (lp = VLINK; lp != NULL; lp = lp->next)
    
    if (!GetLock(ASUniqueName("link"),CanonifyName(VBUFF),lp->ifelapsed,lp->expireafter,VUQNAME,CFSTARTTIME))
       {
+      lp->done = 'y';
       continue;
       }
 
@@ -554,7 +556,7 @@ for (lp = VLINK; lp != NULL; lp = lp->next)
 
    matched = varstring = false;
 
-   for( ip = VBINSERVERS; ip != NULL && (!matched); ip = ip->next)
+   for(ip = VBINSERVERS; ip != NULL && (!matched); ip = ip->next)
       {
       path[0] = '\0';
 
@@ -567,7 +569,7 @@ for (lp = VLINK; lp != NULL; lp = lp->next)
       else if (! varstring)
          {
          snprintf(OUTPUT,CF_BUFSIZE*2,"Error while trying to link %s -> %s\n",from,path);
-  CfLog(cfinform,OUTPUT,"");
+         CfLog(cfinform,OUTPUT,"");
          }
 
       if (! varstring)                       /* don't iterate over binservers if not var */
@@ -922,6 +924,7 @@ for (rp = VREQUIRED; rp != NULL; rp = rp->next)
    
    if (!GetLock(ASUniqueName("disks"),rp->name,rp->ifelapsed,rp->expireafter,VUQNAME,CFSTARTTIME))
       {
+      rp->done = 'y';
       continue;
       }
  
@@ -966,12 +969,14 @@ for (rp = VREQUIRED; rp != NULL; rp = rp->next)
       /* HvB : Bas van der Vlies */
       if (!CheckFreeSpace(path,rp))
          {
-         Verbose("Free space below %d, defining %s\n",rp->freespace, rp->define);
+         snprintf(OUTPUT,CF_BUFSIZE,"Free space below %d, defining %s\n",rp->freespace, rp->define);
+         CfLog(cfinform,OUTPUT,"");
          AddMultipleClasses(rp->define);
          }
       else
          {
-         Verbose("Free space above %d, defining %s\n",rp->freespace, rp->elsedef);
+         snprintf(OUTPUT,CF_BUFSIZE,"Free space above %d, defining %s\n",rp->freespace, rp->elsedef);
+         CfLog(cfverbose,OUTPUT,"");
          AddMultipleClasses(rp->elsedef);
          }
       }
@@ -988,7 +993,7 @@ for (rp = VREQUIRED; rp != NULL; rp = rp->next)
 
 if (missing)
    {
-   time_t tloc;;
+   time_t tloc;
 
    if ((tloc = time((time_t *)NULL)) == -1)
       {
@@ -1238,6 +1243,7 @@ for (ptr = VSCRIPT; ptr != NULL; ptr=ptr->next)
    
    if (!GetLock(ASUniqueName("shellcommand"),execstr,ptr->ifelapsed,ptr->expireafter,VUQNAME,CFSTARTTIME))
       {
+      ptr->done = 'y';
       continue;
       }
 
@@ -1614,6 +1620,8 @@ for (dp = VDISABLELIST; dp != NULL; dp=dp->next)
       continue;
       }
 
+   dp->done = 'y';
+
    ExpandVarstring(dp->name,workname,NULL);
    
    ResetOutputRoute(dp->log,dp->inform);
@@ -1868,6 +1876,7 @@ void MountHomeBinServers()
   char host[CF_MAXVARSIZE];
   char mountdir[CF_BUFSIZE];
   char maketo[CF_BUFSIZE];
+  struct Item *ip;
 
   /*
    * HvB: Bas van der Vlies
@@ -1890,6 +1899,8 @@ if (!IsPrivileged())
 
 Banner("Checking home and binservers");
 
+Debug("BINSERVER = %s\n",VDEFAULTBINSERVER.name);
+
 for (mp = VMOUNTABLES; mp != NULL; mp=mp->next)
    {
    sscanf(mp->filesystem,"%[^:]:%s",host,mountdir);
@@ -1916,6 +1927,8 @@ for (mp = VMOUNTABLES; mp != NULL; mp=mp->next)
       strcat(maketo,"/.");
       }
 
+   Debug("I am [%s], you are [%s]\n",host,VDEFAULTBINSERVER.name);
+
    if (strcmp(host,VDEFAULTBINSERVER.name) == 0) /* A host never mounts itself nfs */
       {
       Debug("Skipping host %s\n",host);
@@ -2075,6 +2088,7 @@ for (ptr=VUNMOUNT; ptr != NULL; ptr=ptr->next)
 
    if (!GetLock(ASUniqueName("unmount"),CanonifyName(ptr->name),ptr->ifelapsed,ptr->expireafter,VUQNAME,CFSTARTTIME))
       {
+      ptr->done = 'y';
       continue;
       }
 
@@ -2276,7 +2290,7 @@ void CheckResolv()
 
 Verbose("Checking config in %s\n",VRESOLVCONF[VSYSTEMHARDCLASS]);
   
-if (VDOMAIN == NULL)
+if (strcmp(VDOMAIN,"") == 0)
    {
    CfLog(cferror,"Domain name not specified. Can't configure resolver\n","");
    return;
@@ -2455,12 +2469,13 @@ for (svp = VSERVERLIST; svp != NULL; svp=svp->next) /* order servers */
          continue;
          }
       
-      snprintf(vbuff,CF_BUFSIZE,"%.50s.%.50s_%.50s",path,destination,server); /* Unique ID for copy locking */
+      snprintf(vbuff,CF_BUFSIZE,"%.255s.%.50s_%.50s",path,destination,server); /* Unique ID for copy locking */
       
       if (!GetLock(ASUniqueName("copy"),CanonifyName(vbuff),ip->ifelapsed,ip->expireafter,VUQNAME,CFSTARTTIME))
          {
          SILENT = savesilent;
          ResetOutputRoute('d','d');
+         ip->done = 'y';
          continue;
          }
       
@@ -2530,6 +2545,7 @@ for (ifp = VIFLIST; ifp != NULL; ifp=ifp->next)
    {
    if (!GetLock("netconfig",ifp->ifdev,VIFELAPSED,VEXPIREAFTER,VUQNAME,CFSTARTTIME))
       {
+      ifp->done = 'y';
       continue;
       }
 
@@ -2632,6 +2648,7 @@ for (pp = VPROCLIST; pp != NULL; pp=pp->next)
    
    if (!GetLock(ASUniqueName("processes"),CanonifyName(VBUFF),pp->ifelapsed,pp->expireafter,VUQNAME,CFSTARTTIME))
       {
+      pp->done = 'y';
       continue;
       }
 
@@ -2664,6 +2681,7 @@ void CheckPackages()
 { struct Package *ptr;
   int match = 0;
   int i;
+  char lock[CF_BUFSIZE];
   /* pkgmgr_none will always be the highest number in the enum so set
      the array size with that */
   char *package_install_list[pkgmgr_none] = { NULL };
@@ -2684,8 +2702,11 @@ for (ptr = VPKG; ptr != NULL; ptr=ptr->next)
       continue;
       }
 
-   if (!GetLock(ASUniqueName("packages"),CanonifyName(ptr->name),ptr->ifelapsed,ptr->expireafter,VUQNAME,CFSTARTTIME))
+   snprintf(lock,CF_BUFSIZE-1,"%s_%d_%d",ptr->name,ptr->cmp,ptr->action);
+   
+   if (!GetLock(ASUniqueName("packages"),CanonifyName(lock),ptr->ifelapsed,ptr->expireafter,VUQNAME,CFSTARTTIME))
       {
+      ptr->done = 'y';
       continue;
       }
    
@@ -2798,10 +2819,11 @@ for (ptr = VMETHODS; ptr != NULL; ptr=ptr->next)
       }
 
    ChecksumList(ptr->send_args,digest,'m');
-   snprintf(label,CF_BUFSIZE-1,"%s/rpc_in/localhost_localhost_%s_%s",VLOCKDIR,ptr->name,ChecksumPrint('m',digest));
+   snprintf(label,CF_BUFSIZE-1,"%s/rpc_in/localhost+localhost+%s+%s",VLOCKDIR,ptr->name,ChecksumPrint('m',digest));
 
    if (!GetLock(ASUniqueName("methods-dispatch"),CanonifyName(label),ptr->ifelapsed,ptr->expireafter,VUQNAME,CFSTARTTIME))
       {
+      ptr->done = 'y';
       continue;
       }
    
@@ -3041,7 +3063,6 @@ if (IsItemIn(VMOUNTED,buf))
 
 /*******************************************************************/
 
-
 void AddToFstab(char *host,char *rmountpt,char *mountpt,char *mode,char *options,int ismounted)
 
 { char fstab[CF_BUFSIZE];
