@@ -378,6 +378,7 @@ if (todo == 0)   /* Because classes are stored per edit, not per file */
 
 if (!GetLock(ASUniqueName("editfile"),CanonifyName(filename),VIFELAPSED,VEXPIREAFTER,VUQNAME,CFSTARTTIME))
    {
+   ptr->done = 'y';
    return;
    }
  
@@ -758,7 +759,7 @@ while (ep != NULL)
           
           if (CURRENTLINEPTR == NULL)
              {
-             newlineptr == NULL;
+             newlineptr = NULL;
              }
           else
              {
@@ -804,6 +805,14 @@ while (ep != NULL)
              }
           break;
           
+      case ExpandVariables:
+          if (!ExpandAllVariables(filestart))
+             {
+             printf("Aborting edit of file %s\n",filename);
+             continue;
+             }
+          break;
+          
       case DeleteToLineMatching:
           if (! DeleteToRegExp(&filestart,expdata))
              {
@@ -960,6 +969,28 @@ while (ep != NULL)
              EDITGROUPLEVEL++;
              }
           break;
+
+      case BeginGroupIfMatch:
+          
+          if (CURRENTLINEPTR == NULL || CURRENTLINEPTR->name == NULL )
+             {
+             EditVerbose("(Begin Group - no match for %s - file empty)\n",expdata);
+             break;
+             }
+          
+          if (LineMatches(CURRENTLINEPTR->name,expdata))
+             {
+             EditVerbose("(Begin Group - match for %s)\n",expdata);
+             EDITGROUPLEVEL++;
+             }
+          else
+             {
+             EditVerbose("(Begin Group - skipping %s)\n",expdata);
+             ep = SkipToEndGroup(ep,filename);
+             }
+
+          break;
+
           
       case BeginGroupIfNoLineMatching:
           if (LocateItemMatchingRegExp(filestart,expdata) != 0)
@@ -973,6 +1004,20 @@ while (ep != NULL)
              EDITGROUPLEVEL++;
              }
           break;
+
+      case BeginGroupIfLineMatching:
+          if (LocateItemMatchingRegExp(filestart,expdata) == 0)
+             {
+             EditVerbose("(Begin Group - skipping %s)\n",expdata);
+             ep = SkipToEndGroup(ep,filename);
+             }
+          else
+             {
+             EditVerbose("(Begin Group - line matching %s)\n",expdata);
+             EDITGROUPLEVEL++;
+             }
+          break;
+
           
       case BeginGroupIfNoLineContaining:
           if (LocateNextItemContaining(filestart,expdata) != 0)
@@ -987,6 +1032,19 @@ while (ep != NULL)
              }
           break;
           
+      case BeginGroupIfLineContaining:
+          if (LocateNextItemContaining(filestart,expdata) == 0)
+             {
+             EditVerbose("(Begin Group - skipping, string matched)\n");
+             ep = SkipToEndGroup(ep,filename);
+             }
+          else
+             {
+             EditVerbose("(Begin Group - line containing %s)\n",expdata);
+             EDITGROUPLEVEL++;
+             }
+          break;
+          
       case BeginGroupIfNoSuchLine:
           if (IsItemIn(filestart,expdata))
              {
@@ -1377,6 +1435,41 @@ return true;
 
 /********************************************************************/
 
+int ExpandAllVariables (struct Item *list)
+
+{ char *sp;
+  int i = 1;
+  struct Item *ip;
+
+  for (ip = list; ip != NULL; ip=ip->next, i++)
+    {
+
+    if ((sp = malloc(CF_EXPANDSIZE)) == NULL)
+      {
+      printf("Memory allocation failed in ExpandEditLineVariables, aborting edit.\n");
+      return false;
+      }
+
+    memset( sp, 0, CF_EXPANDSIZE);
+    ExpandVarstring(ip->name,sp,NULL);
+
+    if (strcmp(sp,ip->name) == 0)
+      {
+      EditVerbose("ExpandVariables - no expansions in %10s...\n", sp);
+      continue;
+      }
+
+    EditVerbose("Expanded line %d to %10s...\n",i,sp);
+    free (ip->name);
+    ip->name = sp;
+    NUMBEROFEDITS++;
+  }
+
+return true;
+}
+
+/********************************************************************/
+
 int RunEditScript (char *script,char *fname,struct Item **filestart,struct Edit *ptr)
 
 { FILE *pp;
@@ -1426,11 +1519,13 @@ if (pp == NULL)
 
 while (!feof(pp))   
    {
-   ReadLine(CURRENTITEM,CF_BUFSIZE,pp);
+   char buffer[CF_BUFSIZE];
+   
+   ReadLine(buffer,CF_BUFSIZE-1,pp);
 
    if (!feof(pp))
       {
-      EditVerbose("%s\n",CURRENTITEM);
+      EditVerbose("%s\n",buffer);
       }
    }
 
@@ -1545,20 +1640,39 @@ void CheckEditSwitches(char *filename,struct Edit *ptr)
 
 { struct stat statbuf;
   struct Edlist *ep;
-  char inform = 'd', log = 'd';
+  char inform, log;
   char expdata[CF_EXPANDSIZE];
   int fd;
-struct Edlist *actions = ptr->actions;
+  struct Edlist *actions = ptr->actions;
   
 PARSING = true;
- 
+
+if (INFORM)
+   {
+   inform = 'y';
+   }
+else
+   {
+   inform = 'n';
+   }
+
+if (LOGGING)
+   {
+   log = 'y';
+   }
+else
+   {
+   log = 'n';
+   }
+
+
 for (ep = actions; ep != NULL; ep=ep->next)
    {
    if (IsExcluded(ep->classes))
       {
       continue;
       }
-
+   
    ExpandVarstring(ep->data,expdata,NULL);
    
    switch(ep->code)
@@ -1585,8 +1699,16 @@ for (ep = actions; ep != NULL; ep=ep->next)
                 snprintf(OUTPUT,CF_BUFSIZE*2,"Creating file %s, mode %o\n",filename,(0644 & ~ptr->umask));
                 CfLog(cfinform,OUTPUT,"");
                 umask(mask);
-                return;
-                }    
+                break;
+                }
+             }
+          else
+             {
+             if (stat(filename,&statbuf) == -1)
+                {
+                snprintf(OUTPUT,CF_BUFSIZE*2,"Should create and edit file %s, mode %o\n",filename,(0644 & ~ptr->umask));
+                CfLog(cfinform,OUTPUT,"");
+                }
              }
           
           break;
@@ -1605,8 +1727,7 @@ for (ep = actions; ep != NULL; ep=ep->next)
           if (strcmp("timestamp",ToLowerStr(expdata)) == 0 || strcmp("stamp",ToLowerStr(expdata)) == 0)
              {
              IMAGEBACKUP = 's';
-             }
-          
+             }          
           break;
           
       case EditLog:
@@ -1621,8 +1742,11 @@ for (ep = actions; ep != NULL; ep=ep->next)
              log = 'n';
              break;
              }
+
+          break;
           
       case EditInform:
+
           if (strcmp(ToLowerStr(expdata),"true") == 0 || strcmp(ToLowerStr(expdata),"on") == 0)
              {
              inform = 'y';
@@ -1633,7 +1757,9 @@ for (ep = actions; ep != NULL; ep=ep->next)
              {
              inform = 'n';
              break;
-             }                   
+             }
+
+          break;
       }
    }
 
@@ -1670,7 +1796,7 @@ if (editsdone)
             
             sscanf(sp,"%[^,:.]",currentitem);
             
-            sp += strlen(currentitem);
+            sp += strlen(currentitem) - 1;
             
             AddClassToHeap(currentitem);
             }
@@ -1696,7 +1822,7 @@ if (editsdone)
              
              sscanf(sp,"%[^,:.]",currentitem);
              
-             sp += strlen(currentitem);
+             sp += strlen(currentitem) - 1;
              
              AddClassToHeap(currentitem);
              }
@@ -1735,6 +1861,7 @@ if (!LoadItemList(&infilelist,infile))
       {
       case DeleteLinesStartingFileItems:
           positive = true;
+
       case DeleteLinesNotStartingFileItems:
           matches = 0;
           
@@ -1764,6 +1891,7 @@ if (!LoadItemList(&infilelist,infile))
           
       case DeleteLinesContainingFileItems:
           positive = true;
+
       case DeleteLinesNotContainingFileItems:
           matches = 0;
           
@@ -1865,11 +1993,14 @@ while(ep != NULL)
    {
    switch (ep->code)
       {
+      case BeginGroupIfMatch:
       case BeginGroupIfNoMatch:
       case BeginGroupIfNoLineMatching:
+      case BeginGroupIfLineMatching:
       case BeginGroupIfNoSuchLine:
       case BeginGroupIfFileIsNewer:
       case BeginGroupIfFileExists:
+      case BeginGroupIfLineContaining:
       case BeginGroupIfNoLineContaining:
       case BeginGroupIfDefined:
       case BeginGroupIfNotDefined:
