@@ -375,16 +375,21 @@ return -1;
 void AddClassToHeap(char *class)
 
 {
+Chop(class);
 Debug("AddClassToHeap(%s)\n",class);
 
-/*if (! IsItemIn(VALLADDCLASSES,class))
+if (strlen(class) == 0)
    {
-   snprintf(OUTPUT,CF_BUFSIZE,"Defining class %s -- but it isn't declared installable",class);
-   yyerror(OUTPUT);
-   }*/
+   return;
+   }
+
+if (IsItemIn(ABORTHEAP,class))
+   {
+   snprintf(OUTPUT,CF_BUFSIZE,"Cfagent aborted on defined class [%s]\n",class);
+   CfLog(cferror,OUTPUT,"");
+   exit(1);
+   }
 
-Chop(class);
- 
 if (IsItemIn(VHEAP,class))
    {
    return;
@@ -511,15 +516,17 @@ int IsDefinedClass(char *class)
   /* Evaluates a.b.c|d.e.f etc and returns true if the class */
   /* is currently true, given the defined heap and negations */
 
-{
+{ int ret;
 Debug4("IsDefinedClass(%s,VADDCLASSES)\n",class);
 
 if (class == NULL)
    {
    return true;
    }
- 
-return EvaluateORString(class,VADDCLASSES);
+
+ret = EvaluateORString(class,VADDCLASSES);
+
+return ret;
 }
 
 
@@ -691,7 +698,7 @@ while(*sp != '\0')
       {
       atom = cbuff+1;
 
-      Debug4("Checking AND Atom %s?\n");
+      Debug4("Checking AND Atom %s?\n",atom);
       
       cbuff[strlen(cbuff)-1] = '\0';
       
@@ -720,7 +727,7 @@ while(*sp != '\0')
             return false;
             }
          }
-      
+
       continue;
       }
    else
@@ -753,7 +760,7 @@ while(*sp != '\0')
       {
       if (negation)
          {
-         Debug4("EvaluateANDString(%s) returns false by negation\n",class);
+         Debug4("EvaluateANDString(%s) returns false by negation 1\n",class);
          return false;
          }
       else
@@ -900,7 +907,7 @@ for (sp = class; *sp != '\0'; sp++)
 if (bracklevel != 0)
    {
    sprintf(OUTPUT,"Bracket mismatch, in [class=%s], level = %d\n",class,bracklevel);
-   yyerror(OUTPUT);;
+   yyerror(OUTPUT);
    FatalError("Aborted");
    }
 
