@@ -481,8 +481,8 @@ if ((ptr != NULL) && S_ISREG(dstat->st_mode) && (ptr->checksum != 'n'))
     if (!DONTDO)
        {
        if (ChecksumChanged(file,digest,cferror,false,ptr->checksum))
-   {
-   }
+          {
+          }
        }
     }
 
@@ -1324,7 +1324,7 @@ void CompressFile(char *file)
 { char comm[CF_BUFSIZE];
   FILE *pp;
  
-if (strlen(COMPRESSCOMMAND) == 0)
+  if ((COMPRESSCOMMAND == NULL) || strlen(COMPRESSCOMMAND) == 0)
    {
    CfLog(cferror,"CompressCommand variable is not defined","");
    return;
