@@ -84,8 +84,8 @@ return true;
 char *EvaluateFunction(char *f,char *value)
 
 { enum builtin fn;
-  char name[CF_MAXVARSIZE],vargs[CF_BUFSIZE],args[CF_EXPANDSIZE];
-  int negated = false;
+ char *sp,name[CF_MAXVARSIZE],args[CF_EXPANDSIZE];
+  int negated = false,count = 1;
 
 if (*f == '!')
    {
@@ -93,8 +93,29 @@ if (*f == '!')
    f++;
    }
  
-sscanf(f,"%255[^(](%255[^)])",name,vargs);
-ExpandVarstring(vargs,args,NULL); 
+sscanf(f,"%255[^(]",name);
+
+
+strncpy(args,f+strlen(name)+1,CF_EXPANDSIZE);
+
+for (sp = args; *sp != '\0'; sp++)
+   {
+   if (*sp == '(')
+      {
+      count++;
+      }
+
+   if (*sp == ')')
+      {
+      count--;
+      if (count == 0)
+         {
+         *sp = '\0';
+         }
+      }
+   }
+
+
 Debug("HandleFunction: %s(%s)\n",name,args);
 
 switch (fn = FunctionStringToCode(name))
@@ -114,7 +135,10 @@ switch (fn = FunctionStringToCode(name))
        HandleStatInfo(fn,args,value);
        break;
    case fn_execresult:
-       HandleFunctionExec(args,value);
+       HandleFunctionExec(args,value,false);
+       break;
+   case fn_execshellresult:
+       HandleFunctionExec(args,value,true);
        break;
    case fn_returnszero:
        HandleReturnsZero(args,value);
@@ -149,9 +173,14 @@ switch (fn = FunctionStringToCode(name))
    case fn_readfile:
        HandleReadFile(args,value);
        break;
+
    case fn_readarray:
        HandleReadArray(args,value);
        break;
+   case fn_readtcp:
+       HandleReadTCP(args,value);
+       break;
+       
    case fn_readtable:
        HandleReadTable(args,value);
        break;
@@ -282,7 +311,7 @@ return (enum builtin) i;
 void GetRandom(char *args,char *value)
 
 { int result,from=-1,to=-1;
-  char argv[CF_MAXFARGS][CF_MAXVARSIZE];
+  char argv[CF_MAXFARGS][CF_EXPANDSIZE];
  
 if (ACTION != control)
    {
@@ -315,11 +344,11 @@ snprintf(value,CF_BUFSIZE,"%u",result);
 void HandleStatInfo(enum builtin fn,char *args,char *value)
 
 { struct stat statbuf;
-  char argv[CF_MAXFARGS][CF_MAXVARSIZE];
+  char argv[CF_MAXFARGS][CF_EXPANDSIZE];
 
 FunctionArgs(args,argv,1);
 
-if (lstat(args,&statbuf) == -1)
+if (lstat(argv[0],&statbuf) == -1)
    {
    strcpy(value,CF_NOCLASS);
    return;
@@ -368,8 +397,11 @@ strcpy(value,CF_NOCLASS);
 void HandleIPRange(char *args,char *value)
 
 { struct Item *ip;
+  char argv[CF_MAXFARGS][CF_EXPANDSIZE];
+
+FunctionArgs(args,argv,1);
  
-if (strchr(args,','))
+if (strchr(argv[0],','))
    {
    yyerror("Illegal argument to unary class-function");
    return;
@@ -377,7 +409,7 @@ if (strchr(args,','))
  
 strcpy(value,CF_NOCLASS);
 
-if (!FuzzyMatchParse(args))
+if (!FuzzyMatchParse(argv[0]))
    {
    return;
    }
@@ -387,7 +419,7 @@ for (ip = IPADDRESSES; ip != NULL; ip = ip->next)
    {
    Debug("Checking IP Range against iface %s\n",VIPADDRESS);
    
-   if (FuzzySetMatch(args,ip->name) == 0)
+   if (FuzzySetMatch(argv[0],ip->name) == 0)
       {
       Debug("IPRange Matched\n");
       strcpy(value,CF_ANYCLASS);
@@ -398,7 +430,7 @@ for (ip = IPADDRESSES; ip != NULL; ip = ip->next)
 
 Debug("Checking IP Range against RDNS %s\n",VIPADDRESS);
 
-if (FuzzySetMatch(args,VIPADDRESS) == 0)
+if (FuzzySetMatch(argv[0],VIPADDRESS) == 0)
    {
    Debug("IPRange Matched\n");
    strcpy(value,CF_ANYCLASS);
@@ -413,19 +445,22 @@ strcpy(value,CF_NOCLASS);
 
 void HandleHostRange(char *args,char *value)
 
-{
-Debug("SRDEBUG in HandleHostRange()\n"); 
-Debug("SRDEBUG args=%s value=%s\n",args,value);
+{ char argv[CF_MAXFARGS][CF_EXPANDSIZE];
 
-if (!FuzzyHostParse(args))
+FunctionArgs(args,argv,2);
+
+if (!FuzzyHostParse(argv[0],argv[1]))
    {
    strcpy(value,CF_NOCLASS);
    return;
    }
+
 /* VDEFAULTBINSERVER.name is relative domain name */
 /* (see nameinfo.c ~line 145)                     */
 
-if (FuzzyHostMatch(args,VDEFAULTBINSERVER.name) == 0)
+Debug("Parsing fuzzy host succeeded\n");
+
+if (FuzzyHostMatch(argv[0],argv[1],VDEFAULTBINSERVER.name) == 0)
    {
    Debug("SRDEBUG SUCCESS!\n");
    strcpy(value,CF_ANYCLASS);
@@ -444,7 +479,7 @@ return;
 void HandleCompareStat(enum builtin fn,char *args,char *value)
 
 { struct stat frombuf,tobuf;
-  char argv[CF_MAXFARGS][CF_MAXVARSIZE];
+  char argv[CF_MAXFARGS][CF_EXPANDSIZE];
 
 FunctionArgs(args,argv,2); 
 strcpy(value,CF_NOCLASS);
@@ -492,25 +527,29 @@ strcpy(value,CF_NOCLASS);
 
 /*********************************************************************/
 
-void HandleFunctionExec(char *args,char *value)
+void HandleFunctionExec(char *args,char *value,int useshell)
 
 { char command[CF_MAXVARSIZE];
+  char argv[CF_MAXFARGS][CF_EXPANDSIZE];
+  
+FunctionArgs(args,argv,1); 
 
- if (ACTION != control)
+if (ACTION != control)
    {
-   yyerror("Use of ExecResult(s) outside of variable assignment");
+   yyerror("Use of Exec[Shell]Result(s) outside of variable assignment");
    }
  
-if (*args == '/')
+if (*argv[0] == '/')
    {
-   strncpy(command,args,CF_MAXVARSIZE);
-   GetExecOutput(command,value);
+   strncpy(command,argv[0],CF_MAXVARSIZE);
+   GetExecOutput(command,value,useshell);
    Chop(value);
    value[CF_MAXVARSIZE-1] = '\0';  /* Truncate to CF_MAXVARSIZE */
    }
  else
     {
-    yyerror("ExecResult(/command) must specify an absolute path");
+    snprintf(OUTPUT,CF_BUFSIZE,"Exec[Shell]Result(%s) must specify an absolute path",argv[0]);
+    yyerror(OUTPUT);
     } 
 }
 
@@ -519,17 +558,20 @@ if (*args == '/')
 void HandleReturnsZero(char *args,char *value)
 
 { char command[CF_BUFSIZE];
-
+  char argv[CF_MAXFARGS][CF_EXPANDSIZE];
+  
 if (ACTION != groups)
    {
    yyerror("Use of ReturnsZero(s) outside of class assignment");
    }
 
-Debug("HandleReturnsZero(%s)\n",args); 
+FunctionArgs(args,argv,1); 
+
+Debug("HandleReturnsZero(%s)\n",argv); 
  
-if (*args == '/')
+if (*argv[0] == '/')
    {
-   strncpy(command,args,CF_BUFSIZE);
+   strncpy(command,argv[0],CF_BUFSIZE);
    
    if (ShellCommandReturnsZero(command))
       {
@@ -550,15 +592,18 @@ if (*args == '/')
 
 void HandleIsDefined(char *args,char *value)
 
-{
+{ char argv[CF_MAXFARGS][CF_EXPANDSIZE];
+
+FunctionArgs(args,argv,1);
+
 if (ACTION != groups)
    {
    yyerror("Use of IsDefined(s) outside of class assignment");
    }
 
-Debug("HandleIsDefined(%s)\n",args); 
+Debug("HandleIsDefined(%s)\n",argv[0]); 
  
-if (GetMacroValue(CONTEXTID,args))
+if (GetMacroValue(CONTEXTID,argv[0]))
    {
    strcpy(value,CF_ANYCLASS);
    return;
@@ -571,7 +616,7 @@ strcpy(value,CF_NOCLASS);
 
 void HandleSyslogFn(char *args,char *value)
 
-{ char argv[CF_MAXFARGS][CF_MAXVARSIZE];
+{ char argv[CF_MAXFARGS][CF_EXPANDSIZE];
   int priority = LOG_ERR;
 
 FunctionArgs(args,argv,2);
@@ -628,7 +673,7 @@ if (!DONTDO)
 
 void HandleStrCmp(char *args,char *value)
 
-{ char argv[CF_MAXFARGS][CF_MAXVARSIZE];
+{ char argv[CF_MAXFARGS][CF_EXPANDSIZE];
 
 FunctionArgs(args,argv,2); 
  
@@ -646,7 +691,7 @@ else
 
 void HandleGreaterThan(char *args,char *value,char ch)
 
-{ char argv[CF_MAXFARGS][CF_MAXVARSIZE];
+{ char argv[CF_MAXFARGS][CF_EXPANDSIZE];
   double a = CF_NOVAL,b = CF_NOVAL;
  
 FunctionArgs(args,argv,2); 
@@ -714,7 +759,7 @@ else
 
 void HandleRegCmp(char *args,char *value)
 
-{ char argv[CF_MAXFARGS][CF_MAXVARSIZE];
+{ char argv[CF_MAXFARGS][CF_EXPANDSIZE];
   struct Item *list = NULL, *ret; 
 
 FunctionArgs(args,argv,2);
@@ -725,6 +770,8 @@ if (ACTION != groups)
    return;
    }
 
+Debug("List source = (%d)[%s]\n",strlen(argv[1]),argv[1]);
+
 list = SplitStringAsItemList(argv[1],LISTSEPARATOR);
 
 ret = LocateNextItemMatching(list,argv[0]);
@@ -746,7 +793,7 @@ DeleteItemList(list);
 
 void HandleReadFile(char *args,char *value)
 
-{ char argv[CF_MAXFARGS][CF_MAXVARSIZE];
+{ char argv[CF_MAXFARGS][CF_EXPANDSIZE];
   int i,val = 0;
   FILE *fp;
 
@@ -789,7 +836,7 @@ fclose(fp);
 
 void HandleReadArray(char *args,char *value)
 
-{ char argv[CF_MAXFARGS][CF_MAXVARSIZE];
+{ char argv[CF_MAXFARGS][CF_EXPANDSIZE];
   char *sp,*filename=argv[0],*maxbytes=argv[4],*formattype=argv[1];
   char *commentchar=argv[3],*sepchar=argv[2],buffer[CF_BUFSIZE];
   int i=0,val = 0,read = 0;
@@ -862,7 +909,7 @@ while (!feof(fp))
       }
    else if (strcmp(formattype,"textkey") == 0)
       {
-      char argv[CF_MAXFARGS][CF_MAXVARSIZE],lvalue[CF_BUFSIZE];
+      char argv[CF_MAXFARGS][CF_EXPANDSIZE],lvalue[CF_BUFSIZE];
       if (!FunctionArgs(buffer,argv,2))
          {
          break;
@@ -888,7 +935,7 @@ while (!feof(fp))
 
 void HandleReadTable(char *args,char *value)
 
-{  char argv[CF_MAXFARGS][CF_MAXVARSIZE];
+{  char argv[CF_MAXFARGS][CF_EXPANDSIZE];
   char *sp,*filename=argv[0],*maxbytes=argv[4],*formattype=argv[1];
   char *commentchar=argv[3],*sepchar=argv[2],buffer[CF_BUFSIZE];
   int i=0,j=0,val = 0,read = 0;
@@ -964,7 +1011,7 @@ while (!feof(fp))
       }
    else if (strcmp(formattype,"textkey") == 0)
       {
-      char argv[CF_MAXFARGS][CF_MAXVARSIZE],lvalue[CF_BUFSIZE];
+      char argv[CF_MAXFARGS][CF_EXPANDSIZE],lvalue[CF_BUFSIZE];
       if (!FunctionArgs(buffer,argv,3))
          {
          break;
@@ -990,7 +1037,7 @@ snprintf(value,CF_BUFSIZE-1,"CF_ASSOCIATIVE_ARRAY%s",args);
 
 void HandleReadList(char *args,char *value)
 
-{ char argv[CF_MAXFARGS][CF_MAXVARSIZE];
+{ char argv[CF_MAXFARGS][CF_EXPANDSIZE];
   char *sp,*filename=argv[0],*maxbytes=argv[3],*formattype=argv[1];
   char *commentchar=argv[2],buffer[CF_BUFSIZE];
   int val = 0;
@@ -1004,7 +1051,7 @@ val = atoi(maxbytes);
 if (strcmp(formattype,"lines") != 0)
    {
    snprintf(OUTPUT,CF_BUFSIZE,"Unknown format type in ReadList(%s)",args);
-   CfLog(cferror,OUTPUT,"");;
+   CfLog(cferror,OUTPUT,"");
    }
     
 if ((fp = fopen(filename,"r")) == NULL)
@@ -1063,11 +1110,71 @@ value[strlen(value)-1] = '\0';
 
 /*********************************************************************/
 
+void HandleReadTCP(char *args,char *value)
+
+{ char argv[CF_MAXFARGS][CF_EXPANDSIZE];
+  char *sp,*hostnameip=argv[0],*maxbytes=argv[3],*port=argv[1];
+  char *sendstring=argv[2],buffer[CF_BUFSIZE];
+  int val = 0, n_read = 0;
+  short portnum;
+  struct Item *list = NULL,*ip;
+  FILE *fp;
+
+FunctionArgs(args,argv,4);
+ 
+val = atoi(maxbytes);
+portnum = (short) atoi(port);
+
+if (val > CF_BUFSIZE-1)
+   {
+   snprintf(OUTPUT,CF_BUFSIZE,"Too many bytes to read from TCP port %s@%s",port,hostnameip);
+   CfLog(cferror,OUTPUT,"");
+   }
+
+Debug("Want to read %d bytes from port %d at %s\n",val,portnum,hostnameip);
+
+CONN = NewAgentConn();
+
+if (!RemoteConnect(hostnameip,'n',portnum,port))
+   {
+   CfLog(cferror,"Couldn't open a tcp socket","socket");
+
+   if (CONN->sd != CF_NOT_CONNECTED)
+      {
+      close(CONN->sd);
+      CONN->sd = CF_NOT_CONNECTED;
+      }
+
+   DeleteAgentConn(CONN);
+   return;
+   }
+
+if (strlen(sendstring) > 0)
+   {
+   if (SendSocketStream(CONN->sd,sendstring,strlen(sendstring),0) == -1)
+      {
+      DeleteAgentConn(CONN);
+      return;   
+      }
+   }
+
+if ((n_read = recv(CONN->sd,value,val,0)) == -1)
+   {
+   }
+
+close(CONN->sd);
+DeleteAgentConn(CONN);
+
+/* value set to result */
+}
+
+/*********************************************************************/
+
 void HandleSelectPLeader(char *args,char *value)
 
 { FILE *fp;
-  char machine[128],first[128];
-  char argv[CF_MAXFARGS][CF_MAXVARSIZE];
+  char machine[MAXHOSTNAMELEN],first[MAXHOSTNAMELEN];
+  char argv[CF_MAXFARGS][CF_EXPANDSIZE];
   char *filename=argv[0],*commentchar=argv[1];
   char *policy=argv[2],*size=argv[3];
   struct Item *list = NULL,*ip;
@@ -1122,9 +1229,9 @@ while (!feof(fp))
          }
       }
    
-   memset(machine,0,127);
+   memset(machine,0,MAXHOSTNAMELEN-1);
    
-   sscanf(buffer,"%127s",machine);
+   sscanf(buffer,"%255s",machine);
 
    if (strlen(machine) == 0)
       {
@@ -1139,7 +1246,7 @@ while (!feof(fp))
 
    if (strlen(first) == 0)
       {
-      strncpy(first,machine,127);
+      strncpy(first,machine,MAXHOSTNAMELEN-1);
       }
    
    if ((count == psize) || ((count > 0) && feof(fp)))
@@ -1171,11 +1278,11 @@ while (!feof(fp))
                Verbose(" %s (leader)\n",ip->name);
                if (strlen(ip->name) > 0)
                   {
-                  strncpy(value,ip->name,127);
+                  strncpy(value,ip->name,MAXHOSTNAMELEN-1);
                   }
                else
                   {
-                  strncpy(value,first,127);
+                  strncpy(value,first,MAXHOSTNAMELEN-1);
                   }
                done = true;
                }
@@ -1213,7 +1320,7 @@ while (!feof(fp))
 
 if (!done)
    {
-   strncpy(value,first,127); /* Fill up blanks in peer groups */
+   strncpy(value,first,MAXHOSTNAMELEN-1); /* Fill up blanks in peer groups */
    }
 
 if (list != NULL)
@@ -1229,7 +1336,7 @@ fclose(fp);
 
 void HandleSelectPGroup(char *args,char *value)
 
-{ char argv[CF_MAXFARGS][CF_MAXVARSIZE],machine[128],first[128];
+{ char argv[CF_MAXFARGS][CF_EXPANDSIZE],machine[MAXHOSTNAMELEN],first[MAXHOSTNAMELEN];
   char *filename=argv[0],*commentchar=argv[1];
   char *policy=argv[2],*size=argv[3];
   struct Item *list = NULL,*ip;
@@ -1286,7 +1393,7 @@ while (!feof(fp))
       }
    
    machine[0] = '\0';
-   sscanf(buffer,"%127s",machine);
+   sscanf(buffer,"%255s",machine);
 
    if (strlen(machine) == 0)
       {
@@ -1301,7 +1408,7 @@ while (!feof(fp))
 
    if (strlen(first) == 0)
       {
-      strncpy(first,machine,127);
+      strncpy(first,machine,MAXHOSTNAMELEN-1);
       }
 
    if ((count == psize) || ((count > 0) && feof(fp)))
@@ -1357,7 +1464,7 @@ while (!feof(fp))
 
 if (!done)
    {
-   strncat(value,first,127); /* Fill up blanks in peer groups */
+   strncat(value,first,MAXHOSTNAMELEN-1); /* Fill up blanks in peer groups */
    }
  
 fclose(fp); 
@@ -1368,10 +1475,13 @@ fclose(fp);
 void HandleReturnValues(char *args,char *value)
 
 { struct Item *ip;
- 
-Verbose("This is a method with return value list: (%s)\n",args);
+  char argv[CF_MAXFARGS][CF_EXPANDSIZE];
 
-for (ip = SplitStringAsItemList(args,','); ip != NULL; ip=ip->next)
+FunctionArgs(args,argv,1);
+ 
+Verbose("This is a method with return value list: (%s)\n",argv[0]);
+
+for (ip = SplitStringAsItemList(argv[0],','); ip != NULL; ip=ip->next)
    {
    AppendItem(&METHODRETURNVARS,ip->name,CLASSBUFF);
    }
@@ -1384,12 +1494,15 @@ strcpy(value,"noinstall");
 void HandleReturnClasses(char *args,char *value)
 
 { struct Item *ip;
- 
-Verbose("This is a method with return class list: %s\n",args);
+  char argv[CF_MAXFARGS][CF_EXPANDSIZE];
 
-for (ip = SplitStringAsItemList(args,','); ip != NULL; ip=ip->next)
+FunctionArgs(args,argv,1);
+ 
+Verbose("This is a method with return class list: %s\n",argv[0]);
+
+for (ip = SplitStringAsItemList(argv[0],','); ip != NULL; ip=ip->next)
    {
-   AppendItem(&METHODRETURNCLASSES,args,CLASSBUFF);
+   AppendItem(&METHODRETURNCLASSES,argv[0],CLASSBUFF);
    }
 
 strcpy(value,"noinstall");
@@ -1407,8 +1520,10 @@ void HandleShowState(char *args,char *value)
   int maxlen = 0,count;
   double *dist = NULL, S = 0.0;
   char *offset = NULL;
-  
-  
+  char argv[CF_MAXFARGS][CF_EXPANDSIZE];
+
+FunctionArgs(args,argv,1);
+
 if ((ACTION != alerts) && PARSING)
    {
    yyerror("Use of ShowState(type) outside of alert declaration");
@@ -1422,7 +1537,7 @@ if (PARSING)
    return;
    }
  
-snprintf(buffer,CF_BUFSIZE-1,"%s/state/cf_%s",CFWORKDIR,args);
+snprintf(buffer,CF_BUFSIZE-1,"%s/state/cf_%s",CFWORKDIR,argv[0]);
 
 if (stat(buffer,&statbuf) == 0)
    {
@@ -1445,9 +1560,9 @@ if (stat(buffer,&statbuf) == 0)
          {
          Verbose("%s: (%2d) %s",VPREFIX,conns,buffer);
          
-         if (IsSocketType(args))
+         if (IsSocketType(argv[0]))
             {
-            if (strncmp(args,"incoming",8) == 0 || strncmp(args,"outgoing",8) == 0)
+            if (strncmp(argv[0],"incoming",8) == 0 || strncmp(argv[0],"outgoing",8) == 0)
                {
                if (strncmp(buffer,"tcp",3) == 0)
                   {
@@ -1462,7 +1577,7 @@ if (stat(buffer,&statbuf) == 0)
                DePort(vbuff);
                }
             }
-         else if (IsTCPType(args))
+         else if (IsTCPType(argv[0]))
             {
             count = 1;
             sscanf(buffer,"%d %[^\n]",&count,remote);
@@ -1512,7 +1627,7 @@ if (stat(buffer,&statbuf) == 0)
    printf("%s: -----------------------------------------------------------------------------------\n",VPREFIX);
    printf("%s: In the last 40 minutes, the peak state was q = %d:\n",VPREFIX,conns);
 
-   if (IsSocketType(args)||IsTCPType(args))
+   if (IsSocketType(argv[0])||IsTCPType(argv[0]))
       {
       if (addresses != NULL)
          {
@@ -1603,12 +1718,12 @@ if (stat(buffer,&statbuf) == 0)
       }
    
    printf("%s: -----------------------------------------------------------------------------------\n",VPREFIX);
-   snprintf(buffer,CF_BUFSIZE,"State of %s peaked at %s\n",args,ctime(&statbuf.st_mtime));
+   snprintf(buffer,CF_BUFSIZE,"State of %s peaked at %s\n",argv[0],ctime(&statbuf.st_mtime));
    strcpy(value,buffer);
    }
 else 
    {
-   snprintf(buffer,CF_BUFSIZE,"State parameter %s is not known or recorded\n",args);   
+   snprintf(buffer,CF_BUFSIZE,"State parameter %s is not known or recorded\n",argv[0]);
    strcpy(value,buffer);
    }
 
@@ -1624,7 +1739,7 @@ if (dist)
 
 void HandleFriendStatus(char *args,char *value)
 
-{ char argv[CF_MAXFARGS][CF_MAXVARSIZE];
+{ char argv[CF_MAXFARGS][CF_EXPANDSIZE];
   int time = -1;
   
 if ((ACTION != alerts) && PARSING)
@@ -1654,7 +1769,7 @@ strcpy(value,""); /* No reply */
 
 void HandleSetState(char *args,char *value)
 
-{ char argv[CF_MAXFARGS][CF_MAXVARSIZE];
+{ char argv[CF_MAXFARGS][CF_EXPANDSIZE];
   char *name=argv[0],*ttlbuf=argv[1],*policy=argv[2];
   unsigned int ttl = 0;
 
@@ -1695,7 +1810,7 @@ else
 
 void HandleUnsetState(char *args,char *value)
 
-{ char argv[CF_MAXFARGS][CF_MAXVARSIZE];
+{ char argv[CF_MAXFARGS][CF_EXPANDSIZE];
   
 value[0] = '\0';
 FunctionArgs(args,argv,1);
@@ -1709,7 +1824,7 @@ DeletePersistentClass(argv[0]);
 
 void HandlePrepModule(char *args,char *value)
 
-{ char argv[CF_MAXFARGS][CF_MAXVARSIZE];
+{ char argv[CF_MAXFARGS][CF_EXPANDSIZE];
   char ebuff[CF_EXPANDSIZE];
 
 ExpandVarstring(args,ebuff,NULL);
@@ -1718,7 +1833,9 @@ value[0] = '\0';
 FunctionArgs(ebuff,argv,2);
 
 Debug("PrepModule(%s,%s)\n",argv[0],argv[1]);
- 
+
+BuildClassEnvironment();
+
 if (CheckForModule(argv[0],argv[1]))
    {
    strcpy(value,CF_ANYCLASS);
@@ -1733,7 +1850,7 @@ else
 
 void HandleAssociation(char *args,char *value)
 
-{ char argv[CF_MAXFARGS][CF_MAXVARSIZE],lvalue[CF_BUFSIZE];
+{ char argv[CF_MAXFARGS][CF_EXPANDSIZE],lvalue[CF_BUFSIZE];
  
 value[0] = '\0';
 FunctionArgs(args,argv,2);
@@ -1749,80 +1866,53 @@ snprintf(value,CF_BUFSIZE-1,"CF_ASSOCIATIVE_ARRAY%s",args);
 /* Level 3                                                           */
 /*********************************************************************/
 
-int FunctionArgs(char *args,char arg[CF_MAXFARGS][CF_MAXVARSIZE],int number)
+int FunctionArgs(char *args,char arg[CF_MAXFARGS][CF_EXPANDSIZE],int number)
 
-{ char argv[CF_MAXFARGS][CF_MAXVARSIZE];
-  char *sp,*start[CF_MAXFARGS];
+{ char *sp,*start[CF_MAXFARGS],exbuf[CF_EXPANDSIZE];
   int count = 0, i;
+  struct Item *ip =  NULL, *ipp;
 
 if (number > CF_MAXFARGS)
    {
    FatalError("Software error: too many function arguments");
    }
-  
+
+ip = ListFromArgs(args);
+
+if (DEBUG)
+   {
+   DebugListItemList(ip);
+   }
+
+count = ListLen(ip);
+
+if (count != number)
+   {
+   if (PARSING)
+      {
+      snprintf(OUTPUT,CF_BUFSIZE,"Function or format of input file requires %d argument items",number);
+      yyerror(OUTPUT);
+      }
+   else
+      {
+      snprintf(OUTPUT,CF_BUFSIZE,"Assignment (%s) with format error - %d/%d expected args",args,count,number);
+      CfLog(cferror,OUTPUT,"");
+      }
+   return false;
+   }
+
+ipp = ip;
+
 for (i = 0; i < number; i++)
    {
-   memset(argv[i],0,CF_MAXVARSIZE);
+   ExpandVarstring(ipp->name,exbuf,NULL);
+   strncpy(arg[i],exbuf,CF_EXPANDSIZE);
+   Debug("ARG[%d] %s\n",i,arg[i]);
+   ipp = ipp->next;
    }
 
-start[0] = args; 
+DeleteItemList(ip);
 
-for (sp = args; *sp != '\0'; sp++)
-   {
-   if (*sp == '\"')
-      {
-      while (*++sp != '\"')
-         {
-         }
-      continue;
-      }
-   
-   if (*sp == '\'')
-      {
-      while (*++sp != '\'')
-         {
-         }
-      continue;
-      }
-   
-   if (*sp == ',')
-      {
-      if (++count > number-1)
-         {
-         break;
-         }
-      
-      start[count] = sp+1;
-      }
-   }
- 
- if (count != number-1)
-    {
-    if (PARSING)
-       {
-       snprintf(OUTPUT,CF_BUFSIZE,"Function or format of input file requires %d argument items",number);
-       yyerror(OUTPUT);
-       }
-    else
-       {
-       snprintf(OUTPUT,CF_BUFSIZE,"Assignment (%s) with format error",args);
-       CfLog(cferror,OUTPUT,"");
-       }
-    return false;
-    }
- 
- for (i = 0; i < number-1; i++)
-    {
-    strncpy(argv[i],start[i],start[i+1]-start[i]-1);
-    }
- 
- sscanf(start[number-1],"%[^)]",argv[number-1]); 
- 
- for (i = 0; i < number; i++)
-    {
-    strncpy(arg[i],UnQuote(argv[i]),CF_MAXVARSIZE-1);
-    }
- 
 return true;
 }
 
