@@ -61,6 +61,7 @@ char CFPUBKEYFILE[CF_BUFSIZE];
 char CFPRIVKEYFILE[CF_BUFSIZE];
 char AVDB[CF_MAXVARSIZE];
 char CFWORKDIR[CF_BUFSIZE];
+char PIDFILE[CF_BUFSIZE];
 
 RSA *PRIVKEY = NULL, *PUBKEY = NULL;
 
@@ -93,7 +94,7 @@ pthread_mutex_t MUTEX_LOCK = PTHREAD_MUTEX_INITIALIZER;
 /*                                                                 */
 /*******************************************************************/
 
-  PUBLIC char *COPYRIGHT = "Free Software Foundation 1994-\nDonated by Mark Burgess, Faculty of Engineering,\nOslo University College, 0254 Oslo, Norway";
+  PUBLIC char *COPYRIGHT = "Free Software Foundation 1994-\nDonated by Mark Burgess, Faculty of Engineering,\nOslo University College, Norway";
 
   PRIVATE char *VPRECONFIG = "cf.preconf";
   PRIVATE char *VRCFILE = "cfrc";
@@ -134,6 +135,7 @@ pthread_mutex_t MUTEX_LOCK = PTHREAD_MUTEX_INITIALIZER;
   PUBLIC short LOGTIDYHOMEFILES = true;
   PUBLIC short UPDATEONLY = false;
   PUBLIC short SKIPIDENTIFY = false;
+  PUBLIC short ALL_SINGLECOPY = false;
 
   PUBLIC char FORK = 'n';
 
@@ -215,6 +217,7 @@ char *TCPNAMES[CF_NETATTR] =
  /* Methods                                                         */
  /*******************************************************************/
 
+  PUBLIC int GOTMETHODARGS = false;
   PUBLIC struct Item *METHODARGS = NULL;
   PUBLIC char ** METHODARGV = NULL;
   PUBLIC int METHODARGC = 0;
@@ -243,11 +246,12 @@ char *TCPNAMES[CF_NETATTR] =
  /* Data/list structures - root pointers                            */
  /*******************************************************************/
 
+  PUBLIC struct Item *ABORTHEAP = NULL;
+  
   PROTECTED  struct Item *VTIMEZONE = NULL;
   PROTECTED  struct Item *VMOUNTLIST = NULL;
   PROTECTED  struct Item *VEXCLUDECOPY = NULL;
   PROTECTED  struct Item *VAUTODEFINE = NULL;
-  PROTECTED  struct Item *VSINGLECOPY = NULL;
   PROTECTED  struct Item *VEXCLUDELINK = NULL;
   PROTECTED  struct Item *VCOPYLINKS = NULL;
   PROTECTED  struct Item *VLINKCOPIES = NULL;
@@ -283,7 +287,7 @@ char *TCPNAMES[CF_NETATTR] =
   PROTECTED  struct Mounted *MOUNTED = NULL;             /* Files systems already mounted */
   PROTECTED  struct MiscMount *VMISCMOUNT = NULL;
   PROTECTED  struct MiscMount *VMISCMOUNTTOP = NULL;
-  PROTECTED  struct Item *VBINSERVERS = &VDEFAULTBINSERVER;
+  PROTECTED  struct Item *VBINSERVERS = NULL;
   PROTECTED  struct Link *VLINK = NULL;
   PROTECTED  struct Link *VLINKTOP = NULL;
   PROTECTED  struct File *VFILE = NULL;
@@ -547,6 +551,7 @@ char *TCPNAMES[CF_NETATTR] =
       "islink",
       "isplain",
       "execresult",
+      "execshellresult",
       "returnszero",
       "iprange",
       "hostrange",
@@ -571,6 +576,7 @@ char *TCPNAMES[CF_NETATTR] =
       "selectpartitionneighbors",
       "isgreaterthan",
       "islessthan",
+      "readtcp",
       NULL
       };
 
@@ -638,6 +644,7 @@ char *TCPNAMES[CF_NETATTR] =
       "ge",
       "le",
       "ne",
+      "none",
       NULL
       };
 
@@ -671,7 +678,6 @@ char *TCPNAMES[CF_NETATTR] =
 
   PUBLIC  short SHOWDB = false;
   PUBLIC  short PARSING = false;
-  PRIVATE short NOABSPATH = false;
   PRIVATE short TRAVLINKS = false;
   PRIVATE short PTRAVLINKS = false;
   PRIVATE short DEADLINKS = true;
@@ -713,11 +719,13 @@ char *TCPNAMES[CF_NETATTR] =
   PRIVATE short NOSPLAY = false;
   PRIVATE short DONESPLAY = false;
 
+  PUBLIC  struct Item *VSINGLECOPY = NULL;
 
   PROTECTED  struct Item *VACLBUILD = NULL;
   PROTECTED  struct Item *VFILTERBUILD = NULL;
   PROTECTED  struct Item *VSTRATEGYBUILD = NULL;
 
+  PRIVATE char NOABSPATH = 'n';
   PRIVATE char TIDYDIRS = 'n';
   PRIVATE char XDEV = false;
   PRIVATE char IMAGEBACKUP='y';
@@ -769,8 +777,8 @@ char *TCPNAMES[CF_NETATTR] =
   PRIVATE char *MOUNTOPTS;
   PRIVATE char *DESTINATION;
   PRIVATE char *IMAGEACTION;
-  PRIVATE char *VIFNAME[16];
-  PRIVATE char *VIFNAMEOVERRIDE[16];
+  PRIVATE char VIFNAME[16];
+  PRIVATE char VIFNAMEOVERRIDE[16];
   PRIVATE char *CHDIR;
   PRIVATE char *LOCALREPOS;
   PRIVATE char *EXPR;
@@ -830,7 +838,7 @@ char *TCPNAMES[CF_NETATTR] =
   /*
    * HvB: Bas van der Vlies
   */
-  PRIVATE flag MOUNT_RO = false;
+  PRIVATE flag CF_MOUNT_RO = false;
 
   PRIVATE char *COMMATTRIBUTES[] =
      {
@@ -1023,6 +1031,7 @@ char *TCPNAMES[CF_NETATTR] =
      "AppendIfNoSuchLinesFromFile",
      "IncrementPointer",
      "ReplaceLineWith",
+     "ExpandVariables",
      "DeleteToLineMatching",
      "HashCommentToLineMatching",
      "PercentCommentToLineMatching",
@@ -1037,8 +1046,10 @@ char *TCPNAMES[CF_NETATTR] =
      "GotoLastLine",
      "BreakIfLineMatches",
      "BeginGroupIfNoMatch",
+     "BeginGroupIfMatch",
      "BeginGroupIfNoLineMatching",
      "BeginGroupIfNoSuchLine",
+     "BeginGroupIfLineMatching",
      "EndGroup",
      "Append",
      "Prepend",
@@ -1064,6 +1075,7 @@ char *TCPNAMES[CF_NETATTR] =
      "BeginGroupIfFileIsNewer",
      "BeginGroupIfFileExists",
      "BeginGroupIfNoLineContaining",
+     "BeginGroupIfLineContaining",
      "BeginGroupIfDefined",
      "BeginGroupIfNotDefined",
      "AutoCreate",
