@@ -52,7 +52,7 @@ NewParser();
 
 for (ip = VRPCPEERLIST; ip != NULL; ip = ip->next)
    {
-   strncpy(client,ip->name,64);
+   strncpy(client,ip->name,MAXHOSTNAMELEN);
    
    if (strstr(ip->name,".")||strstr(ip->name,":"))
       {
@@ -138,11 +138,14 @@ if (strlen(from) == 0)     /* Check for root dir */
 strncpy(newto,to,CF_BUFSIZE-2);
 AddSlash(newto);
 
-if (! MakeDirectoriesFor(newto,ip->forcedirs))
+if (strcmp(ip->action,"warn") != 0)
    {
-   snprintf(OUTPUT,CF_BUFSIZE*2,"Unable to make directory for %s in copy: %s to %s\n",newto,ip->path,ip->destination);
-   CfLog(cferror,OUTPUT,"");
-   return;
+   if (! MakeDirectoriesFor(newto,ip->forcedirs))
+      {
+      snprintf(OUTPUT,CF_BUFSIZE*2,"Unable to make directory for %s in copy: %s to %s\n",newto,ip->path,ip->destination);
+      CfLog(cferror,OUTPUT,"");
+      return;
+      }
    }
 
 if ((dirh = cfopendir(from,ip)) == NULL)
@@ -231,24 +234,13 @@ for (dirp = cfreaddir(dirh,ip); dirp != NULL; dirp = cfreaddir(dirh,ip))
    if (!S_ISDIR(statbuf.st_mode))
       {
       succeed = 0;
-      for (ptr = VEXCLUDECACHE; ptr != NULL; ptr=ptr->next)
-          {
-          if ((strncmp(ptr->name,newto,strlen(newto)+1) == 0) && (strncmp(ptr->classes,ip->classes,strlen(ip->classes)+1) == 0))
-             {
-             succeed = 1;
-             }
-          }
 
-      if (succeed)
+      if (IsItemIn(VEXCLUDECACHE,newto))
          {
-         snprintf(OUTPUT,CF_BUFSIZE*2,"Skipping excluded file %s class %s\n",newto,ip->classes);
+         snprintf(OUTPUT,CF_BUFSIZE*2,"Skipping single-copied file %s class %s\n",newto,ip->classes);
          CfLog(cfverbose,OUTPUT,"");
          continue;
          }
-      else
-         {
-         Debug2("file %s class %s was not excluded\n",newto,ip->classes);
-         }
       }
 
    if (S_ISDIR(statbuf.st_mode))
@@ -284,7 +276,7 @@ for (dirp = cfreaddir(dirh,ip); dirp != NULL; dirp = cfreaddir(dirh,ip))
             }
          }
       
-      CheckCopiedFile(ip->cf_findertype,newto,ip->plus,ip->minus,fixall,ip->uid,ip->gid,&deststatbuf,&statbuf,NULL,ip->acl_aliases);
+      CheckCopiedFile(ip->cf_findertype,newto,ip->plus,ip->minus,ip->action,ip->uid,ip->gid,&deststatbuf,&statbuf,NULL,ip->acl_aliases);
       
       (ip->uid)->uid = save_uid;
       (ip->gid)->gid = save_gid;
@@ -467,6 +459,7 @@ Debug2("CheckImage (source=%s destination=%s)\n",source,destination);
 
 if (ip->linktype == 'n')
    {
+   Debug("Treating links as files for %s\n",source);
    found = cfstat(source,&sourcestatbuf,ip);
    }
 else
@@ -479,6 +472,7 @@ if (found == -1)
    snprintf(OUTPUT,CF_BUFSIZE*2,"Can't stat %s\n",source);
    CfLog(cferror,OUTPUT,"");
    FlushClientCache(ip);
+   AddMultipleClasses(ip->elsedef);
    return;
    }
 
@@ -526,7 +520,7 @@ if (S_ISDIR(sourcestatbuf.st_mode))
        }
     else
        {
-       CheckCopiedFile(ip->cf_findertype,destdir,ip->plus,ip->minus,fixall,ip->uid,ip->gid,&deststatbuf,&sourcestatbuf,NULL,ip->acl_aliases);
+       CheckCopiedFile(ip->cf_findertype,destdir,ip->plus,ip->minus,ip->action,ip->uid,ip->gid,&deststatbuf,&sourcestatbuf,NULL,ip->acl_aliases);
        }
 
    for (dirp = cfreaddir(dirh,ip); dirp != NULL; dirp = cfreaddir(dirh,ip))
@@ -552,14 +546,28 @@ if (S_ISDIR(sourcestatbuf.st_mode))
          }
       
       strcat(destfile, dirp->d_name);
-      
-      if (cflstat(sourcefile,&sourcestatbuf,ip) == -1)
+
+      if (ip->linktype == 'n')
          {
-         printf("%s: Can't stat %s\n",VPREFIX,sourcefile);
-         FlushClientCache(ip);       
-         (ip->uid)->uid = save_uid;
-         (ip->gid)->gid = save_gid;
-         return;
+         if (cfstat(sourcefile,&sourcestatbuf,ip) == -1)
+            {
+            printf("%s: Can't stat %s\n",VPREFIX,sourcefile);
+            FlushClientCache(ip);       
+            (ip->uid)->uid = save_uid;
+            (ip->gid)->gid = save_gid;
+            return;
+            }
+         }
+      else
+         {
+         if (cflstat(sourcefile,&sourcestatbuf,ip) == -1)
+            {
+            printf("%s: Can't stat %s\n",VPREFIX,sourcefile);
+            FlushClientCache(ip);       
+            (ip->uid)->uid = save_uid;
+            (ip->gid)->gid = save_gid;
+            return;
+            }
          }
       
       ImageCopy(sourcefile,destfile,sourcestatbuf,ip);
@@ -708,7 +716,7 @@ void ImageCopy(char *sourcefile,char *destfile,struct stat sourcestatbuf,struct
   struct stat deststatbuf;
   struct Link empty;
   struct Item *ptr, *ptr1;
-  int succeed, silent = false, enforcelinks;
+  int succeed = false,silent = false, enforcelinks;
   mode_t srcmode = sourcestatbuf.st_mode;
   int ok_to_copy = false, found;
 
@@ -723,39 +731,25 @@ if ((strcmp(sourcefile,destfile) == 0) && (strcmp(ip->server,"localhost") == 0))
    return;
    }
 
- empty.defines = NULL;
- empty.elsedef = NULL;
+empty.defines = NULL;
+empty.elsedef = NULL;
 
- if (IgnoredOrExcluded(image,sourcefile,ip->inclusions,ip->exclusions))
-    {
-    return;
-    }
- 
- succeed = 0;
-
- for (ptr = VEXCLUDECACHE; ptr != NULL; ptr=ptr->next)
-    {
-    if ((strncmp(ptr->name,destfile,strlen(destfile)+1) == 0) && (strncmp(ptr->classes,ip->classes,strlen(ip->classes)+1) == 0))
-       {
-       succeed = 1;
-       }
-    }
- 
-if (succeed)
+if (IgnoredOrExcluded(image,sourcefile,ip->inclusions,ip->exclusions))
    {
-   snprintf(OUTPUT,CF_BUFSIZE*2,"Skipping excluded file %s class %s\n",destfile,ip->classes);
+   return;
+   }
+
+if (IsItemIn(VEXCLUDECACHE,destfile))
+   {
+   snprintf(OUTPUT,CF_BUFSIZE*2,"Skipping single-copied file %s class %s\n",destfile,ip->classes);
    CfLog(cfverbose,OUTPUT,"");
    return;
    }
-else
-   {
-   Debug2("file %s class %s was not excluded\n",destfile,ip->classes);
-   }
-
 
 if (ip->linktype != 'n')
    {
    lastnode=ReadLastNode(sourcefile);
+
    if (IsWildItemIn(VLINKCOPIES,lastnode) || IsWildItemIn(ip->symlink,lastnode))
       {
       Verbose("cfengine: copy item %s marked for linking instead\n",sourcefile);
@@ -789,211 +783,187 @@ if (ip->linktype != 'n')
             }
          else
             {
-            CheckCopiedFile(ip->cf_findertype,destfile,ip->plus,ip->minus,fixall,ip->uid,ip->gid,&deststatbuf,&sourcestatbuf,NULL,ip->acl_aliases);
+            CheckCopiedFile(ip->cf_findertype,destfile,ip->plus,ip->minus,ip->action,ip->uid,ip->gid,&deststatbuf,&sourcestatbuf,NULL,ip->acl_aliases);
             }     
          }      
       return;
       }
    }
  
- if (strcmp(ip->action,"silent") == 0)
-    {
-    silent = true;
-    }
- 
- memset(linkbuf,0,CF_BUFSIZE);
- 
- found = lstat(destfile,&deststatbuf);
- 
- if (found != -1)
-    {
-    if ((S_ISLNK(deststatbuf.st_mode) && (ip->linktype == 'n')) || (S_ISLNK(deststatbuf.st_mode)  && ! S_ISLNK(sourcestatbuf.st_mode)))
-       {
-       if (!S_ISLNK(sourcestatbuf.st_mode) && (ip->typecheck == 'y'))
-          {
-          printf("%s: image exists but destination type is silly (file/dir/link doesn't match)\n",VPREFIX);
-          printf("%s: source=%s, dest=%s\n",VPREFIX,sourcefile,destfile);
-          return;
-          }
-       if (DONTDO)
-          {
-          Verbose("Need to remove old symbolic link %s to make way for copy\n",destfile);
-          }
-       else 
-          {
-          if (unlink(destfile) == -1)
-             {
-             snprintf(OUTPUT,CF_BUFSIZE*2,"Couldn't remove link %s",destfile);
-             CfLog(cferror,OUTPUT,"unlink");
-             return;
-             }
-          Verbose("Removing old symbolic link %s to make way for copy\n",destfile);
-          found = -1;
-          }
-       } 
-    }
- 
- if (ip->size != CF_NOSIZE)
-    {
-    switch (ip->comp)
-       {
-       case '<':  if (sourcestatbuf.st_size > ip->size)
-          {
-          snprintf(OUTPUT,CF_BUFSIZE*2,"Source file %s is > %d bytes in copy (omitting)\n",sourcefile,ip->size);
-          CfLog(cfinform,OUTPUT,"");
-          return;
-          }
-           break;
-           
-       case '=':
-           if (sourcestatbuf.st_size != ip->size)
-              {
-              snprintf(OUTPUT,CF_BUFSIZE*2,"Source file %s is not %d bytes in copy (omitting)\n",sourcefile,ip->size);
-              CfLog(cfinform,OUTPUT,"");
-              return;
-              }
-           break;
-           
-       default:
-           if (sourcestatbuf.st_size < ip->size)
-              {
-              snprintf(OUTPUT,CF_BUFSIZE*2,"Source file %s is < %d bytes in copy (omitting)\n",sourcefile,ip->size);
-              CfLog(cfinform,OUTPUT,"");
-              return;
-              }
-           break;;
-       }
-    }
- 
- 
- if (found == -1)
-    {
-    if (strcmp(ip->action,"warn") == 0)
-       {
-       snprintf(OUTPUT,CF_BUFSIZE*2,"Image file %s is non-existent\n",destfile);
-       CfLog(cfinform,OUTPUT,"");
-       snprintf(OUTPUT,CF_BUFSIZE*2,"(should be copy of %s)\n",sourcefile);
-       CfLog(cfinform,OUTPUT,"");
-       return;
-       }
-    
-    if (S_ISREG(srcmode))
-       {
-       snprintf(OUTPUT,CF_BUFSIZE*2,"%s wasn't at destination (copying)",destfile);
-       if (DONTDO)
-          {
-          printf("Need this: %s\n",OUTPUT);
-          return;
-          }
-       
-       CfLog(cfverbose,OUTPUT,"");
-       snprintf(OUTPUT,CF_BUFSIZE*2,"Copying from %s:%s\n",server,sourcefile);
-       CfLog(cfinform,OUTPUT,"");
-       
-       if (CopyReg(sourcefile,destfile,sourcestatbuf,deststatbuf,ip))
-          {
-          if (stat(destfile,&deststatbuf) == -1)
-             {
-             snprintf(OUTPUT,CF_BUFSIZE*2,"Can't stat %s\n",destfile);
-             CfLog(cferror,OUTPUT,"stat");
-             }
-          else
-             {
-             CheckCopiedFile(ip->cf_findertype,destfile,ip->plus,ip->minus,fixall,ip->uid,ip->gid,&deststatbuf,&sourcestatbuf,NULL,ip->acl_aliases);
-             }
-          
-          AddMultipleClasses(ip->defines);
-          
-          for (ptr = VAUTODEFINE; ptr != NULL; ptr=ptr->next)
-             {
-             if (strncmp(ptr->name,destfile,strlen(destfile)+1) == 0) 
-                {
-                snprintf(OUTPUT,CF_BUFSIZE*2,"cfengine: image %s was set to autodefine %s\n",ptr->name,ptr->classes);
-                CfLog(cfinform,OUTPUT,"");
-                AddMultipleClasses(ptr->classes);
-                }
-             }
-          
-          if (VSINGLECOPY != NULL)
-             {
-             succeed = 1;
-             }
-          else
-             {
-             succeed = 0;
-             }
-          
-          for (ptr = VSINGLECOPY; ptr != NULL; ptr=ptr->next)
-             {
-             if ((strcmp(ptr->name,"on") != 0) && (strcmp(ptr->name,"true") != 0))
-                {
-                continue;
-                }
-             
-             if (strncmp(ptr->classes,ip->classes,strlen(ip->classes)+1) == 0)
-                {
-                for (ptr1 = VEXCLUDECACHE; ptr1 != NULL; ptr1=ptr1->next)
-                   {
-                   if ((strncmp(ptr1->name,destfile,strlen(destfile)+1) == 0) && (strncmp(ptr1->classes,ip->classes,strlen(ip->classes)+1) == 0))
-                      {
-                      succeed = 0;  
-                      }
-                   }
-                }
-             }
-          
-          if (succeed)
-             {
-             Debug("Appending image %s class %s to singlecopy list\n",destfile,ip->classes);
-             AppendItem(&VEXCLUDECACHE,destfile,ip->classes);
-             }
-          }
-       else
-          {
-          AddMultipleClasses(ip->failover);
-          }
-       
-       Debug2("Leaving ImageCopy\n");
-       return;
-       }
-    
-    if (S_ISFIFO (srcmode))
-       {
-#ifdef HAVE_MKFIFO
-       if (DONTDO)
-          {
-          Silent("%s: Make FIFO %s\n",VPREFIX,destfile);
-          }
-       else if (mkfifo (destfile,srcmode))
-          {
-          snprintf(OUTPUT,CF_BUFSIZE*2,"Cannot create fifo `%s'", destfile);
-          CfLog(cferror,OUTPUT,"mkfifo");
-          return;
-          }
-       
-       AddMultipleClasses(ip->defines);
-#endif
-       }
-    else
-       {
-       if (S_ISBLK (srcmode) || S_ISCHR (srcmode) || S_ISSOCK (srcmode))
-          {
-          if (DONTDO)
-             {
-             Silent("%s: Make BLK/CHR/SOCK %s\n",VPREFIX,destfile);
-             }
-          else if (mknod (destfile, srcmode, sourcestatbuf.st_rdev))
-             {
-             snprintf(OUTPUT,CF_BUFSIZE*2,"Cannot create special file `%s'",destfile);
-             CfLog(cferror,OUTPUT,"mknod");
-             return;
-             }
-          
-          AddMultipleClasses(ip->defines);
-         }
-       }
+if (strcmp(ip->action,"silent") == 0)
+   {
+   silent = true;
+   }
 
-   if (S_ISLNK(srcmode))
+memset(linkbuf,0,CF_BUFSIZE);
+
+found = lstat(destfile,&deststatbuf);
+
+if (found != -1)
+   {
+   if ((S_ISLNK(deststatbuf.st_mode) && (ip->linktype == 'n')) || (S_ISLNK(deststatbuf.st_mode) && ! S_ISLNK(sourcestatbuf.st_mode)))
+      {
+      if ((!S_ISLNK(sourcestatbuf.st_mode) && (ip->typecheck == 'y')) && (ip->linktype != 'n'))
+         {
+         printf("%s: image exists but destination type is silly (file/dir/link doesn't match) - %c\n",VPREFIX,ip->linktype);
+         printf("%s: source=%s, dest=%s\n",VPREFIX,sourcefile,destfile);
+         return;
+         }
+      
+      if (DONTDO)
+         {
+         Verbose("Need to remove old symbolic link %s to make way for copy\n",destfile);
+         }
+      else 
+         {
+         if (unlink(destfile) == -1)
+            {
+            snprintf(OUTPUT,CF_BUFSIZE*2,"Couldn't remove link %s",destfile);
+            CfLog(cferror,OUTPUT,"unlink");
+            return;
+            }
+         Verbose("Removing old symbolic link %s to make way for copy\n",destfile);
+         found = -1;
+         }
+      } 
+   }
+
+if (ip->size != CF_NOSIZE)
+   {
+   switch (ip->comp)
+      {
+      case '<':  if (sourcestatbuf.st_size > ip->size)
+         {
+         snprintf(OUTPUT,CF_BUFSIZE*2,"Source file %s is > %d bytes in copy (omitting)\n",sourcefile,ip->size);
+         CfLog(cfinform,OUTPUT,"");
+         return;
+         }
+          break;
+          
+      case '=':
+          if (sourcestatbuf.st_size != ip->size)
+             {
+             snprintf(OUTPUT,CF_BUFSIZE*2,"Source file %s is not %d bytes in copy (omitting)\n",sourcefile,ip->size);
+             CfLog(cfinform,OUTPUT,"");
+             return;
+             }
+          break;
+          
+      default:
+          if (sourcestatbuf.st_size < ip->size)
+             {
+             snprintf(OUTPUT,CF_BUFSIZE*2,"Source file %s is < %d bytes in copy (omitting)\n",sourcefile,ip->size);
+             CfLog(cfinform,OUTPUT,"");
+             return;
+             }
+          break;
+      }
+   }
+
+
+if (found == -1)
+   {
+   if (strcmp(ip->action,"warn") == 0)
+      {
+      snprintf(OUTPUT,CF_BUFSIZE*2,"Image file %s is non-existent\n",destfile);
+      CfLog(cferror,OUTPUT,"");
+      snprintf(OUTPUT,CF_BUFSIZE*2,"(should be copy of %s)\n",sourcefile);
+      CfLog(cferror,OUTPUT,"");
+      return;
+      }
+   
+   if (S_ISREG(srcmode) || (S_ISLNK(srcmode) && ip->linktype == 'n'))
+      {
+      snprintf(OUTPUT,CF_BUFSIZE*2,"%s wasn't at destination (copying)",destfile);
+      if (DONTDO)
+         {
+         printf("Need this: %s\n",OUTPUT);
+         return;
+         }
+      
+      CfLog(cfverbose,OUTPUT,"");
+      snprintf(OUTPUT,CF_BUFSIZE*2,"Copying from %s:%s\n",server,sourcefile);
+      CfLog(cfinform,OUTPUT,"");
+      
+      if (CopyReg(sourcefile,destfile,sourcestatbuf,deststatbuf,ip))
+         {
+         if (stat(destfile,&deststatbuf) == -1)
+            {
+            snprintf(OUTPUT,CF_BUFSIZE*2,"Can't stat %s\n",destfile);
+            CfLog(cferror,OUTPUT,"stat");
+            }
+         else
+            {
+            CheckCopiedFile(ip->cf_findertype,destfile,ip->plus,ip->minus,ip->action,ip->uid,ip->gid,&deststatbuf,&sourcestatbuf,NULL,ip->acl_aliases);
+            }
+         
+         AddMultipleClasses(ip->defines);
+         
+         if (ALL_SINGLECOPY || IsWildItemIn(VSINGLECOPY,destfile))
+            {
+            if (!IsItemIn(VEXCLUDECACHE,destfile))
+               {
+               Debug("Appending image %s class %s to singlecopy list\n",destfile,ip->classes);
+               PrependItem(&VEXCLUDECACHE,destfile,NULL);
+               }
+            }         
+
+         for (ptr = VAUTODEFINE; ptr != NULL; ptr=ptr->next)
+            {
+            if (WildMatch(ptr->name,destfile))
+               {
+               snprintf(OUTPUT,CF_BUFSIZE*2,"Image %s was set to autodefine class %s\n",ptr->name,ptr->classes);
+               CfLog(cfinform,OUTPUT,"");
+               AddMultipleClasses(ptr->classes);
+               }
+            } 
+         }
+      else
+         {
+         AddMultipleClasses(ip->failover);
+         }
+      
+      Debug2("Leaving ImageCopy\n");
+      return;
+      }
+   
+   if (S_ISFIFO (srcmode))
+      {
+#ifdef HAVE_MKFIFO
+      if (DONTDO)
+         {
+         Silent("%s: Make FIFO %s\n",VPREFIX,destfile);
+         }
+      else if (mkfifo (destfile,srcmode))
+         {
+         snprintf(OUTPUT,CF_BUFSIZE*2,"Cannot create fifo `%s'", destfile);
+         CfLog(cferror,OUTPUT,"mkfifo");
+         return;
+         }
+      
+      AddMultipleClasses(ip->defines);
+#endif
+      }
+   else
+      {
+      if (S_ISBLK (srcmode) || S_ISCHR (srcmode) || S_ISSOCK (srcmode))
+         {
+         if (DONTDO)
+            {
+            Silent("%s: Make BLK/CHR/SOCK %s\n",VPREFIX,destfile);
+            }
+         else if (mknod (destfile, srcmode, sourcestatbuf.st_rdev))
+            {
+            snprintf(OUTPUT,CF_BUFSIZE*2,"Cannot create special file `%s'",destfile);
+            CfLog(cferror,OUTPUT,"mknod");
+            return;
+            }
+         
+         AddMultipleClasses(ip->defines);
+         }
+      }
+   
+   if (S_ISLNK(srcmode) && ip->linktype != 'n')
       {
       if (cfreadlink(sourcefile,linkbuf,CF_BUFSIZE,ip) == -1)
          {
@@ -1033,8 +1003,12 @@ if (ip->linktype != 'n')
          case 'a':
              succeed = AbsoluteLink(destfile,linkbuf,NULL,NULL,NULL,true,&empty);
              break;
+
+         case 'n': /* Link copied instead */
+             break;
+             
          default:
-             printf("cfengine: internal error, link type was [%c] in ImageCopy\n",ip->linktype);
+             printf("cfengine: internal error, link type was [%c] in ImageCopy 2\n",ip->linktype);
              return;
          }
       
@@ -1047,272 +1021,236 @@ if (ip->linktype != 'n')
             }
          else
             {
-            CheckCopiedFile(ip->cf_findertype,destfile,ip->plus,ip->minus,fixall,ip->uid,ip->gid,&deststatbuf,&sourcestatbuf,NULL,ip->acl_aliases);
+            CheckCopiedFile(ip->cf_findertype,destfile,ip->plus,ip->minus,ip->action,ip->uid,ip->gid,&deststatbuf,&sourcestatbuf,NULL,ip->acl_aliases);
             }
          AddMultipleClasses(ip->defines);
          }
       }
-    }
- else
-    {
-    Debug("Destination file %s exists\n",destfile);
-    
-    if (ip->force == 'n')
-       {
-       switch (ip->type)
-          {
-          case 'c':
-              if (S_ISREG(deststatbuf.st_mode) && S_ISREG(srcmode))
-                 {
-                 ok_to_copy = CompareCheckSums(sourcefile,destfile,ip,&sourcestatbuf,&deststatbuf);
-                 }      
-              else
-                 {
-                 CfLog(cfinform,"Checksum comparison replaced by ctime: files not regular\n","");
-                 snprintf(OUTPUT,CF_BUFSIZE*2,"%s -> %s\n",sourcefile,destfile);
-                 CfLog(cfinform,OUTPUT,"");
-                 ok_to_copy = (deststatbuf.st_ctime < sourcestatbuf.st_ctime)||(deststatbuf.st_mtime < sourcestatbuf.st_mtime);
-                 }
-              
-              if (ok_to_copy && strcmp(ip->action,"warn") == 0)
-                 { 
-                 snprintf(OUTPUT,CF_BUFSIZE*2,"Image file %s has a wrong MD5 checksum (should be copy of %s)\n",destfile,sourcefile);
-                 CfLog(cfinform,OUTPUT,"");
-                 return;
-                 }
-              break;
-              
-          case 'b':
-              if (S_ISREG(deststatbuf.st_mode) && S_ISREG(srcmode))
-                 {
-                 ok_to_copy = CompareBinarySums(sourcefile,destfile,ip,&sourcestatbuf,&deststatbuf);
-                 }      
-              else
-                 {
-                 CfLog(cfinform,"Byte comparison replaced by ctime: files not regular\n","");
-                 snprintf(OUTPUT,CF_BUFSIZE*2,"%s -> %s\n",sourcefile,destfile);
-                 CfLog(cfinform,OUTPUT,"");
-                 ok_to_copy = (deststatbuf.st_ctime < sourcestatbuf.st_ctime)||(deststatbuf.st_mtime < sourcestatbuf.st_mtime);
-                 }
-              
-              if (ok_to_copy && strcmp(ip->action,"warn") == 0)
-                 { 
-                 snprintf(OUTPUT,CF_BUFSIZE*2,"Image file %s has a wrong binary checksum (should be copy of %s)\n",destfile,sourcefile);
-                 CfLog(cferror,OUTPUT,"");
-                 return;
-                 }
-              break;
-              
-          case 'm':
-              ok_to_copy = (deststatbuf.st_mtime < sourcestatbuf.st_mtime);
-              
-              if (ok_to_copy && strcmp(ip->action,"warn") == 0)
-                 { 
-                 snprintf(OUTPUT,CF_BUFSIZE*2,"Image file %s out of date (should be copy of %s)\n",destfile,sourcefile);
-                 CfLog(cferror,OUTPUT,"");
-                 return;
-                 }
-              break;
-
-          case 'a':
-
-              ok_to_copy = (deststatbuf.st_ctime < sourcestatbuf.st_ctime)||(deststatbuf.st_mtime < sourcestatbuf.st_mtime)||CompareBinarySums(sourcefile,destfile,ip,&sourcestatbuf,&deststatbuf);;
-              
-              if (ok_to_copy && strcmp(ip->action,"warn") == 0)
-                 { 
-                 snprintf(OUTPUT,CF_BUFSIZE*2,"Image file %s is updated somehow (should be copy of %s)\n",destfile,sourcefile);
-                 CfLog(cferror,OUTPUT,"");
-                 return;
-                 }
-              break;
-              
-          default:
-              ok_to_copy = (deststatbuf.st_ctime < sourcestatbuf.st_ctime)||(deststatbuf.st_mtime < sourcestatbuf.st_mtime);
-              
-              if (ok_to_copy && strcmp(ip->action,"warn") == 0)
-                 { 
-                 snprintf(OUTPUT,CF_BUFSIZE*2,"Image file %s out of date (should be copy of %s)\n",destfile,sourcefile);
-                 CfLog(cferror,OUTPUT,"");
-                 return;
-                 }
-              break;
-          }
-       }
-    
-    
-    if (ip->typecheck == 'y')
-       {
-       if ((S_ISDIR(deststatbuf.st_mode)  && ! S_ISDIR(sourcestatbuf.st_mode))  ||
-           (S_ISREG(deststatbuf.st_mode)  && ! S_ISREG(sourcestatbuf.st_mode))  ||
-           (S_ISBLK(deststatbuf.st_mode)  && ! S_ISBLK(sourcestatbuf.st_mode))  ||
-           (S_ISCHR(deststatbuf.st_mode)  && ! S_ISCHR(sourcestatbuf.st_mode))  ||
-           (S_ISSOCK(deststatbuf.st_mode) && ! S_ISSOCK(sourcestatbuf.st_mode)) ||
-           (S_ISFIFO(deststatbuf.st_mode) && ! S_ISFIFO(sourcestatbuf.st_mode)) ||
-           (S_ISLNK(deststatbuf.st_mode)  && ! S_ISLNK(sourcestatbuf.st_mode)))
-           
-          {
-          printf("%s: image exists but destination type is silly (file/dir/link doesn't match)\n",VPREFIX);
-          printf("%s: source=%s, dest=%s\n",VPREFIX,sourcefile,destfile);
-          return;
-          }
-       }
-    
-    if ((ip->force == 'y') || ok_to_copy || S_ISLNK(sourcestatbuf.st_mode))  /* Always check links */
-       {
-       if (S_ISREG(srcmode))
-          {
-          snprintf(OUTPUT,CF_BUFSIZE*2,"Update of image %s from master %s on %s",destfile,sourcefile,server);
-          
-          if (DONTDO)
-             {
-             printf("Need: %s\n",OUTPUT);
-             return;
-             }
-          
-          CfLog(cfinform,OUTPUT,"");
-          
-          AddMultipleClasses(ip->defines);
-          
-          for (ptr = VAUTODEFINE; ptr != NULL; ptr=ptr->next)
-             {
-             if (strncmp(ptr->name,destfile,strlen(destfile)+1) == 0)
+   }
+else
+   {
+   Debug("Destination file %s exists\n",destfile);
+   
+   if (ip->force == 'n')
+      {
+      switch (ip->type)
+         {
+         case 'c':
+             if (S_ISREG(deststatbuf.st_mode) && S_ISREG(srcmode))
                 {
-                snprintf(OUTPUT,CF_BUFSIZE*2,"cfengine: image %s was set to autodefine %s\n",ptr->name,ptr->classes);
+                ok_to_copy = CompareCheckSums(sourcefile,destfile,ip,&sourcestatbuf,&deststatbuf);
+                }      
+             else
+                {
+                CfLog(cfinform,"Checksum comparison replaced by ctime: files not regular\n","");
+                snprintf(OUTPUT,CF_BUFSIZE*2,"%s -> %s\n",sourcefile,destfile);
                 CfLog(cfinform,OUTPUT,"");
-                AddMultipleClasses(ptr->classes);
+                ok_to_copy = (deststatbuf.st_ctime < sourcestatbuf.st_ctime)||(deststatbuf.st_mtime < sourcestatbuf.st_mtime);
                 }
-             } 
-          
-          if (CopyReg(sourcefile,destfile,sourcestatbuf,deststatbuf,ip))
-             {
-             if (stat(destfile,&deststatbuf) == -1)
+             
+             if (ok_to_copy && strcmp(ip->action,"warn") == 0)
+                { 
+                snprintf(OUTPUT,CF_BUFSIZE*2,"Image file %s has a wrong MD5 checksum (should be copy of %s)\n",destfile,sourcefile);
+                CfLog(cfinform,OUTPUT,"");
+                return;
+                }
+             break;
+             
+         case 'b':
+             if (S_ISREG(deststatbuf.st_mode) && S_ISREG(srcmode))
                 {
-                snprintf(OUTPUT,CF_BUFSIZE*2,"Can't stat %s\n",destfile);
-                CfLog(cferror,OUTPUT,"stat");
-                }
+                ok_to_copy = CompareBinarySums(sourcefile,destfile,ip,&sourcestatbuf,&deststatbuf);
+                }      
              else
                 {
-                CheckCopiedFile(ip->cf_findertype,destfile,ip->plus,ip->minus,fixall,ip->uid,ip->gid,&deststatbuf,&sourcestatbuf,NULL,ip->acl_aliases);
+                CfLog(cfinform,"Byte comparison replaced by ctime: files not regular\n","");
+                snprintf(OUTPUT,CF_BUFSIZE*2,"%s -> %s\n",sourcefile,destfile);
+                CfLog(cfinform,OUTPUT,"");
+                ok_to_copy = (deststatbuf.st_ctime < sourcestatbuf.st_ctime)||(deststatbuf.st_mtime < sourcestatbuf.st_mtime);
                 }
              
-             if (VSINGLECOPY != NULL)
-                {
-                succeed = 1;
-                }
-             else
-                {
-                succeed = 0;
+             if (ok_to_copy && strcmp(ip->action,"warn") == 0)
+                { 
+                snprintf(OUTPUT,CF_BUFSIZE*2,"Image file %s has a wrong binary checksum (should be copy of %s)\n",destfile,sourcefile);
+                CfLog(cferror,OUTPUT,"");
+                return;
                 }
+             break;
              
-             for (ptr = VSINGLECOPY; ptr != NULL; ptr=ptr->next)
-                {
-                if (strncmp(ptr->classes,ip->classes,strlen(ip->classes)+1) == 0)
+         case 'm':
+             ok_to_copy = (deststatbuf.st_mtime < sourcestatbuf.st_mtime);
+             
+             if (ok_to_copy && strcmp(ip->action,"warn") == 0)
+                { 
+                snprintf(OUTPUT,CF_BUFSIZE*2,"Image file %s out of date (should be copy of %s)\n",destfile,sourcefile);
+                CfLog(cferror,OUTPUT,"");
+                return;
+                }
+             break;
+             
+         case 'a':
+             
+             ok_to_copy = (deststatbuf.st_ctime < sourcestatbuf.st_ctime)||(deststatbuf.st_mtime < sourcestatbuf.st_mtime)||CompareBinarySums(sourcefile,destfile,ip,&sourcestatbuf,&deststatbuf);
+             
+             if (ok_to_copy && strcmp(ip->action,"warn") == 0)
+                { 
+                snprintf(OUTPUT,CF_BUFSIZE*2,"Image file %s is updated somehow (should be copy of %s)\n",destfile,sourcefile);
+                CfLog(cferror,OUTPUT,"");
+                return;
+                }
+             break;
+              
+         default:
+             ok_to_copy = (deststatbuf.st_ctime < sourcestatbuf.st_ctime)||(deststatbuf.st_mtime < sourcestatbuf.st_mtime);
+             
+             if (ok_to_copy && strcmp(ip->action,"warn") == 0)
+                { 
+                snprintf(OUTPUT,CF_BUFSIZE*2,"Image file %s out of date (should be copy of %s)\n",destfile,sourcefile);
+                CfLog(cferror,OUTPUT,"");
+                return;
+                }
+             break;
+         }
+      }
+   
+   
+   if (ip->typecheck == 'y' && ip->linktype != 'n')
+      {
+      if ((S_ISDIR(deststatbuf.st_mode)  && ! S_ISDIR(sourcestatbuf.st_mode))  ||
+          (S_ISREG(deststatbuf.st_mode)  && ! S_ISREG(sourcestatbuf.st_mode))  ||
+          (S_ISBLK(deststatbuf.st_mode)  && ! S_ISBLK(sourcestatbuf.st_mode))  ||
+          (S_ISCHR(deststatbuf.st_mode)  && ! S_ISCHR(sourcestatbuf.st_mode))  ||
+          (S_ISSOCK(deststatbuf.st_mode) && ! S_ISSOCK(sourcestatbuf.st_mode)) ||
+          (S_ISFIFO(deststatbuf.st_mode) && ! S_ISFIFO(sourcestatbuf.st_mode)) ||
+          (S_ISLNK(deststatbuf.st_mode)  && ! S_ISLNK(sourcestatbuf.st_mode)))
+          
+         {
+         printf("%s: image exists but destination type is silly (file/dir/link doesn't match)\n",VPREFIX);
+         printf("%s: source=%s, dest=%s\n",VPREFIX,sourcefile,destfile);
+         return;
+         }
+      }
+   
+   if ((ip->force == 'y') || ok_to_copy || S_ISLNK(sourcestatbuf.st_mode))  /* Always check links */
+      {
+      if (S_ISREG(srcmode) || ip->linktype == 'n')
+         {
+         snprintf(OUTPUT,CF_BUFSIZE*2,"Update of image %s from master %s on %s",destfile,sourcefile,server);
+         
+         if (DONTDO)
+            {
+            printf("Need: %s\n",OUTPUT);
+            return;
+            }
+         
+         CfLog(cfinform,OUTPUT,"");
+         
+         AddMultipleClasses(ip->defines);
+         
+         for (ptr = VAUTODEFINE; ptr != NULL; ptr=ptr->next)
+            {
+            if (WildMatch(ptr->name,destfile))
+               {
+               snprintf(OUTPUT,CF_BUFSIZE*2,"Image %s was set to autodefine class %s\n",ptr->name,ptr->classes);
+               CfLog(cfinform,OUTPUT,"");
+               AddMultipleClasses(ptr->classes);
+               }
+            } 
+         
+         if (CopyReg(sourcefile,destfile,sourcestatbuf,deststatbuf,ip))
+            {
+            if (stat(destfile,&deststatbuf) == -1)
+               {
+               snprintf(OUTPUT,CF_BUFSIZE*2,"Can't stat %s\n",destfile);
+               CfLog(cferror,OUTPUT,"stat");
+               }
+            else
+               {
+               CheckCopiedFile(ip->cf_findertype,destfile,ip->plus,ip->minus,ip->action,ip->uid,ip->gid,&deststatbuf,&sourcestatbuf,NULL,ip->acl_aliases);
+               }
+            
+            if (ALL_SINGLECOPY || IsWildItemIn(VSINGLECOPY,destfile))
+               {
+               if (!IsItemIn(VEXCLUDECACHE,destfile))
+                  {
+                  Debug("Appending image %s class %s to singlecopy list\n",destfile,ip->classes);
+                  PrependItem(&VEXCLUDECACHE,destfile,NULL);
+                  }
+               }                      
+            } 
+         else
+            {
+            AddMultipleClasses(ip->failover);
+            }
+         
+         return;
+         }
+      
+      if (S_ISLNK(sourcestatbuf.st_mode))
+         {
+         if (cfreadlink(sourcefile,linkbuf,CF_BUFSIZE,ip) == -1)
+            {
+            snprintf(OUTPUT,CF_BUFSIZE*2,"Can't readlink %s\n",sourcefile);
+            CfLog(cferror,OUTPUT,"");
+            return;
+            }
+         
+         snprintf(OUTPUT,CF_BUFSIZE*2,"Checking link from %s to %s\n",destfile,linkbuf);
+         CfLog(cfverbose,OUTPUT,"");
+         
+         enforcelinks = ENFORCELINKS;
+         ENFORCELINKS = true;
+         
+         switch (ip->linktype)
+            {
+            case 's':
+                if (*linkbuf == '.')
                    {
-                   for (ptr1 = VEXCLUDECACHE; ptr1 != NULL; ptr1=ptr1->next)
-                      {
-                      if ((strncmp(ptr1->name,destfile,strlen(destfile)+1) == 0) && (strncmp(ptr1->classes,ip->classes,strlen(ip->classes)+1) == 0))
-                         {
-                         succeed = 0;
-                         }
-                      }
+                   succeed = RelativeLink(destfile,linkbuf,NULL,NULL,NULL,true,&empty);
                    }
-                }
-             
-             if (succeed)
-                {
-                AppendItem(&VEXCLUDECACHE,destfile,ip->classes);
-                }
-             } 
-          else
-             {
-             AddMultipleClasses(ip->failover);
-             }
-          
-          return;
-          }
-       
-       if (S_ISLNK(sourcestatbuf.st_mode))
-          {
-          if (cfreadlink(sourcefile,linkbuf,CF_BUFSIZE,ip) == -1)
-             {
-             snprintf(OUTPUT,CF_BUFSIZE*2,"Can't readlink %s\n",sourcefile);
-             CfLog(cferror,OUTPUT,"");
-             return;
-             }
-          
-          snprintf(OUTPUT,CF_BUFSIZE*2,"Checking link from %s to %s\n",destfile,linkbuf);
-          CfLog(cfverbose,OUTPUT,"");
-          
-          enforcelinks = ENFORCELINKS;
-          ENFORCELINKS = true;
-          
-          switch (ip->linktype)
-             {
-             case 's':
-                 if (*linkbuf == '.')
-                    {
-                    succeed = RelativeLink(destfile,linkbuf,NULL,NULL,NULL,true,&empty);
-                    }
-                 else
-                    {
-                    succeed = LinkFiles(destfile,linkbuf,NULL,NULL,NULL,true,&empty);
-                    }
-                 break;
-             case 'r':
-                 succeed = RelativeLink(destfile,linkbuf,NULL,NULL,NULL,true,&empty);
-                 break;
-             case 'a':
-                 succeed = AbsoluteLink(destfile,linkbuf,NULL,NULL,NULL,true,&empty);
-                 break;
-             default:
-                 printf("cfengine: internal error, link type was [%c] in ImageCopy\n",ip->linktype);
-                 return;
-             }
-          
-          if (succeed)
-             {
-             CheckCopiedFile(ip->cf_findertype,destfile,ip->plus,ip->minus,fixall,ip->uid,ip->gid,&deststatbuf,&sourcestatbuf,NULL,ip->acl_aliases);
-             }
-          ENFORCELINKS = enforcelinks;
-          }
-       }
-    else
-       {
-       CheckCopiedFile(ip->cf_findertype,destfile,ip->plus,ip->minus,fixall,ip->uid,ip->gid,&deststatbuf,&sourcestatbuf,NULL,ip->acl_aliases);
-       
-       if (VSINGLECOPY != NULL)
-          {
-          succeed = 1;
-          }
-       else
-          {
-          succeed = 0;
-          }
-       
-       for (ptr = VSINGLECOPY; ptr != NULL; ptr=ptr->next)
-          {
-          if (strncmp(ptr->classes,ip->classes,strlen(ip->classes)+1) == 0)
-             {
-             for (ptr1 = VEXCLUDECACHE; ptr1 != NULL; ptr1=ptr1->next)
-                {
-                if ((strncmp(ptr1->name,destfile,strlen(destfile)+1) == 0) && (strncmp(ptr1->classes,ip->classes,strlen(ip->classes)+1) == 0))
+                else
                    {
-                   succeed = 0;
+                   succeed = LinkFiles(destfile,linkbuf,NULL,NULL,NULL,true,&empty);
                    }
-                }
-             }
+                break;
+            case 'r':
+                succeed = RelativeLink(destfile,linkbuf,NULL,NULL,NULL,true,&empty);
+                break;
+            case 'a':
+                succeed = AbsoluteLink(destfile,linkbuf,NULL,NULL,NULL,true,&empty);
+                break;
+            default:
+                printf("cfengine: internal error, link type was [%c] in ImageCopy\n",ip->linktype);
+                return;
+            }
+         
+         if (succeed)
+            {
+            CheckCopiedFile(ip->cf_findertype,destfile,ip->plus,ip->minus,ip->action,ip->uid,ip->gid,&deststatbuf,&sourcestatbuf,NULL,ip->acl_aliases);
+            }
+         ENFORCELINKS = enforcelinks;
+         }
+      }
+   else
+      {
+      CheckCopiedFile(ip->cf_findertype,destfile,ip->plus,ip->minus,ip->action,ip->uid,ip->gid,&deststatbuf,&sourcestatbuf,NULL,ip->acl_aliases);
+      
+      /* Now we have to check for single copy, even though nothing was copied
+         otherwise we can get oscillations between multipe versions if type is based on a checksum */
+      
+      if (ALL_SINGLECOPY || IsWildItemIn(VSINGLECOPY,destfile))
+         {
+         if (!IsItemIn(VEXCLUDECACHE,destfile))
+            {
+            Debug("Appending image %s class %s to singlecopy list\n",destfile,ip->classes);
+            PrependItem(&VEXCLUDECACHE,destfile,NULL);
+            }
           }
-       
-       if (succeed)
-          {
-          Debug("Appending image %s class %s to singlecopy list\n",destfile,ip->classes);
-          AppendItem(&VEXCLUDECACHE,destfile,ip->classes);
-          }
-       
-       Debug("Image file is up to date: %s\n",destfile);
-       AddMultipleClasses(ip->elsedef);
-       }
-    }
+      
+      Debug("Image file is up to date: %s\n",destfile);
+      AddMultipleClasses(ip->elsedef);
+      }
+   }
 }
 
 /*********************************************************************/
@@ -1818,7 +1756,7 @@ if (rsrcfork)
     
 #ifdef DARWIN
     }
-#endif
+ #endif
  
  if ((IMAGEBACKUP != 'n') && backupisdir)
     {
