@@ -36,7 +36,7 @@
 
 /*****************************************************************************/
 
-int RemoteConnect(char *host,char forceipv4)          /* Handle ipv4 or ipv6 connection */
+int RemoteConnect(char *host,char forceipv4,short oldport, char *newport) 
 
 { int err;
 
@@ -53,7 +53,7 @@ if (forceipv4 == 'n')
    query.ai_family = AF_UNSPEC;
    query.ai_socktype = SOCK_STREAM;
 
-   if ((err = getaddrinfo(host,STR_CFENGINEPORT,&query,&response)) != 0)
+   if ((err = getaddrinfo(host,newport,&query,&response)) != 0)
       {
       snprintf(OUTPUT,CF_BUFSIZE,"Unable to find hostname or cfengine service: (%s/%s) %s",host,STR_CFENGINEPORT,gai_strerror(err));
       CfLog(cfinform,OUTPUT,"");
@@ -62,7 +62,7 @@ if (forceipv4 == 'n')
    
    for (ap = response; ap != NULL; ap = ap->ai_next)
       {
-      Verbose("Connect to %s = %s on port cfengine\n",host,sockaddr_ntop(ap->ai_addr));
+      Verbose("Connect to %s = %s on port %s\n",host,sockaddr_ntop(ap->ai_addr),newport);
       
       if ((CONN->sd = socket(ap->ai_family,ap->ai_socktype,ap->ai_protocol)) == -1)
          {
@@ -154,7 +154,7 @@ if (forceipv4 == 'n')
       return false;
       }
    
-   cin.sin_port = SHORT_CFENGINEPORT;
+   cin.sin_port = oldport;
    cin.sin_addr.s_addr = ((struct in_addr *)(hp->h_addr))->s_addr;
    cin.sin_family = AF_INET; 
    
@@ -208,7 +208,7 @@ if ((server = getservbyname(CFENGINE_SERVICE,"tcp")) == NULL)
    }
 else
    {
-   SHORT_CFENGINEPORT = htons(server->s_port);
+   SHORT_CFENGINEPORT = server->s_port;
    }
 
 Verbose("Setting cfengine new port to %u\n",SHORT_CFENGINEPORT);
@@ -227,7 +227,7 @@ if ((server = getservbyname(CFENGINE_SERVICE,"tcp")) == NULL)
    }
 else
    {
-   snprintf(STR_CFENGINEPORT,15,"%d",htons(server->s_port));
+   snprintf(STR_CFENGINEPORT,15,"%d",ntohs(server->s_port));
    }
 
 Verbose("Setting cfengine old port to %s\n",STR_CFENGINEPORT);
@@ -237,7 +237,7 @@ Verbose("Setting cfengine old port to %s\n",STR_CFENGINEPORT);
 
 char *Hostname2IPString(char *hostname)
 
-{ static char ipbuffer[65];
+{ static char ipbuffer[CF_SMALLBUF];
   int err;
  
 #if defined(HAVE_GETADDRINFO) && !defined(DARWIN)
@@ -248,7 +248,7 @@ char *Hostname2IPString(char *hostname)
  query.ai_family = AF_UNSPEC;
  query.ai_socktype = SOCK_STREAM;
 
- memset(ipbuffer,0,63);
+ memset(ipbuffer,0,CF_SMALLBUF-1);
  
 if ((err = getaddrinfo(hostname,NULL,&query,&response)) != 0)
    {
@@ -264,7 +264,7 @@ for (ap = response; ap != NULL; ap = ap->ai_next)
 
    if (strlen(ipbuffer) == 0)
       {
-      snprintf(ipbuffer,63,"Empty IP result for %s",hostname);
+      snprintf(ipbuffer,CF_SMALLBUF-1,"Empty IP result for %s",hostname);
       }
    freeaddrinfo(response);   
    return ipbuffer;
@@ -274,18 +274,18 @@ for (ap = response; ap != NULL; ap = ap->ai_next)
  struct sockaddr_in cin;
  memset(&cin,0,sizeof(cin));
 
- memset(ipbuffer,0,63);
+ memset(ipbuffer,0,CF_SMALLBUF-1);
 
 if ((hp = gethostbyname(hostname)) != NULL)
    {
    cin.sin_addr.s_addr = ((struct in_addr *)(hp->h_addr))->s_addr;
-   strncpy(ipbuffer,inet_ntoa(cin.sin_addr),63);
+   strncpy(ipbuffer,inet_ntoa(cin.sin_addr),CF_SMALLBUF-1);
    Verbose("Found address (%s) for host %s\n",ipbuffer,hostname);
    return ipbuffer;
    }
 #endif
    
-snprintf(ipbuffer,63,"Unknown IP %s",hostname);
+snprintf(ipbuffer,CF_SMALLBUF-1,"Unknown IP %s",hostname);
 return ipbuffer;
 }
 
@@ -294,7 +294,7 @@ return ipbuffer;
 
 char *IPString2Hostname(char *ipaddress)
 
-{ static char hostbuffer[128];
+{ static char hostbuffer[MAXHOSTNAMELEN];
   int err;
 
 #if defined(HAVE_GETADDRINFO) && !defined(DARWIN)
@@ -306,21 +306,21 @@ memset(&response,0,sizeof(response));
 
 query.ai_flags = AI_CANONNAME;
 
-memset(hostbuffer,0,128);
+memset(hostbuffer,0,MAXHOSTNAMELEN);
 
 if ((err = getaddrinfo(ipaddress,NULL,&query,&response)) != 0)
    {
    snprintf(OUTPUT,CF_BUFSIZE,"Unable to lookup IP address (%s): %s",ipaddress,gai_strerror(err));
    CfLog(cferror,OUTPUT,"");
-   snprintf(hostbuffer,127,"(Non registered IP)"); 
+   snprintf(hostbuffer,MAXHOSTNAMELEN-1,"(Non registered IP)"); 
    return hostbuffer;
    }
 
 for (ap = response; ap != NULL; ap = ap->ai_next)
    {   
-   if ((err = getnameinfo(ap->ai_addr,ap->ai_addrlen,hostbuffer,127,0,0,0)) != 0)
+   if ((err = getnameinfo(ap->ai_addr,ap->ai_addrlen,hostbuffer,MAXHOSTNAMELEN,0,0,0)) != 0)
       {
-      snprintf(hostbuffer,127,"(Non registered IP)");
+      snprintf(hostbuffer,MAXHOSTNAMELEN-1,"(Non registered IP)");
       freeaddrinfo(response);
       return hostbuffer;
       }
@@ -330,13 +330,15 @@ for (ap = response; ap != NULL; ap = ap->ai_next)
    return hostbuffer;
    }
 
- snprintf(hostbuffer,127,"(Non registered IP)"); 
+ snprintf(hostbuffer,MAXHOSTNAMELEN-1,"(Non registered IP)");
+ 
 #else
+
 struct hostent *hp;
 struct sockaddr_in myaddr;
 struct in_addr iaddr;
   
-memset(hostbuffer,0,128);
+memset(hostbuffer,0,MAXHOSTNAMELEN);
 
 if ((iaddr.s_addr = inet_addr(ipaddress)) != -1)
    {
@@ -348,7 +350,7 @@ if ((iaddr.s_addr = inet_addr(ipaddress)) != -1)
       return hostbuffer;
       }
 
-   strncpy(hostbuffer,hp->h_name,CF_MAXVARSIZE);
+   strncpy(hostbuffer,hp->h_name,MAXHOSTNAMELEN-1);
    }
 else
    {
@@ -610,3 +612,41 @@ while (dbcp->c_get(dbcp, &key, &value, DB_NEXT) == 0)
 dbcp->c_close(dbcp);
 dbp->close(dbp,0);
 }
+
+
+/*********************************************************************/
+
+struct cfagent_connection *NewAgentConn()
+
+{ struct cfagent_connection *ap;
+
+if ((ap = (struct cfagent_connection *)malloc(sizeof(struct cfagent_connection))) == NULL)
+   {
+   return NULL;
+   }
+
+Debug("New server connection...\n");
+ap->sd = CF_NOT_CONNECTED;
+ap->family = AF_INET; 
+ap->trust = false;
+ap->localip[0] = '\0';
+ap->remoteip[0] = '\0';
+ap->session_key = NULL;
+ap->error = false; 
+return ap;
+};
+
+/*********************************************************************/
+
+void DeleteAgentConn(struct cfagent_connection *ap)
+
+{
+if (ap->session_key != NULL)
+   {
+   free(ap->session_key);
+   }
+
+free(ap);
+ap = NULL; 
+}
+
