@@ -45,7 +45,8 @@ struct Item *ListFromArgs(char *string)
 /* Splits a string with quoted components etc */
 
 { struct Item *ip = NULL;
-  int dquote_level = 0,i = 0;
+  int inquotes_level = 0,i = 0;
+  int inquote_level = 0;
   int paren_level = 0;
   char *sp,lastch = '\0';
   char item[CF_BUFSIZE];
@@ -60,38 +61,59 @@ for (sp = string; *sp != '\0'; sp++)
           
           if (lastch == '\\')  /* Escaped quote */
              {
-             sp--;
-             *sp = ')';
-             continue;
+             if (inquotes_level == 0)
+                {
+                yyerror("Quoting error - escaped quote outside string");
+                FatalError("Unrecoverable");
+                }
+             
+             i--;
              }
           else
              {
-             if (dquote_level == 0)
-                {
-                dquote_level = 1;
-                continue;
-                }
-             else
-                {
-                dquote_level = 0;
-                continue;
-                }
+             inquotes_level = 1 - inquotes_level; /* toggle */
+             continue;
              }
           break;
+
+      case '\'':
           
+          if (lastch == '\\')  /* Escaped quote */
+             {
+             if (inquotes_level == 0)
+                {
+                yyerror("Quoting error - escaped quote outside string");
+                FatalError("Unrecoverable");
+                }
+             
+             i--;
+             }
+          else
+             {
+             inquote_level = 1 - inquote_level; /* toggle */
+             continue;
+             }
+          break;
+
       case '(':
-          
-          paren_level++;
+
+          if (inquotes_level == 0)
+             {
+             paren_level++;
+             }
           break;
           
       case ')':
           
-          paren_level--;
+          if (inquotes_level == 0)
+             {          
+             paren_level--;
+             }
           break;
           
       case ',':
           
-          if (dquote_level == 0 && paren_level == 0)
+          if ((inquotes_level == 0) && (paren_level == 0))
              {
              item[i] = '\0';
              i = 0;
@@ -100,13 +122,15 @@ for (sp = string; *sp != '\0'; sp++)
              continue;
              }
       }
-   
+
+   Debug("ListArg[%d]=(%s)\n",i,sp);
    item[i++] = *sp;
    lastch = *sp;
    }
- 
- AppendItem(&ip,item,""); 
- return ip;
+
+item[i] = '\0';
+AppendItem(&ip,item,""); 
+return ip;
 }
 
 /*********************************************************************/
@@ -162,7 +186,7 @@ return(false);
 
 /*********************************************************************/
 
-int IsWildItemIn(struct Item *list,char *item)
+int IsWildItemIn(struct Item *list,char *wildcard)
 
    /* Checks whether item matches a list of wildcards */
 
@@ -175,9 +199,9 @@ for (ptr = list; ptr != NULL; ptr=ptr->next)
       continue;
       }
 
-   if (WildMatch(ptr->name,item))
+   if (WildMatch(wildcard,ptr->name) || WildMatch(ptr->name,wildcard))
       {
-      Debug("IsWildItem(%s,%s)\n",item,ptr->name);
+      Debug("IsWildItem(%s,%s)\n",wildcard,ptr->name);
       return(true);
       }
    }
@@ -207,7 +231,7 @@ if ((sp = malloc(strlen(string)+1)) == NULL)
 
 if (CURRENTLINEPTR == NULL)   /* File is empty */
    {
-   if (filestart == NULL)
+   if (*filestart == NULL)
       {
       *filestart = ip;
       ip->next = NULL;
@@ -792,7 +816,7 @@ for (ip = *list; ip != NULL; ip=ip->next)
       if ((ip->name = malloc(strlen(buff)+1)) == NULL)
          {
          CfLog(cferror,"malloc in CommentItemStarting\n","");
-         FatalError("");;
+         FatalError("");
          }
 
       strcpy(ip->name,buff);
@@ -846,7 +870,7 @@ for (ip = *list; ip != NULL; ip=ip->next)
       if ((ip->name = malloc(strlen(buff)+1)) == NULL)
          {
          CfLog(cferror,"malloc in CommentItemContaining\n","");
-         FatalError("");;
+         FatalError("");
          }
 
       strcpy(ip->name,buff);
@@ -913,7 +937,7 @@ for (ip = *list; ip != NULL; ip=ip->next)
          if ((ip->name = malloc(strlen(buff)+1)) == NULL)
             {
             CfLog(cferror,"malloc in CommentItemContaining\n ","");
-            FatalError("");;
+            FatalError("");
             }
          
          strcpy(ip->name,buff);
