@@ -42,9 +42,7 @@ int ListLen(struct Item *list)
 
 { int count = 0;
   struct Item *ip;
-
-Debug("Check ListLen\n");
-  
+ 
 for (ip = list; ip != NULL; ip=ip->next)
    {
    count++;
@@ -189,30 +187,6 @@ return(false);
 
 /*********************************************************************/
 
-void CopyList (struct Item **dest, struct Item *source)
-
-/* Copy or concat lists */
-    
-{ struct Item *ip;
-
-if (*dest != NULL)
-   {
-   FatalError("CopyList - list not initialized");
-   }
- 
-if (source == NULL)
-   {
-   return;
-   }
- 
-for (ip = source; ip != NULL; ip = ip ->next)
-   {
-   AppendItem(dest,ip->name,ip->classes);
-   }
-}
-
-/*********************************************************************/
-
 struct Item *ConcatLists (struct Item *list1,struct Item *list2)
 
 /* Notes: * Refrain from freeing list2 after using ConcatLists
@@ -228,7 +202,6 @@ if (list1 == NULL)
 for (endOfList1=list1; endOfList1->next!=NULL; endOfList1=endOfList1->next)
    {
    }
-
 endOfList1->next = list2;
 return list1;
 }
@@ -693,7 +666,7 @@ if (isv4 && isCIDR)
 if (isv4 && isrange)
    {
    long i, from = -1, to = -1;
-   char *sp1,buffer1[CF_MAX_IP_LEN];
+   char *sp1,buffer1[8];
    
    sp1 = s;
    
@@ -794,19 +767,10 @@ if (strstr(s1,":") != 0)
    isv6 = true;
    }
 
-if (strstr(s2,".") != 0)
-   {
-   isv4 = true;
-   }
-
-if (strstr(s2,":") != 0)
-   {
-   isv6 = true;
-   }
-
 if (isv4 && isv6)
    {
-   /* This is just wrong */
+   snprintf(OUTPUT,CF_BUFSIZE,"Mixture of IPv6 and IPv4 addresses: %s",s1);
+   CfLog(cferror,OUTPUT,"");
    return -1;
    }
 
@@ -866,7 +830,7 @@ if (isv4)
    else
       {
       long i, from = -1, to = -1, cmp = -1;
-      char *sp1,*sp2,buffer1[CF_MAX_IP_LEN],buffer2[CF_MAX_IP_LEN];
+      char *sp1,*sp2,buffer1[8],buffer2[8];
       
       sp1 = s1;
       sp2 = s2;
@@ -955,7 +919,7 @@ if (isv6)
    else
       {
       long i, from = -1, to = -1, cmp = -1;
-      char *sp1,*sp2,buffer1[CF_MAX_IP_LEN],buffer2[CF_MAX_IP_LEN];
+      char *sp1,*sp2,buffer1[16],buffer2[16];
 
       sp1 = s1;
       sp2 = s2;
@@ -1038,14 +1002,14 @@ int FuzzyHostMatch(char *arg0, char* arg1, char *refhost)
 
 /*
  * do something like...
+ *   @args = split(/,/,$s1);
  *   if ( $refhost !~ /(\d+)$/ ) {
- *     return 1; # failure: refhost doesn't end in numeral
+ *     return 1; # failure: no num in hostname
  *   }
- *   $hostnum = $1;
- *   if ( $hostnum < $args[1] || $hostnum > $args[2] ) {
- *     return 1; # failure: refhost hostnum not in range
+ *   if ( $1 < $args[1] || $1 > $args[2] ) {
+ *     return 1; # failure: hostname num not in range
  *   }
- *   $refhost =~ s/^(.*)\d.*$/$1/;
+ *   $refhost =~ s/^(.*?)\d.*$/$1/;
  *   if ( $refhost ne $args[0] ) {
  *     return 1; # failure: hostname doesn't match basename
  *   }
@@ -1053,16 +1017,12 @@ int FuzzyHostMatch(char *arg0, char* arg1, char *refhost)
  */
 
 { struct Item *args;
-  char *sp, refbase[CF_MAXVARSIZE];
+ char *sp, refbase[CF_MAXVARSIZE];
   long cmp = -1, start = -1, end = -1;
 
-strncpy(refbase,refhost,strlen(refhost));
-sp = refbase + strlen(refbase) - 1;
-while ( isdigit((int)*sp) ) { sp--; }
-sp++;
-sscanf(sp,"%ld",&cmp);
-*sp = '\0';
-Debug("SRDEBUG FuzzyHostMatch: split refhost=%s into refbase=%s and cmp=%d\n",refhost,refbase,cmp);
+sscanf(refhost,"%[^0-9]%ld",&refbase,&cmp);
+
+Debug("Found refbase=%s,cmp=%d\n",refbase,cmp);
 
 if (cmp < 0)
    {
@@ -1078,19 +1038,20 @@ sscanf(arg1,"%ld-%ld",&start,&end);
 
 if ( cmp < start || cmp > end )
    {
-   Debug("SRDEBUG Failed on numberical range (%d < %d < %d)\n",end,cmp,start);
+   Debug("Failed on numberical range (%d < %d < %d)",end,cmp,start);
    return 1;
    }
 
-if (strcmp(refbase,ToUpperStr(arg0)) != 0)
+if (strcmp(refbase,arg0) != 0)
    {
-   Debug("SRDEBUG Failed on name (%s != %s)\n",refbase,ToUpperStr(arg0));
+   Debug("Failed on name %s != %s)",refbase,arg0);
    return 1;
    }
 
 return 0;
 }
 
+
 /*********************************************************************/
 /* String Handling                                                   */
 /*********************************************************************/
