@@ -74,7 +74,7 @@ DB *DBP;
 void PreLockState()
 
 {
- strcpy(CFLOCK,"pre-lock-state");
+strcpy(CFLOCK,"pre-lock-state");
 }
 
 /********************************************************************/
@@ -96,6 +96,25 @@ strcpy(CFLOCK,SAVELOCK);
 
 /********************************************************************/
 
+void WritePID(char *filename)
+
+{ FILE *fp;
+
+snprintf(PIDFILE,CF_BUFSIZE-1,"%s/%s",WORKDIR,filename);
+ 
+if ((fp = fopen(PIDFILE,"w")) == NULL)
+   {
+   snprintf(OUTPUT,CF_BUFSIZE,"Could not write to PID file %s\n",filename);
+   CfLog(cfinform,OUTPUT,"fopen");
+   }
+
+fprintf(fp,"%d\n",getpid());
+
+fclose(fp);
+}
+
+/********************************************************************/
+
 void HandleSignal(int signum)
  
 {
@@ -113,6 +132,7 @@ if (signum != SIGCHLD)
    
    if (signum == SIGTERM || signum == SIGINT || signum == SIGHUP || signum == SIGSEGV || signum == SIGKILL|| signum == SIGPIPE)
       {
+      unlink(PIDFILE);
       ReleaseCurrentLock();
       closelog();
       exit(0);
@@ -487,10 +507,42 @@ if (PutLock(CFLOCK) == -1)
    {
    snprintf(OUTPUT,CF_BUFSIZE*2,"GetLock: can't open new lock file %s\n",CFLOCK);
    CfLog(cferror,OUTPUT,"fopen");
-   FatalError("");;
+   FatalError("");
    }
 }
 
+/**********************************************************************/
+
+void SetSignals()
+
+
+{ int i;
+
+ SIGNALS[SIGHUP] = strdup("SIGHUP");
+ SIGNALS[SIGINT] = strdup("SIGINT");
+ SIGNALS[SIGTRAP] = strdup("SIGTRAP");
+ SIGNALS[SIGKILL] = strdup("SIGKILL");
+ SIGNALS[SIGPIPE] = strdup("SIGPIPE");
+ SIGNALS[SIGCONT] = strdup("SIGCONT");
+ SIGNALS[SIGABRT] = strdup("SIGABRT");
+ SIGNALS[SIGSTOP] = strdup("SIGSTOP");
+ SIGNALS[SIGQUIT] = strdup("SIGQUIT");
+ SIGNALS[SIGTERM] = strdup("SIGTERM");
+ SIGNALS[SIGCHLD] = strdup("SIGCHLD");
+ SIGNALS[SIGUSR1] = strdup("SIGUSR1");
+ SIGNALS[SIGUSR2] = strdup("SIGUSR2");
+ SIGNALS[SIGBUS] = strdup("SIGBUS");
+ SIGNALS[SIGSEGV] = strdup("SIGSEGV");
+
+ for (i = 0; i < highest_signal; i++)
+    {
+    if (SIGNALS[i] == NULL)
+       {
+       SIGNALS[i] = strdup("NOSIG");
+       }
+    }
+}
+
 
 /************************************************************************/
 /* Level 3                                                              */
