@@ -39,7 +39,7 @@ void CfOpenLog()
 
 { char value[CF_BUFSIZE];
   int facility = LOG_USER; 
-  static lastsyslog=0;
+  static int lastsyslog = 0;
  
 if (GetMacroValue(CONTEXTID,"SyslogFacility"))
    {
@@ -236,6 +236,20 @@ switch(level)
        
        break;
 
+   case cfloginform: 
+
+       if (LOGGING && IsPrivileged() && !DONTDO)
+          {
+          syslog(LOG_INFO," %s",buffer);    
+          
+          if ((errstr != NULL) && (strlen(errstr) > 0))
+             {
+             syslog(LOG_INFO," %s",errstr);  
+             }
+          }
+       
+       break;
+
    case cferror:
        printf("%s: %s",VPREFIX,buffer);
        
@@ -281,6 +295,7 @@ switch(level)
 void ResetOutputRoute (char log,char inform)
 
 {
+
 if ((log == 'y') || (log == 'n') || (inform == 'y') || (inform == 'n'))
    {
    INFORM_save = INFORM;
