@@ -71,7 +71,7 @@ if ((ptr = (struct cfObject *)malloc(sizeof(struct cfObject))) == NULL)
    {
    FatalError("Memory Allocation failed for cfObject");
    }
- 
+
 if (VOBJTOP == NULL)
    {
    VOBJ = ptr;
@@ -117,6 +117,31 @@ for (i = 0; i < CF_HASHTABLESIZE; i++)
 
 /*******************************************************************/
 
+void BlankHashTable(char *scope)
+
+{ int i;
+  struct cfObject *ptr;
+
+for (ptr = VOBJ; ptr != NULL; ptr=ptr->next)
+   {
+   if (strcmp(ptr->scope,scope) == 0)
+      {
+      Verbose("Clearing macros in scope(%s)\n",scope);
+      
+      for (i = 0; i < CF_HASHTABLESIZE; i++)
+         {
+         if (ptr->hashtable[i] != NULL)
+            {
+            free(ptr->hashtable[i]);
+            ptr->hashtable[i] = NULL;
+            }
+         }
+      }
+   }
+}
+
+/*******************************************************************/
+
 void PrintHashTable(char **table)
 
 { int i;
@@ -190,7 +215,7 @@ if (strlen(name) > CF_MAXVARSIZE)
    return;
    }
 
-snprintf(exp,CF_BUFSIZE,"$(%s)",name);
+snprintf(exp,CF_BUFSIZE,"${%s}",name);
 
 if (strstr(value,exp))
    {
@@ -198,7 +223,7 @@ if (strstr(value,exp))
    return;
    }
 
-snprintf(exp,CF_BUFSIZE,"${%s}",name);
+snprintf(exp,CF_BUFSIZE,"$(%s)",name);
 
 if (strstr(value,exp))
    {
@@ -251,8 +276,11 @@ if (ptr->hashtable[slot] != 0)
       
       if (CompareMacro(name,ptr->hashtable[slot]) == 0)
          {
-         snprintf(VBUFF,CF_BUFSIZE,"Redefinition of macro %s=%s",name,exp);
-         Warning(VBUFF);
+          if (PARSING && !IsItemIn(VREDEFINES,name))
+             {
+             snprintf(VBUFF,CF_BUFSIZE,"Redefinition of macro %s=%s",name,exp);
+             Warning(VBUFF);
+             }
          free(ptr->hashtable[slot]);
          ptr->hashtable[slot] = sp;
          return;
@@ -373,6 +401,7 @@ else
       {
       }
 
+   Debug1("Return Macrovalue={%s}\n",sp+1);
    return(sp+1);
    }   
 }
