@@ -32,13 +32,93 @@
 #include "cf.extern.h"
 
 
+/*******************************************************************/
+
+void CheckForMethod()
+
+{ struct Item *ip;
+  int i = 0;
+
+if (strcmp(METHODNAME,"cf-nomethod") == 0)
+   {
+   return;
+   }
+
+if (! MINUSF)
+   {
+   FatalError("Input files claim to be a module but this is a parent process\n");
+   }
+
+Verbose("\n++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++\n+\n");
+Verbose("+ This is a private method: %s\n",METHODNAME);
+
+if (METHODARGS == NULL)
+   {
+   FatalError("This module was declared a method but no MethodParameters declaration was given");
+   }
+else
+   {
+   Verbose("+\n+ Method argument prototype = (");
+
+   i = 1;
+   
+   for (ip = METHODARGS; ip != NULL; ip=ip->next)
+      {
+      i++;
+      }
+
+   METHODARGV = (char **) malloc(sizeof(char *) * i); 
+   
+   i = 0;
+
+   for (ip = METHODARGS; ip != NULL; ip=ip->next)
+      {
+      /* Fill this temporarily with the formal parameters */
+      METHODARGV[i++] = ip->name;
+      Verbose("%s ",ip->name);
+      }
+
+   METHODARGC = i;
+   
+   Verbose(")\n+\n");
+   }
+ 
+Verbose("++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++\n\n");
+
+Verbose("Looking for a data package for this method (%s)\n",METHODMD5);
+
+if (!ChildLoadMethodPackage(METHODNAME,METHODMD5))
+   {
+   snprintf(OUTPUT,CF_BUFSIZE,"No valid incoming request to execute method (%s)\n",METHODNAME);
+   CfLog(cfinform,OUTPUT,"");
+   exit(0);
+   }
+
+Debug("Method package looks ok -- proceeding\n"); 
+}
+
+/*******************************************************************/
+
+void CheckMethodReply()
+
+{
+if (ScopeIsMethod())
+   {
+   if (strlen(METHODREPLYTO) > 0)
+      {
+      Banner("Method reply message");
+      DispatchMethodReply();
+      }
+   }
+}
+
 /*****************************************************************************/
 
 void DispatchNewMethod(struct Method *ptr)
 
 { struct Item *ip;
   char label[CF_BUFSIZE]; 
-  char serverip[64],clientip[64];
+  char serverip[CF_SMALLBUF],clientip[CF_SMALLBUF];
 
 serverip[0] = clientip[0] = '\0';
   
@@ -49,7 +129,7 @@ for (ip = ptr->servers; ip != NULL; ip=ip->next)
       Verbose("\nDispatch method localhost:%s to %s/rpc_in\n",ptr->name,VLOCKDIR);
 
       ptr->invitation = 'y';
-      snprintf(label,CF_BUFSIZE-1,"%s/rpc_in/localhost_localhost_%s_%s",VLOCKDIR,ptr->name,ChecksumPrint('m',ptr->digest));
+      snprintf(label,CF_BUFSIZE-1,"%s/rpc_in/localhost+localhost+%s+%s",VLOCKDIR,ptr->name,ChecksumPrint('m',ptr->digest));
       EncapsulateMethod(ptr,label);
       }
    else
@@ -73,7 +153,7 @@ for (ip = ptr->servers; ip != NULL; ip=ip->next)
          }
       
       Verbose("Hailing server (%s) from our calling id %s\n",serverip,VFQNAME);
-      snprintf(label,CF_BUFSIZE-1,"%s/rpc_out/%s_%s_%s_%s",VLOCKDIR,clientip,serverip,ptr->name,ChecksumPrint('m',ptr->digest));
+      snprintf(label,CF_BUFSIZE-1,"%s/rpc_out/%s+%s+%s+%s",VLOCKDIR,clientip,serverip,ptr->name,ChecksumPrint('m',ptr->digest));
       EncapsulateMethod(ptr,label);
       Debug("\nDispatched method %s to %s/rpc_out\n",label,VLOCKDIR);
       }
@@ -307,7 +387,6 @@ if (IsExcluded(ptr->classes))
  
 ResetOutputRoute(ptr->log,ptr->inform);
 
-//if (!GetLock(ASUniqueName("method-exec"),CanonifyName(ptr->name),ptr->ifelapsed,ptr->expireafter,VUQNAME,CFSTARTTIME))
 if (!GetLock(ASUniqueName("method-exec"),CanonifyName(methodname),ptr->ifelapsed,ptr->expireafter,VUQNAME,CFSTARTTIME))
    {
    return;
@@ -400,7 +479,7 @@ return;
 int ParentLoadReplyPackage(char *methodname)
 
 { char client[CF_MAXVARSIZE],server[CF_BUFSIZE],name[CF_BUFSIZE],buf[CF_BUFSIZE];
-  char line[CF_BUFSIZE],type[64],arg[CF_BUFSIZE], **methodargv = NULL;
+  char line[CF_BUFSIZE],type[CF_SMALLBUF],arg[CF_BUFSIZE], **methodargv = NULL;
   char basepackage[CF_BUFSIZE],digeststring[CF_BUFSIZE],extra[CF_MAXVARSIZE];
   char *sp;
   struct Item *ip;
@@ -461,6 +540,7 @@ snprintf(buf,CF_BUFSIZE,"rpc_in_%s_%s",methodname,digeststring);
 
 if (IsDefinedClass(CanonifyName(buf)))
    {
+   free((char *)methodargv);
    return false;
    }
 else
@@ -542,6 +622,7 @@ if ((fp = fopen(basepackage,"r")) == NULL)
                  {
                  snprintf(OUTPUT,CF_BUFSIZE,"could not open argument bundle %s\n",arg);
                  CfLog(cferror,OUTPUT,"fopen");
+                 free((char *)methodargv);
                  return false;
                  }
               
@@ -549,6 +630,7 @@ if ((fp = fopen(basepackage,"r")) == NULL)
                  {
                  snprintf(OUTPUT,CF_BUFSIZE,"Could not write to local parameter file %s\n",methodargv[argnum]);
                  CfLog(cferror,OUTPUT,"fopen");
+                 free((char *)methodargv);
                  fclose(fin);
                  return false;
                  }
@@ -638,7 +720,7 @@ return true;
 
 int ChildLoadMethodPackage(char *name,char *digeststring)
 
-{ char line[CF_BUFSIZE],type[64],arg[CF_BUFSIZE];
+{ char line[CF_BUFSIZE],type[CF_SMALLBUF],arg[CF_BUFSIZE];
   char basepackage[CF_BUFSIZE],cffilename[CF_BUFSIZE],buf[CF_BUFSIZE],ebuff[CF_EXPANDSIZE];
   char clientip[CF_BUFSIZE],ipaddress[CF_BUFSIZE];
   struct stat statbuf;
@@ -666,8 +748,7 @@ else
    strncpy(ipaddress,"localhost",63);     
    }
 
-
-snprintf(basepackage,CF_BUFSIZE-1,"%s/rpc_in/%s_%s_%s_%s",VLOCKDIR,clientip,ipaddress,METHODNAME,METHODMD5);
+snprintf(basepackage,CF_BUFSIZE-1,"%s/rpc_in/%s+%s+%s+%s",VLOCKDIR,clientip,ipaddress,METHODNAME,METHODMD5);
 
 argnum = CountAttachments(basepackage);
  
@@ -886,13 +967,13 @@ return true;
 void DispatchMethodReply()
 
 { char label[CF_BUFSIZE]; 
-  char ipaddress[64],clientip[64];
+  char ipaddress[CF_SMALLBUF],clientip[CF_SMALLBUF];
 
 Verbose("DispatchMethodReply()\n\n");
 
 if (strcmp(METHODREPLYTO,"localhost") == 0 || strcmp(METHODREPLYTO,"::1") == 0 || strcmp(METHODREPLYTO,"127.0.0.1") == 0)
    {    
-   snprintf(label,CF_BUFSIZE-1,"%s/rpc_in/localhost_localhost_%s:Reply_%s",VLOCKDIR,METHODNAME,METHODMD5);
+   snprintf(label,CF_BUFSIZE-1,"%s/rpc_in/localhost+localhost+%s:Reply+%s",VLOCKDIR,METHODNAME,METHODMD5);
    EncapsulateReply(label);
    }
 else
@@ -902,7 +983,7 @@ else
 
    Verbose("\nDispatch method %s:%s to %s/rpc_out\n",METHODREPLYTO,METHODNAME,VLOCKDIR);
 
-   snprintf(label,CF_BUFSIZE-1,"%s/rpc_out/%s_%s_%s:Reply_%s",VLOCKDIR,clientip,ipaddress,METHODNAME,METHODMD5);
+   snprintf(label,CF_BUFSIZE-1,"%s/rpc_out/%s+%s+%s:Reply+%s",VLOCKDIR,clientip,ipaddress,METHODNAME,METHODMD5);
    EncapsulateReply(label);
    }
 }
@@ -912,7 +993,7 @@ else
 
 char *GetMethodFilename(struct Method *ptr)
 
-{ char line[CF_BUFSIZE],type[64],arg[CF_BUFSIZE];
+{ char line[CF_BUFSIZE],type[CF_SMALLBUF],arg[CF_BUFSIZE];
   char basepackage[CF_BUFSIZE],cffilename[CF_BUFSIZE],ebuff[CF_EXPANDSIZE];
   static char returnfile[CF_BUFSIZE];
   FILE *fp;
@@ -1249,11 +1330,11 @@ if ((fp = fopen(name,"w")) == NULL)
        {
        char correction[CF_BUFSIZE];
        snprintf(correction,CF_BUFSIZE-1,"%s/rpc_in/%s",VLOCKDIR,name+strlen(VLOCKDIR)+2+strlen("rpc_out"));
-       fprintf(fp,"%s %s_%d\n",VMETHODPROTO[cfmeth_attacharg],correction,i);
+       fprintf(fp,"%s %s+%d\n",VMETHODPROTO[cfmeth_attacharg],correction,i);
        }
     else
        {
-       fprintf(fp,"%s %s_%d\n",VMETHODPROTO[cfmeth_attacharg],name,i);
+       fprintf(fp,"%s %s+%d\n",VMETHODPROTO[cfmeth_attacharg],name,i);
        }
     }
 
@@ -1270,7 +1351,7 @@ if ((fp = fopen(name,"w")) == NULL)
  for (ip = ptr->send_args; ip != NULL; ip=ip->next)
     {
     i++;    
-    snprintf(filename,CF_BUFSIZE-1,"%s_%d",name,i);
+    snprintf(filename,CF_BUFSIZE-1,"%s+%d",name,i);
     Debug("Create arg_file %s\n",filename);
     
     if (IsBuiltinFunction(ip->name))
@@ -1440,11 +1521,11 @@ if ((fp = fopen(name,"w")) == NULL)
        {
        char correction[CF_BUFSIZE];
        snprintf(correction,CF_BUFSIZE-1,"%s/rpc_in/%s",VLOCKDIR,name+strlen(VLOCKDIR)+2+strlen("rpc_out"));
-       fprintf(fp,"%s %s_%d (%s)\n",VMETHODPROTO[cfmeth_attacharg],correction,i,expbuf);
+       fprintf(fp,"%s %s+%d (%s)\n",VMETHODPROTO[cfmeth_attacharg],correction,i,expbuf);
        }
     else
        {
-       fprintf(fp,"%s %s_%d (%s)\n",VMETHODPROTO[cfmeth_attacharg],name,i,expbuf);
+       fprintf(fp,"%s %s+%d (%s)\n",VMETHODPROTO[cfmeth_attacharg],name,i,expbuf);
        }
     }
 
@@ -1462,7 +1543,7 @@ if ((fp = fopen(name,"w")) == NULL)
  for (ip = METHODRETURNVARS; ip != NULL; ip=ip->next)
     {
     i++;    
-    snprintf(filename,CF_BUFSIZE-1,"%s_%d",name,i);
+    snprintf(filename,CF_BUFSIZE-1,"%s+%d",name,i);
     Debug("Create arg_file %s\n",filename);
     
     if (IsBuiltinFunction(ip->name))
@@ -1585,5 +1666,11 @@ server[0] = '\0';
 digeststring[0] = '\0';
 extra[0] = '\0';
  
-sscanf(name,"%1024[^_]_%1024[^_]_%1024[^_]_%[^_]_%64s",client,server,methodname,digeststring,extra);
+sscanf(name,"%1024[^+]+%1024[^+]+%1024[^+]+%[^+]+%64s",client,server,methodname,digeststring,extra);
+
+Debug("Method client -> %s\n",client);
+Debug("Method server -> %s\n",server);
+Debug("Method name -> %s\n",methodname);
+Debug("Method digeststring -> %s\n",digeststring);
+Debug("Method extra -> %s\n",extra);
 }
