@@ -502,12 +502,16 @@ switch(action)
                  Debug("Skipping excluded pattern %s\n",file);
                  return true;
                  }
+              break;
+              
    case links:
               if (IsWildItemIn(VEXCLUDELINK,lastnode) || IsWildItemIn(exclusions,lastnode))
                  {
                  Debug("Skipping excluded pattern %s\n",file);
                  return true;
                  }
+              
+              break;
    default:
               if (IsWildItemIn(exclusions,lastnode))
                  {
@@ -607,6 +611,8 @@ else if (pid == 0)                     /* child */
       perror("execvp");
       exit(1);
       }
+
+   free((char *)argv);
    }
 else                                    /* parent */
    {
@@ -649,38 +655,6 @@ return false;
 }
 
 
-/**********************************************************************/
-
-void SetSignals()
-
-
-{ int i;
-
- SIGNALS[SIGHUP] = strdup("SIGHUP");
- SIGNALS[SIGINT] = strdup("SIGINT");
- SIGNALS[SIGTRAP] = strdup("SIGTRAP");
- SIGNALS[SIGKILL] = strdup("SIGKILL");
- SIGNALS[SIGPIPE] = strdup("SIGPIPE");
- SIGNALS[SIGCONT] = strdup("SIGCONT");
- SIGNALS[SIGABRT] = strdup("SIGABRT");
- SIGNALS[SIGSTOP] = strdup("SIGSTOP");
- SIGNALS[SIGQUIT] = strdup("SIGQUIT");
- SIGNALS[SIGTERM] = strdup("SIGTERM");
- SIGNALS[SIGCHLD] = strdup("SIGCHLD");
- SIGNALS[SIGUSR1] = strdup("SIGUSR1");
- SIGNALS[SIGUSR2] = strdup("SIGUSR2");
- SIGNALS[SIGBUS] = strdup("SIGBUS");
- SIGNALS[SIGSEGV] = strdup("SIGSEGV");
-
- for (i = 0; i < highest_signal; i++)
-    {
-    if (SIGNALS[i] == NULL)
-       {
-       SIGNALS[i] = strdup("NOSIG");
-       }
-    }
-}
-
 /*********************************************************************/
 
 void SetClassesOnScript(char *execstr,char *classes,char *elseclasses,int useshell)
@@ -858,6 +832,16 @@ if (stat("/etc/UnitedLinux-release",&statbuf) != -1)
    Verbose("\nThis appears to be a UnitedLinux system.\n");
    AddClassToHeap("UnitedLinux");
    }
+
+if (stat("/etc/vmware",&statbuf) != -1)
+   {
+   if (S_ISDIR(statbuf.st_mode))
+      {
+      Verbose("\nThis appears to be a VMWare xSX system.\n");
+      AddClassToHeap("VMware");
+      VM_version();
+      }
+   }
  
 }
 
@@ -930,7 +914,7 @@ char strmajor[CF_MAXVARSIZE];
        }
     }
  
- if (major != -1 && vendor != "")
+ if (major != -1 && (strcmp(vendor,"") != 0))
     {
     classbuf[0] = '\0';
     strcat(classbuf, vendor);
@@ -1104,21 +1088,23 @@ Verbose("Looking for redhat linux info in \"%s\"\n",relstring);
        {
        sprintf(strmajor, "%d", major);
        minor = -2;
-       };
+       }
     }
  
- if (major != -1 && minor != -1 && vendor != "")
+ if (major != -1 && minor != -1 && (strcmp(vendor,"") != 0))
     {
     classbuf[0] = '\0';
     strcat(classbuf, vendor);
     AddClassToHeap(classbuf);
     strcat(classbuf, "_");
-    if(edition != "")
+    
+    if (strcmp(edition,"") != 0)
        {
        strcat(classbuf, edition);
        AddClassToHeap(classbuf);
        strcat(classbuf, "_");
        }
+    
     strcat(classbuf, strmajor);
     AddClassToHeap(classbuf);
     if (minor != -2)
@@ -1136,10 +1122,9 @@ Verbose("Looking for redhat linux info in \"%s\"\n",relstring);
 int linux_suse_version(void)
 {
 #define SUSE_REL_FILENAME "/etc/SuSE-release"
-#define SUSE_ID "SuSE Linux"
 #define SUSE_SLES8_ID "SuSE SLES-8"
 #define SUSE_SLES9_ID "SUSE LINUX Enterprise Server 9"
-#define SUSE_RELEASE_FLAG "Linux "
+#define SUSE_RELEASE_FLAG "linux "
 
 /* The full string read in from SuSE-release */
 char relstring[CF_MAXVARSIZE];
@@ -1148,6 +1133,7 @@ char classbuf[CF_MAXVARSIZE];
 /* Where the numerical release will be found */
 char *release=NULL;
 
+int i;
 int major = -1;
 char strmajor[CF_MAXVARSIZE];
 int minor = -1;
@@ -1180,13 +1166,18 @@ FILE *fp;
     strcat(classbuf, "SLES9");
     AddClassToHeap(classbuf);
     }
- 
-   /* Determine release version. We assume that the version follows
-    * the string "SuSE Linux".
-    */
- 
+
+ /* Convert relstring to lowercase to handle rename of SuSE to 
+  * SUSE with SUSE 10.0. 
+  */
+
+ for (i = 0; i < strlen(relstring); i++)
+    {
+    relstring[i] = tolower(relstring[i]);
+    }
+
  /* Determine release version. We assume that the version follows
-  * the string "SuSE Linux".
+  * the string "SuSE Linux" or "SUSE LINUX".
   */
  release = strstr(relstring, SUSE_RELEASE_FLAG);
  if(release == NULL)
@@ -1262,6 +1253,7 @@ int linux_mandrake_version(void)
 /* We are looking for one of the following strings... */
 #define MANDRAKE_ID "Linux Mandrake"
 #define MANDRAKE_REV_ID "Mandrake Linux"
+#define MANDRAKE_10_1_ID "Mandrakelinux"
 
 #define RELEASE_FLAG "release "
 #define MANDRAKE_REL_FILENAME "/etc/mandrake-release"
@@ -1302,6 +1294,11 @@ char strminor[CF_MAXVARSIZE];
     {
     vendor = "mandrake";
     }
+
+ else if(!strncmp(relstring, MANDRAKE_10_1_ID, strlen(MANDRAKE_10_1_ID)))
+    {
+    vendor = "mandrake";
+    }
  else
     {
     Verbose("Could not identify OS distro from %s\n", MANDRAKE_REL_FILENAME);
@@ -1330,10 +1327,10 @@ char strminor[CF_MAXVARSIZE];
        {
        Verbose("Could not break down release version numbers in %s\n",
        MANDRAKE_REL_FILENAME);
-       };
+       }
     }
 
- if (major != -1 && minor != -1 && vendor != "")
+ if (major != -1 && minor != -1 && strcmp(vendor, ""))
     {
     classbuf[0] = '\0';
     strcat(classbuf, vendor);
@@ -1352,3 +1349,23 @@ char strminor[CF_MAXVARSIZE];
 }
 
 /******************************************************************/
+
+/******************************************************************/
+
+int VM_version(void)
+
+{ FILE *fp;
+  char buffer[CF_BUFSIZE];
+  struct stat statbuf;
+
+if ((fp = fopen("/etc/issue","r")) == NULL)
+   {
+   return 1;   
+   }
+
+fgets(buffer,sizeof(buffer), fp);
+AddClassToHeap(CanonifyName(buffer));
+
+fclose(fp);
+return 0;
+}
