@@ -134,22 +134,25 @@ if ((sp = malloc(strlen(VSYSNAME.nodename)+1)) == NULL)
 
 strcpy(sp,VSYSNAME.nodename);
 SetDomainName(sp);
-
+strncpy(VUQNAME,sp,MAXHOSTNAMELEN);  /* Default assume non-qualified kernel name, correct below */
+      
 for (sp2=sp; *sp2 != '\0'; sp2++)  /* Truncate fully qualified name */
    {
    if (*sp2 == '.')
       {
       *sp2 = '\0';
       Debug("Truncating fully qualified hostname %s to %s\n",VSYSNAME.nodename,sp);
+      strncpy(VUQNAME,sp,MAXHOSTNAMELEN);
       break;
       }
    }
 
- 
 VDEFAULTBINSERVER.name = sp;
 
 AddClassToHeap(CanonifyName(sp));
 
+free(sp); /* Release the ressource */
+
  
 if ((tloc = time((time_t *)NULL)) == -1)
    {
@@ -302,7 +305,7 @@ else
 void GetInterfaceInfo(void)
 
 { int fd,len,i,j;
-  struct ifreq ifbuf[512],ifr, *ifp;
+  struct ifreq ifbuf[CF_IFREQ],ifr, *ifp;
   struct ifconf list;
   struct sockaddr_in *sin;
   struct hostent *hp;
@@ -328,7 +331,7 @@ if (ioctl(fd, SIOCGIFCONF, &list) == -1 || (list.ifc_len < (sizeof(struct ifreq)
 if (ioctl(fd, OSIOCGIFCONF, &list) == -1 || (list.ifc_len < (sizeof(struct ifreq))))
 #endif
    {
-   CfLog(cferror,"Couldn't get interfaces","ioctl");
+   CfLog(cferror,"Couldn't get interfaces - old kernel? Try setting CF_IFREQ to 1024","ioctl");
    exit(1);
    }
 
@@ -384,11 +387,14 @@ for (j = 0,len = 0,ifp = list.ifc_req; len < list.ifc_len; len+=SIZEOF_IFREQ(*if
                AddClassToHeap(CanonifyName(inet_ntoa(sin->sin_addr)));
                Debug("Adding hostname %s..\n",hp->h_name);
                AddClassToHeap(CanonifyName(hp->h_name));
-               
-               for (i=0;hp->h_aliases[i]!=NULL;i++)
+
+               if (hp->h_aliases != NULL)
                   {
-                  Debug("Adding alias %s..\n",hp->h_aliases[i]);
-                  AddClassToHeap(CanonifyName(hp->h_aliases[i]));
+                  for (i=0; hp->h_aliases[i] != NULL; i++)
+                     {
+                     Debug("Adding alias %s..\n",hp->h_aliases[i]);
+                     AddClassToHeap(CanonifyName(hp->h_aliases[i]));
+                     }
                   }
                }               
 
@@ -461,6 +467,26 @@ void GetV6InterfaceInfo(void)
            }
         
         break;
+
+    case hp:
+        
+        if ((pp = cfpopen("/usr/sbin/ifconfig -a","r")) == NULL)
+           {
+           Verbose("Could not find interface info\n");
+           return;
+           }
+
+        break;
+
+    case aix:
+        
+        if ((pp = cfpopen("/etc/ifconfig -a","r")) == NULL)
+           {
+           Verbose("Could not find interface info\n");
+           return;
+           }
+
+        break;
         
     default:
         
@@ -545,32 +571,202 @@ void AddNetworkClass(char *netmask) /* Function contrib David Brownlee <abs@mono
 
 /*********************************************************************/
 
-void SetDomainName(char *sp)           /* Bas van der Vlies */
+void SetDomainName(char *hostname)
 
 { char fqn[CF_MAXVARSIZE];
   char *ptr;
   char buffer[CF_BUFSIZE];
+ 
+strcpy(VFQNAME,hostname); // By default VFQNAME = hostname (nodename)
 
-if (gethostname(fqn, sizeof(fqn)) != -1)
+if (strstr(VFQNAME,".") == 0)
    {
-   strcpy(VFQNAME,fqn);
-   strcpy(buffer,VFQNAME);
-   AddClassToHeap(CanonifyName(buffer));
-   AddClassToHeap(CanonifyName(ToLowerStr(buffer)));
+   // The nodename is not full qualified
+   // We'll try to find the FQDN hostname
 
-   if (strstr(fqn,"."))
+   if (gethostname(fqn, sizeof(fqn)) != -1)
       {
-      ptr = strchr(fqn, '.');
-      strcpy(VDOMAIN, ++ptr);
+      struct hostent *hp;
+
+      if (hp = gethostbyname(fqn))
+         {
+         if (strstr(hp->h_name,"."))
+            {
+            // We find a FQDN hostname
+            // So we change the VFQNAME variable
+            strncpy(VFQNAME,hp->h_name,CF_MAXVARSIZE);
+            VFQNAME[CF_MAXVARSIZE-1]=0; // Be sure the string is null terminated
+            }
+         }
       }
    }
 
+strcpy(buffer,VFQNAME);
+AddClassToHeap(CanonifyName(buffer));
+AddClassToHeap(CanonifyName(ToLowerStr(buffer)));
+
+if (strstr(VFQNAME,"."))
+   {
+// If VFQNAME is full qualified we can create VDOMAIN variable
+   ptr = strchr(VFQNAME, '.');
+   strcpy(VDOMAIN, ++ptr);
+   DeleteClassFromHeap("undefined_domain");
+   }
+
 if (strstr(VFQNAME,".") == 0 && (strcmp(VDOMAIN,CF_START_DOMAIN) != 0))
    {
    strcat(VFQNAME,".");
    strcat(VFQNAME,VDOMAIN);
    }
 
+if (strstr(VFQNAME,"."))
+   {
+   /* Add some domain hierarchy classes */
+   for (ptr=VFQNAME; *ptr != '\0'; ptr++)
+      {
+      if (*ptr == '.')
+         {
+         if (*(ptr+1) != '\0')
+            {
+            Debug("Defining domain #%s#\n",(ptr+1));
+            AddClassToHeap(CanonifyName(ptr+1));
+            }
+         else
+            {
+            Debug("Domain rejected\n");
+            }      
+         }
+      }
+   }
 AddClassToHeap(CanonifyName(VDOMAIN));
-DeleteClassFromHeap("undefined_domain");
+}
+
+/*******************************************************************/
+
+void SetReferenceTime(int setclasses)
+
+{ time_t tloc;
+ char vbuff[CF_BUFSIZE];
+ 
+if ((tloc = time((time_t *)NULL)) == -1)
+   {
+   CfLog(cferror,"Couldn't read system clock\n","");
+   }
+
+CFSTARTTIME = tloc;
+
+snprintf(vbuff,CF_BUFSIZE,"%s",ctime(&tloc));
+
+Verbose("Reference time set to %s\n",ctime(&tloc));
+
+if (setclasses)
+   {
+   AddTimeClass(vbuff);
+   }
+}
+
+
+/*******************************************************************/
+
+void SetStartTime(int setclasses)
+
+{ time_t tloc;
+ 
+if ((tloc = time((time_t *)NULL)) == -1)
+   {
+   CfLog(cferror,"Couldn't read system clock\n","");
+   }
+
+CFINITSTARTTIME = tloc;
+
+Debug("Job start time set to %s\n",ctime(&tloc));
+}
+
+/*******************************************************************/
+
+void BuildClassEnvironment()
+
+{ struct Item *ip;
+ int size = 0;
+ char file[CF_BUFSIZE], *sp;
+ FILE *fp;
+ 
+Debug("(BuildClassEnvironment)\n");
+
+snprintf(ALLCLASSBUFFER,CF_BUFSIZE,"%s=",CF_ALLCLASSESVAR);
+
+if (!IsPrivileged())
+   {
+   Verbose("\n(Non privileged user...)\n\n");
+   
+   if ((sp = getenv("HOME")) == NULL)
+      {
+      FatalError("You do not have a HOME variable pointing to your home directory");
+      }  
+
+   snprintf(file,CF_BUFSIZE,"%s/.cfagent/allclasses",sp);
+   }
+else
+   {
+   snprintf(file,CF_BUFSIZE,"%s/state/allclasses",WORKDIR);
+   }
+
+
+if ((fp = fopen(file,"w")) == NULL)
+   {
+   CfLog(cfinform,"Could not open allclasses cache file","");
+   return;
+   }
+
+for (ip = VHEAP; ip != NULL; ip=ip->next)
+   {
+   if (IsDefinedClass(ip->name))
+      {
+      if ((size += strlen(ip->name)) > CF_ALLCLASSSIZE - CF_BUFFERMARGIN)
+         {
+         Verbose("Class buffer overflowed, dumping class environment for modules\n");
+         Verbose("This would probably crash the exec interface on most machines\n");
+         }
+      else
+         {
+         size++; /* Allow for : separator */
+         strcat(ALLCLASSBUFFER,ip->name);
+         strcat(ALLCLASSBUFFER,":");
+         }
+
+      fprintf(fp,"%s\n",ip->name);
+      }
+   }
+ 
+ for (ip = VALLADDCLASSES; ip != NULL; ip=ip->next)
+    {
+    if (IsDefinedClass(ip->name))
+      {
+      if ((size += strlen(ip->name)) > 4*CF_BUFSIZE - CF_BUFFERMARGIN)
+         {
+         Verbose("Class buffer overflowed, dumping class environment for modules\n");
+         Verbose("This would probably crash the exec interface on most machines\n");
+         }
+      else
+         {
+         size++; /* Allow for : separator */
+         strcat(ALLCLASSBUFFER,ip->name);
+         strcat(ALLCLASSBUFFER,":");         
+         }
+      
+      fprintf(fp,"%s\n",ip->name);
+      }
+    }
+ 
+ Debug2("---\nENVIRONMENT: %s\n---\n",ALLCLASSBUFFER);
+ 
+ if (USEENVIRON)
+    {
+    if (putenv(ALLCLASSBUFFER) == -1)
+       {
+       perror("putenv");
+       }
+    }
+
+ fclose(fp);
 }
