@@ -225,15 +225,6 @@ return sp;
 
 #endif
 
-#ifndef HAVE_STRSEP
-
-char *strsep(char **stringp, const char *delim)
-
-{
-return strtok(stringp,delim);
-}
-
-#endif
 
 
 /***********************************************************/
