@@ -39,7 +39,8 @@
 int BadProtoReply(char *buf)
 
 {
-return (strncmp(buf,"BAD:",4) == 0);
+ Debug("Protoreply: (%s)\n",buf);
+ return (strncmp(buf,"BAD:",4) == 0);
 }
 
 /*********************************************************************/
@@ -63,80 +64,99 @@ return(strncmp(buf,CF_FAILEDSTR,strlen(CF_FAILEDSTR)) == 0);
 int IdentifyForVerification(int sd,char *localip,int family)
 
 { char sendbuff[CF_BUFSIZE],dnsname[CF_BUFSIZE];
-  struct sockaddr_in myaddr;
   struct in_addr *iaddr;
   struct hostent *hp;
   int len,err;
   struct passwd *user_ptr;
   char *uname;
+#if defined(HAVE_GETADDRINFO) && !defined(DARWIN)
+  char myaddr[256]; /* Compilation trick for systems that don't know ipv6 */
+#else
+  struct sockaddr_in myaddr;
+#endif
   
 memset(sendbuff,0,CF_BUFSIZE);
 memset(dnsname,0,CF_BUFSIZE);
 
-
 if (!SKIPIDENTIFY && (strcmp(VDOMAIN,CF_START_DOMAIN) == 0))
    {
    CfLog(cferror,"Undefined domain name","");
    return false;
    }
- 
+
+if (!SKIPIDENTIFY)
+   {
 /* First we need to find out the IP address and DNS name of the socket
    we are sending from. This is not necessarily the same as VFQNAME if
    the machine has a different uname from its IP name (!) This can
    happen on stupidly set up machines or on hosts with multiple
    interfaces, with different names on each interface ... */ 
-
- switch (family)
-    {
-    case AF_INET: len = sizeof(struct sockaddr_in);
-        break;
+   
+   switch (family)
+      {
+      case AF_INET: len = sizeof(struct sockaddr_in);
+          break;
 #if defined(HAVE_GETADDRINFO) && !defined(DARWIN)
-    case AF_INET6: len = sizeof(struct sockaddr_in6);
-        break;
+      case AF_INET6: len = sizeof(struct sockaddr_in6);
+          break;
 #endif
-    default:
-        CfLog(cferror,"Software error in IdentifyForVerification","");
-    }
- 
- if (getsockname(sd,(struct sockaddr *)&myaddr,&len) == -1)
-    {
-    CfLog(cferror,"Couldn't get socket address\n","getsockname");
-    return false;
-    }
- 
- snprintf(localip,CF_MAX_IP_LEN-1,"%s",sockaddr_ntop((struct sockaddr *)&myaddr)); 
- 
- Debug("Identifying this agent as %s i.e. %s, with signature %d\n",localip,VFQNAME,CFSIGNATURE);
- 
+      default:
+          CfLog(cferror,"Software error in IdentifyForVerification","");
+      }
+   
+   if (getsockname(sd,(struct sockaddr *)&myaddr,&len) == -1)
+      {
+      CfLog(cferror,"Couldn't get socket address\n","getsockname");
+      return false;
+      }
+   
+   snprintf(localip,CF_MAX_IP_LEN-1,"%s",sockaddr_ntop((struct sockaddr *)&myaddr)); 
+   
+   Debug("Identifying this agent as %s i.e. %s, with signature %d\n",localip,VFQNAME,CFSIGNATURE);
+   
 #if defined(HAVE_GETADDRINFO) && !defined(DARWIN)
- 
- if ((err=getnameinfo((struct sockaddr *)&myaddr,len,dnsname,CF_MAXVARSIZE,NULL,0,0)) != 0)
-    {
-    snprintf(OUTPUT,CF_BUFSIZE,"Couldn't look up address v6 for %s: %s\n",dnsname,gai_strerror(err));
-    CfLog(cferror,OUTPUT,"");
-    return false;
-    }
- 
+   
+   if ((err=getnameinfo((struct sockaddr *)&myaddr,len,dnsname,CF_MAXVARSIZE,NULL,0,0)) != 0)
+      {
+      snprintf(OUTPUT,CF_BUFSIZE,"Couldn't look up address v6 for %s: %s\n",dnsname,gai_strerror(err));
+      CfLog(cferror,OUTPUT,"");
+      return false;
+      }
+   
 #else 
- 
- iaddr = &(myaddr.sin_addr); 
- hp = gethostbyaddr((void *)iaddr,sizeof(myaddr.sin_addr),family);
- 
- if ((hp == NULL) || (hp->h_name == NULL))
-    {
-    CfLog(cferror,"Couldn't lookup IP address\n","gethostbyaddr");
-    return false;
-    }
- 
- strncpy(dnsname,hp->h_name,CF_MAXVARSIZE);
- 
- if ((strstr(hp->h_name,".") == 0) && (strlen(VDOMAIN) > 0))
-    {
-    strcat(dnsname,".");
-    strcat(dnsname,VDOMAIN);
-    } 
+   
+   iaddr = &(myaddr.sin_addr); 
+
+   hp = gethostbyaddr((void *)iaddr,sizeof(myaddr.sin_addr),family);
+   
+   if ((hp == NULL) || (hp->h_name == NULL))
+      {
+      CfLog(cferror,"Couldn't lookup IP address\n","gethostbyaddr");
+      return false;
+      }
+   
+   strncpy(dnsname,hp->h_name,CF_MAXVARSIZE);
+   
+   if ((strstr(hp->h_name,".") == 0) && (strlen(VDOMAIN) > 0))
+      {
+      strcat(dnsname,".");
+      strcat(dnsname,VDOMAIN);
+      } 
 #endif 
- 
+   }
+else
+   {
+   if (strlen(VFQNAME) > 0)
+      {
+      Verbose("SkipIdent was requested, so we are trusting and annoucning the identity as (%s) for this host\n",VFQNAME);
+      strcat(dnsname,VFQNAME);
+      }
+   else
+      {
+      strcat(dnsname,"skipident");
+      }
+   }
+
 user_ptr = getpwuid(getuid());
 uname = user_ptr ? user_ptr->pw_name : "UNKNOWN";
 
@@ -388,6 +408,7 @@ if (server_pubkey == NULL)
       err = ERR_get_error();
       snprintf(OUTPUT,CF_BUFSIZE,"Private decrypt failed = %s\n",ERR_reason_error_string(err));
       CfLog(cferror,OUTPUT,"");
+      RSA_free(newkey);
       return false;
       }
 
@@ -395,6 +416,7 @@ if (server_pubkey == NULL)
    if ((len=ReceiveTransaction(CONN->sd,in,NULL)) == 0)
       {
       CfLog(cfinform,"Protocol error in RSA authentation from IP %s\n",ip->server);
+      RSA_free(newkey);
       return false;
       }
    
@@ -403,10 +425,12 @@ if (server_pubkey == NULL)
       err = ERR_get_error();
       snprintf(OUTPUT,CF_BUFSIZE,"Private decrypt failed = %s\n",ERR_reason_error_string(err));
       CfLog(cferror,OUTPUT,"");
+      RSA_free(newkey);
       return false;
       }
 
    SavePublicKey(keyname,newkey);
+   server_pubkey = RSAPublicKey_dup(newkey);
    RSA_free(newkey);
    }
  
@@ -427,7 +451,7 @@ else
    DebugBinOut(CONN->session_key,CF_BLOWFISHSIZE);
    }
 
-//blowfishmpisize = BN_bn2mpi((BIGNUM *)CONN->session_key,in);
+/* blowfishmpisize = BN_bn2mpi((BIGNUM *)CONN->session_key,in); */
 
 DebugBinOut(CONN->session_key,CF_BLOWFISHSIZE);
 
