@@ -249,6 +249,8 @@ for (tp = VTIDY; tp != NULL; tp=tp->next)
       continue;
       }
 
+   tp->done = 'y';
+   
    Debug("  Check rule %s ...\n",tp->path);
    
    if ((tp->maxrecurse != CF_INF_RECURSE) && (level > tp->maxrecurse+1))
@@ -324,6 +326,7 @@ int RecursiveTidySpecialArea(char *name,struct Tidy *tp,int maxrecurse,struct st
   struct dirent *dirp;
   char pcwd[CF_BUFSIZE], *parentdir;
   int is_dir,level,goback;
+  static char *defaultname = "/";
        
 Debug("RecursiveTidySpecialArea(%s)\n",name);
 memset(&statbuf,0,sizeof(statbuf));
@@ -353,9 +356,7 @@ if (IgnoreFile(name,"",tp->ignores))
 
 if (strlen(name) == 0)     /* Check for root dir */
    {
-   name = (char *) malloc(2);
-   name[0] = '/';
-   name[1] = '\0';
+   name = defaultname;
    }
 
 if (maxrecurse == tp->maxrecurse)
@@ -373,6 +374,7 @@ if (maxrecurse == tp->maxrecurse)
             CfLog(cferror,OUTPUT,"");
             }
          }
+
       return true;
       }
    }
@@ -381,6 +383,7 @@ if (maxrecurse == tp->maxrecurse)
     {
     snprintf(OUTPUT,CF_BUFSIZE*2,"Can't open directory [%s]\n",name);
     CfLog(cfverbose,OUTPUT,"opendir");
+    free(name);
     return true;
     }
 
@@ -692,7 +695,7 @@ else
    size_match = (tlp->size <= statbuf->st_size);
    }
 
-age_match = tlp->age*CF_TICKS_PER_DAY <= (nowticks-fileticks);
+age_match = tlp->age*CF_TICKS_PER_DAY <= (nowticks-fileticks) || (nowticks < fileticks);
 
 if (age_match && size_match)
    {
