@@ -104,6 +104,7 @@ char *VVNAMES[] =
    "defaultcopytype",
    "allowredefinitionof",
    "defaultpkgmgr",     /* For packages */
+   "abortclasses",
    NULL
    };
 
@@ -175,7 +176,11 @@ for (sp = str; *sp != '\0' ; sp++)       /* check for varitems */
    {
    switch (*sp)
       {
-      case '$': dollar = true;
+      case '$':
+          if (*(sp+1) == '{' || *(sp+1) == '(')
+             {
+             dollar = true;
+             }
           break;
       case '(':
       case '{': 
@@ -331,7 +336,7 @@ int ExpandVarstring(char *string,char buffer[CF_EXPANDSIZE],char *bserver)
 { char *sp,*env;
   char varstring = false;
   char currentitem[CF_EXPANDSIZE],temp[CF_BUFSIZE],name[CF_MAXVARSIZE];
-  int len;
+  int len,increment;
   time_t tloc;
   
 memset(buffer,0,CF_EXPANDSIZE);
@@ -388,6 +393,7 @@ for (sp = string; /* No exit */ ; sp++)       /* check for varitems */
       if (strstr(temp,"$"))
          {
          Debug("Nested variables");
+         increment = strlen(temp)-3;
          ExpandVarstring(temp,currentitem,"");
          CheckVarID(currentitem);
          sp += 3; /* $() */
@@ -395,6 +401,7 @@ for (sp = string; /* No exit */ ; sp++)       /* check for varitems */
       else
          {
          strncpy(currentitem,temp,CF_BUFSIZE-1);
+         increment = strlen(currentitem);
          }
 
       Debug("Scanning variable %s\n",currentitem);
@@ -766,8 +773,9 @@ for (sp = string; /* No exit */ ; sp++)       /* check for varitems */
                    {
                    FatalError("Can't expandvarstring");
                    }
+                
                 strcat(buffer,env);
-                Debug("Expansion gave (%s)\n",buffer);             
+                Debug("Expansion gave (%s), len = %d\n",buffer,strlen(currentitem));             
 
                 break;
                 }
@@ -785,7 +793,8 @@ for (sp = string; /* No exit */ ; sp++)       /* check for varitems */
              strcat(buffer,name);
          }
       
-      sp += strlen(currentitem);
+      sp += increment;
+
       currentitem[0] = '\0';
       }
    }
@@ -898,7 +907,7 @@ struct Item *SplitVarstring(char *varstring,char sep)
   char before[CF_BUFSIZE],after[CF_BUFSIZE],result[CF_BUFSIZE];
   int i;
   
-Debug("SplitVarstring(%s,%c=%d)\n",varstring,sep,sep);
+Debug("SplitVarstring([%s],%c=%d)\n",varstring,sep,sep);
 
 memset(before,0,CF_BUFSIZE);
 memset(after,0,CF_BUFSIZE);
